/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_xDMD8vhD);
  numBytes += sLine_init(&sLine_FTFeIzTV);
  numBytes += sLine_init(&sLine_Q7wo8UDV);
  numBytes += sLine_init(&sLine_O9np7GWF);
  numBytes += sLine_init(&sLine_SmxhU3Qr);
  numBytes += sBiquad_init(&sBiquad_s_C4Xl65kc);
  numBytes += sLine_init(&sLine_feTiTrD3);
  numBytes += sLine_init(&sLine_zgdvcgoU);
  numBytes += sLine_init(&sLine_7I8IkMkD);
  numBytes += sLine_init(&sLine_luQTH23w);
  numBytes += sLine_init(&sLine_eYofaWbK);
  numBytes += sBiquad_init(&sBiquad_s_sGiiG4XQ);
  numBytes += sLine_init(&sLine_ZzERC1eB);
  numBytes += sLine_init(&sLine_Y3CzqMD9);
  numBytes += sLine_init(&sLine_3N93t4YC);
  numBytes += sLine_init(&sLine_PJscdVPl);
  numBytes += sLine_init(&sLine_FImyBQ29);
  numBytes += sLine_init(&sLine_54MqoVpa);
  numBytes += sBiquad_init(&sBiquad_s_DdsUbuaW);
  numBytes += sLine_init(&sLine_VHwSqfq3);
  numBytes += sLine_init(&sLine_WfLSYGOo);
  numBytes += sLine_init(&sLine_VfgWB3lo);
  numBytes += sLine_init(&sLine_0ZmfOL0Q);
  numBytes += sLine_init(&sLine_8tFqwLvq);
  numBytes += sLine_init(&sLine_2NSIzL49);
  numBytes += sBiquad_init(&sBiquad_s_63IS8BpI);
  numBytes += sLine_init(&sLine_buaPGSLL);
  numBytes += sLine_init(&sLine_lWI4tLvw);
  numBytes += sLine_init(&sLine_lKGovGtU);
  numBytes += sLine_init(&sLine_0TBwuNQK);
  numBytes += sLine_init(&sLine_jMAC2ho2);
  numBytes += sBiquad_init(&sBiquad_s_KcUNYXJ8);
  numBytes += sLine_init(&sLine_9yEHmtNA);
  numBytes += sLine_init(&sLine_iSW7F5Yh);
  numBytes += sLine_init(&sLine_Qxh0HVK6);
  numBytes += sLine_init(&sLine_rkpXL11R);
  numBytes += sLine_init(&sLine_vV7SAMrq);
  numBytes += sLine_init(&sLine_a6autZ0S);
  numBytes += sBiquad_init(&sBiquad_s_4hLbhCmr);
  numBytes += sLine_init(&sLine_tOYnzf5b);
  numBytes += sLine_init(&sLine_AO2rZ4n4);
  numBytes += sLine_init(&sLine_1goSm9Zr);
  numBytes += sLine_init(&sLine_4FkqoEdr);
  numBytes += sLine_init(&sLine_dUaqa5FB);
  numBytes += sLine_init(&sLine_AB1tZY1X);
  numBytes += sLine_init(&sLine_QikgEvqi);
  numBytes += sLine_init(&sLine_hKLy1OZR);
  numBytes += sLine_init(&sLine_KMXBEv8k);
  numBytes += sLine_init(&sLine_QMTMDGYj);
  numBytes += sLine_init(&sLine_YMDuPPsn);
  numBytes += sLine_init(&sLine_rqr7pDMe);
  numBytes += sLine_init(&sLine_2T5rapD5);
  numBytes += sLine_init(&sLine_QcWROYeo);
  numBytes += sLine_init(&sLine_3YTudQSD);
  numBytes += sEnv_init(&sEnv_8I2AavaZ, 512, 256);
  numBytes += sEnv_init(&sEnv_k8RewRdg, 512, 256);
  numBytes += sLine_init(&sLine_lpXITf1q);
  numBytes += sLine_init(&sLine_rw2R5x0S);
  numBytes += sLine_init(&sLine_zKhmL0eq);
  numBytes += sLine_init(&sLine_jsOCqsb9);
  numBytes += sLine_init(&sLine_zYIxGrEX);
  numBytes += sLine_init(&sLine_EKuCotir);
  numBytes += sLine_init(&sLine_H9Fyl5Ww);
  numBytes += sLine_init(&sLine_bFZMWWwB);
  numBytes += sLine_init(&sLine_OU8jNKbx);
  numBytes += sLine_init(&sLine_lY4aP3aS);
  numBytes += sLine_init(&sLine_9JeXxVOp);
  numBytes += sLine_init(&sLine_im1mFQcA);
  numBytes += sLine_init(&sLine_OITM22Uh);
  numBytes += sLine_init(&sLine_EPx76WLx);
  numBytes += sLine_init(&sLine_67F3F3cf);
  numBytes += sLine_init(&sLine_jnCCOh9a);
  numBytes += sLine_init(&sLine_3r9ZuJmw);
  numBytes += sLine_init(&sLine_916H9aN2);
  numBytes += sEnv_init(&sEnv_05lA29xt, 512, 256);
  numBytes += sEnv_init(&sEnv_QuennDTW, 512, 256);
  numBytes += sLine_init(&sLine_j3bMlyI5);
  numBytes += sLine_init(&sLine_YAQqEmQ4);
  numBytes += sLine_init(&sLine_8I1ZYsHX);
  numBytes += sLine_init(&sLine_bg6xx5OP);
  numBytes += sLine_init(&sLine_lsv3ZpYe);
  numBytes += sLine_init(&sLine_hvw88l84);
  numBytes += sLine_init(&sLine_4viKkn7K);
  numBytes += sLine_init(&sLine_T4cf6d5T);
  numBytes += sLine_init(&sLine_imap6kx1);
  numBytes += sLine_init(&sLine_s5dewbb7);
  numBytes += sLine_init(&sLine_rbkkO81R);
  numBytes += sLine_init(&sLine_UjIe0wB0);
  numBytes += sLine_init(&sLine_FFPTPYu5);
  numBytes += sLine_init(&sLine_Qv3eaGnk);
  numBytes += sLine_init(&sLine_YjL4PIej);
  numBytes += sLine_init(&sLine_fWRK1Yyw);
  numBytes += sLine_init(&sLine_FxjQcaT5);
  numBytes += sLine_init(&sLine_6TbGbZLC);
  numBytes += sLine_init(&sLine_RdoIW7TP);
  numBytes += sLine_init(&sLine_uUrJ6ASI);
  numBytes += sEnv_init(&sEnv_C0qxFZhV, 512, 256);
  numBytes += sEnv_init(&sEnv_lNcyKyzB, 512, 256);
  numBytes += sLine_init(&sLine_CjF2d5lm);
  numBytes += sLine_init(&sLine_Jauuiu3F);
  numBytes += sLine_init(&sLine_IqUJbKmP);
  numBytes += sLine_init(&sLine_6BrdkH41);
  numBytes += sLine_init(&sLine_ODdFopKq);
  numBytes += sLine_init(&sLine_2dUsWEuF);
  numBytes += sLine_init(&sLine_GcuJvUXP);
  numBytes += sLine_init(&sLine_c81Khmzt);
  numBytes += sLine_init(&sLine_fcK3TKG7);
  numBytes += sLine_init(&sLine_4FuRiRKa);
  numBytes += sLine_init(&sLine_R3UlV6im);
  numBytes += sLine_init(&sLine_23g6OJ46);
  numBytes += sLine_init(&sLine_scf0alsI);
  numBytes += sLine_init(&sLine_XXaEjQCy);
  numBytes += sLine_init(&sLine_hvgcP6hu);
  numBytes += sLine_init(&sLine_nV1cwAVB);
  numBytes += sLine_init(&sLine_8rb5DdsF);
  numBytes += sLine_init(&sLine_K9zOQ3mr);
  numBytes += sEnv_init(&sEnv_N5SiBRa8, 512, 256);
  numBytes += sEnv_init(&sEnv_6j78uC21, 512, 256);
  numBytes += sLine_init(&sLine_66u6Ukwv);
  numBytes += sLine_init(&sLine_I7K81zKl);
  numBytes += sLine_init(&sLine_emrotTTQ);
  numBytes += sLine_init(&sLine_nn8fFKr1);
  numBytes += sLine_init(&sLine_YIazHxvq);
  numBytes += sLine_init(&sLine_Zja1w4Ff);
  numBytes += sLine_init(&sLine_7kKII2te);
  numBytes += sLine_init(&sLine_2kVhlrGH);
  numBytes += sLine_init(&sLine_ADU3pU8E);
  numBytes += sLine_init(&sLine_OVIIniNx);
  numBytes += sLine_init(&sLine_olLnLmzE);
  numBytes += sLine_init(&sLine_2jBiqcyt);
  numBytes += sLine_init(&sLine_FpvHjCof);
  numBytes += sLine_init(&sLine_Cfo3mEtD);
  numBytes += sLine_init(&sLine_FWY9PQO3);
  numBytes += sLine_init(&sLine_kPTb6DvY);
  numBytes += sLine_init(&sLine_nUCE0QFc);
  numBytes += sLine_init(&sLine_5D4Wla7L);
  numBytes += sLine_init(&sLine_cHtUmy29);
  numBytes += sLine_init(&sLine_ww3slCCJ);
  numBytes += sEnv_init(&sEnv_B0dIa2Pd, 512, 256);
  numBytes += sEnv_init(&sEnv_JxZZHewb, 512, 256);
  numBytes += sLine_init(&sLine_h40aHv3q);
  numBytes += sLine_init(&sLine_Apfcv8qH);
  numBytes += sLine_init(&sLine_t3sCLgyX);
  numBytes += sLine_init(&sLine_7VL79Njo);
  numBytes += sLine_init(&sLine_A4iUqYeO);
  numBytes += sLine_init(&sLine_v6lZF7Jr);
  numBytes += sLine_init(&sLine_nvtTWWvs);
  numBytes += sLine_init(&sLine_DlyL8j4R);
  numBytes += sLine_init(&sLine_zKnnP0vm);
  numBytes += sLine_init(&sLine_BtddmSqq);
  numBytes += sLine_init(&sLine_fg4rdsLb);
  numBytes += sLine_init(&sLine_5Xd2g0VE);
  numBytes += sLine_init(&sLine_e6Thk3AC);
  numBytes += sLine_init(&sLine_s5YJ384D);
  numBytes += sLine_init(&sLine_fSsM6t4s);
  numBytes += sLine_init(&sLine_6o9dr5e7);
  numBytes += sLine_init(&sLine_pFzcvv2s);
  numBytes += sLine_init(&sLine_J5to9nmY);
  numBytes += sEnv_init(&sEnv_8KVf23yW, 512, 256);
  numBytes += sEnv_init(&sEnv_ces4OKNA, 512, 256);
  numBytes += sLine_init(&sLine_lKRGoCU4);
  numBytes += sLine_init(&sLine_Tb6keyZu);
  numBytes += sLine_init(&sLine_xXjR9Ejs);
  numBytes += sLine_init(&sLine_7OC7X3OX);
  numBytes += sLine_init(&sLine_yaHtpyqH);
  numBytes += sLine_init(&sLine_lzzAREx4);
  numBytes += cVar_init_f(&cVar_wRL8NeiJ, 0.0f);
  numBytes += cVar_init_f(&cVar_CJNpCzO7, 0.0f);
  numBytes += cVar_init_f(&cVar_KaL8GEYA, 0.0f);
  numBytes += cVar_init_f(&cVar_RYamJPXe, 0.0f);
  numBytes += cVar_init_f(&cVar_kvFRpE5E, 0.0f);
  numBytes += cVar_init_f(&cVar_mHb3A5S0, 1.0f);
  numBytes += cVar_init_f(&cVar_CKlHhUX6, 0.0f);
  numBytes += cVar_init_f(&cVar_9WuZS8VQ, 0.0f);
  numBytes += cVar_init_f(&cVar_Z6hYpUpg, 0.0f);
  numBytes += cVar_init_f(&cVar_fBeNiR6V, 0.0f);
  numBytes += cSlice_init(&cSlice_yedcMs4M, 1, -1);
  numBytes += cVar_init_f(&cVar_3dBjeKVZ, 1337.0f);
  numBytes += cVar_init_f(&cVar_NLXQvknZ, 0.0f);
  numBytes += cIf_init(&cIf_00dv5g5R, false);
  numBytes += cIf_init(&cIf_pkhVKCh4, false);
  numBytes += cBinop_init(&cBinop_cR4d5Uku, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ELJsCNtT, false);
  numBytes += cBinop_init(&cBinop_vsx4zZ3Q, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_vJonjxMy, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_PsZLMm4X, 0.0f);
  numBytes += cIf_init(&cIf_v1EXOned, false);
  numBytes += cIf_init(&cIf_6OGGKHqj, false);
  numBytes += cBinop_init(&cBinop_yYy9dqrb, 0.0f); // __pow
  numBytes += cIf_init(&cIf_d66M5tMd, false);
  numBytes += cBinop_init(&cBinop_4y6hNB1m, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_72yZR9mU, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_FwBC8RLn, 0.0f);
  numBytes += cIf_init(&cIf_MEJgNYUm, false);
  numBytes += cIf_init(&cIf_YXspJS9M, false);
  numBytes += cBinop_init(&cBinop_ixGFGhEl, 0.0f); // __pow
  numBytes += cIf_init(&cIf_DmyJEJYn, false);
  numBytes += cBinop_init(&cBinop_K7OX6se3, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_22RYwgsB, -15.0f); // __eq
  numBytes += cIf_init(&cIf_sIZAQJqJ, false);
  numBytes += cSlice_init(&cSlice_PXaGRUmM, 1, -1);
  numBytes += cVar_init_f(&cVar_dr70IFVw, 0.0f);
  numBytes += cSlice_init(&cSlice_gh8jumh0, 1, -1);
  numBytes += cVar_init_f(&cVar_K3W9zt7K, 0.0f);
  numBytes += cSlice_init(&cSlice_WSFW5uS7, 1, -1);
  numBytes += cVar_init_f(&cVar_TXJraRcY, 0.0f);
  numBytes += cSlice_init(&cSlice_3uyGP4ga, 1, -1);
  numBytes += cVar_init_f(&cVar_y26mh829, 0.313f);
  numBytes += cBinop_init(&cBinop_7ZbfarBQ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_4TD3o4YV, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_n6QEaOJ9, 0.0f);
  numBytes += cVar_init_f(&cVar_BSi5Vrwq, 1337.0f);
  numBytes += cVar_init_f(&cVar_Kfx5IIdi, 0.3f);
  numBytes += cBinop_init(&cBinop_tMpcksBX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cGwZWRVC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F9SEfiHw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vK1IRhnK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uTpiP1gN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GS6LiDOZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7mDCYIQC, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_lTi6qf2S, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_D2Nvrs3a, 0.0f);
  numBytes += cVar_init_f(&cVar_AAsR2Wlq, 1337.0f);
  numBytes += cVar_init_f(&cVar_fHwm3c9n, 0.313f);
  numBytes += cBinop_init(&cBinop_FnMuoCvZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HmL4B2xD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_inEP343P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wmaF8Dba, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RYr2QFZ4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mv8gVPle, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_4EpPA2zY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_3Buw6ULn, 0.0f);
  numBytes += cVar_init_f(&cVar_x1gwRKLx, 1037.0f);
  numBytes += cVar_init_f(&cVar_xKzXKadq, 0.4f);
  numBytes += cBinop_init(&cBinop_odqridHj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_inRegy7y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qprZGvWp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SdYHGKDm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HJBr45nJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sSVifNgm, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_VD1lL5jh, 1, -1);
  numBytes += cVar_init_f(&cVar_7OjavuOg, 1337.0f);
  numBytes += cVar_init_f(&cVar_KtwtQaHu, 0.0f);
  numBytes += cIf_init(&cIf_ERli5Hii, false);
  numBytes += cIf_init(&cIf_AHubwXik, false);
  numBytes += cBinop_init(&cBinop_PAY2ztt4, 0.0f); // __pow
  numBytes += cIf_init(&cIf_jlCmKqXy, false);
  numBytes += cBinop_init(&cBinop_D5lXCMn7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_197M2O46, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Y5GIoMK3, 0.0f);
  numBytes += cIf_init(&cIf_JPy3Unpb, false);
  numBytes += cIf_init(&cIf_vEGGolJz, false);
  numBytes += cBinop_init(&cBinop_uliMo2Ho, 0.0f); // __pow
  numBytes += cIf_init(&cIf_bCVCMST3, false);
  numBytes += cBinop_init(&cBinop_yr1fsxeD, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_aG9E9chf, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_8Qh0LJoM, 0.0f);
  numBytes += cIf_init(&cIf_Xo12sfi8, false);
  numBytes += cIf_init(&cIf_CuI3wd8r, false);
  numBytes += cBinop_init(&cBinop_8NdMOJpx, 0.0f); // __pow
  numBytes += cIf_init(&cIf_qrNoiWo5, false);
  numBytes += cBinop_init(&cBinop_N3pBCIVK, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9cmnrXqf, -15.0f); // __eq
  numBytes += cIf_init(&cIf_GImybfhk, false);
  numBytes += cSlice_init(&cSlice_QjHcjMC4, 1, -1);
  numBytes += cVar_init_f(&cVar_GVdEzmbq, 0.0f);
  numBytes += cSlice_init(&cSlice_K35YFhOm, 1, -1);
  numBytes += cVar_init_f(&cVar_K2v5B417, 0.0f);
  numBytes += cSlice_init(&cSlice_DgCDxJxl, 1, -1);
  numBytes += cVar_init_f(&cVar_CVVo2uHX, 0.0f);
  numBytes += cSlice_init(&cSlice_wgZgvZ6W, 1, -1);
  numBytes += cVar_init_f(&cVar_tInjQ2wH, 0.313f);
  numBytes += cBinop_init(&cBinop_P1CHo4TR, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_31pmYoZ2, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2qZ3tsG9, 0.0f);
  numBytes += cVar_init_f(&cVar_d86Bbco5, 1337.0f);
  numBytes += cVar_init_f(&cVar_p9n8IB2l, 0.3f);
  numBytes += cBinop_init(&cBinop_mn2zqb5D, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Dirf9GuL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L2OvDkOY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Y4XsxyHV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cK0NR0UJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3gCgrjdL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ma3IYKsi, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_OUL5mGkP, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xWAkv9VF, 0.0f);
  numBytes += cVar_init_f(&cVar_PWc7WF6r, 1337.0f);
  numBytes += cVar_init_f(&cVar_oXhyAnSb, 0.313f);
  numBytes += cBinop_init(&cBinop_2cIOP5iF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tuNxYYfO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JLUogoeX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cGjFklXG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W2RGATYJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sik3mTwm, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_T8tjtTHY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_dlBFsnr1, 0.0f);
  numBytes += cVar_init_f(&cVar_ovZIAexZ, 1037.0f);
  numBytes += cVar_init_f(&cVar_gyWI0Gn6, 0.4f);
  numBytes += cBinop_init(&cBinop_zhngUmQ0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UgAK87Sv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UzTMQsGt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EBUsir6W, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DaHQ0cEF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NIGF21M1, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_P4QQETPM, 5705.6f);
  numBytes += cVar_init_f(&cVar_FDEigvhf, 313.3f);
  numBytes += cBinop_init(&cBinop_2l8gP9Be, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_TXX0EwU2, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_gg6MI6Jr, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_DwdHSFeZ, 1, -1);
  numBytes += cVar_init_f(&cVar_iFvY22vC, 0.5f);
  numBytes += cVar_init_f(&cVar_ZNDIRAE8, 0.0f);
  numBytes += cVar_init_f(&cVar_2OBnviHc, 0.0f);
  numBytes += cIf_init(&cIf_u0rpWKLS, false);
  numBytes += cIf_init(&cIf_RWfcuzpu, false);
  numBytes += cDelay_init(this, &cDelay_xyp5WyfG, 10.0f);
  numBytes += cIf_init(&cIf_eIok8QB8, false);
  numBytes += cIf_init(&cIf_ayukdHlK, false);
  numBytes += cDelay_init(this, &cDelay_02IKhrf1, 10.0f);
  numBytes += cIf_init(&cIf_gv69z5QO, false);
  numBytes += cIf_init(&cIf_PU1xLnVD, false);
  numBytes += cDelay_init(this, &cDelay_4vSfFl6b, 10.0f);
  numBytes += cIf_init(&cIf_ULpl7Y9k, false);
  numBytes += cIf_init(&cIf_pgVUVjty, false);
  numBytes += cDelay_init(this, &cDelay_RIHv0xdj, 10.0f);
  numBytes += cIf_init(&cIf_85Kn7t69, false);
  numBytes += cIf_init(&cIf_0UTsNOrt, false);
  numBytes += cDelay_init(this, &cDelay_0xVvjJc2, 10.0f);
  numBytes += cIf_init(&cIf_BQCCpwnD, false);
  numBytes += cIf_init(&cIf_xPuChVNi, false);
  numBytes += cDelay_init(this, &cDelay_QzhFzzHi, 10.0f);
  numBytes += cIf_init(&cIf_jvDsCO9W, false);
  numBytes += cIf_init(&cIf_8VvRW0Mn, false);
  numBytes += cDelay_init(this, &cDelay_85aXoZtW, 10.0f);
  numBytes += cIf_init(&cIf_TRbYJjvI, false);
  numBytes += cIf_init(&cIf_Jp3RT3Tz, false);
  numBytes += cDelay_init(this, &cDelay_jpxD57ec, 10.0f);
  numBytes += cIf_init(&cIf_aLEdvuPg, false);
  numBytes += cIf_init(&cIf_aolZuLyp, false);
  numBytes += cDelay_init(this, &cDelay_bRSyopr6, 10.0f);
  numBytes += cIf_init(&cIf_BR3VwFbi, false);
  numBytes += cIf_init(&cIf_G1azr9m2, false);
  numBytes += cDelay_init(this, &cDelay_ZX14O3un, 10.0f);
  numBytes += cIf_init(&cIf_RGTRJsVp, false);
  numBytes += cIf_init(&cIf_Fs7RzbAO, false);
  numBytes += cDelay_init(this, &cDelay_KOBFAl2F, 10.0f);
  numBytes += cIf_init(&cIf_VocLS6tU, false);
  numBytes += cIf_init(&cIf_dBGMHqnZ, false);
  numBytes += cDelay_init(this, &cDelay_ahyMCF1x, 10.0f);
  numBytes += sVarf_init(&sVarf_JMj3XXFj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XgNQVIPc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0H6UUASK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Rk24idhD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iD9qEnjg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CswBK4RD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9ycg3PKl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qcWIsCaV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_DixvPjcv, 0.0f);
  numBytes += cSlice_init(&cSlice_NpXJStps, 1, -1);
  numBytes += cVar_init_f(&cVar_YBpAip5F, 1.0f);
  numBytes += cSlice_init(&cSlice_ak7Tb1jY, 1, -1);
  numBytes += cVar_init_f(&cVar_lV5Ne8ER, 0.0f);
  numBytes += cSlice_init(&cSlice_DqFI8Qs2, 1, -1);
  numBytes += cVar_init_f(&cVar_EQXW3SnD, 512.0f);
  numBytes += cSlice_init(&cSlice_qGgeFMkP, 1, -1);
  numBytes += cVar_init_f(&cVar_dHWJMhJO, 1.0f);
  numBytes += cSlice_init(&cSlice_COoTDqAP, 1, -1);
  numBytes += cVar_init_f(&cVar_qPoYbhpx, 1.0f);
  numBytes += cDelay_init(this, &cDelay_D4mgjkpY, 20.0f);
  numBytes += cVar_init_f(&cVar_dzFojlpg, 0.0f);
  numBytes += cIf_init(&cIf_HK5q0eaI, false);
  numBytes += cIf_init(&cIf_57zDrK85, false);
  numBytes += cBinop_init(&cBinop_kwZX8AgV, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_9C77ymWA, 1, -1);
  numBytes += cVar_init_f(&cVar_QTOObYbV, 0.0f);
  numBytes += sVarf_init(&sVarf_7QHrG7XT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sCdTfaPH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QBuFdkfc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_szSg8TqW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Y9AMAtzs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LckS7ywX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_edsmT7Vv, 0.0f);
  numBytes += cVar_init_f(&cVar_agHobrHY, 0.0f);
  numBytes += cIf_init(&cIf_JgmLdlVR, false);
  numBytes += cIf_init(&cIf_XA031AKA, false);
  numBytes += cDelay_init(this, &cDelay_hNZEQge1, 10.0f);
  numBytes += cIf_init(&cIf_w7yppu30, false);
  numBytes += cIf_init(&cIf_elQBPX8n, false);
  numBytes += cDelay_init(this, &cDelay_SOxxvD2A, 10.0f);
  numBytes += cIf_init(&cIf_kPCZAG3n, false);
  numBytes += cIf_init(&cIf_JC63vDN7, false);
  numBytes += cDelay_init(this, &cDelay_fIONeKCS, 10.0f);
  numBytes += cIf_init(&cIf_P51trzj4, false);
  numBytes += cIf_init(&cIf_tfrp0dZh, false);
  numBytes += cDelay_init(this, &cDelay_lmA6FrJ5, 10.0f);
  numBytes += cIf_init(&cIf_OmpGSGN8, false);
  numBytes += cIf_init(&cIf_fUbZwLcn, false);
  numBytes += cDelay_init(this, &cDelay_6S8oOB6R, 10.0f);
  numBytes += cIf_init(&cIf_RuNg8wxU, false);
  numBytes += cIf_init(&cIf_NukyAYs2, false);
  numBytes += cDelay_init(this, &cDelay_IANRmvzC, 10.0f);
  numBytes += cIf_init(&cIf_OFW0Xv4P, false);
  numBytes += cIf_init(&cIf_VEm08rhQ, false);
  numBytes += cDelay_init(this, &cDelay_QWufyErR, 10.0f);
  numBytes += cIf_init(&cIf_tQJPbwH7, false);
  numBytes += cIf_init(&cIf_tpwJWkHL, false);
  numBytes += cDelay_init(this, &cDelay_0NYnOCus, 10.0f);
  numBytes += cIf_init(&cIf_v5GYzPj5, false);
  numBytes += cIf_init(&cIf_XnnXnh4F, false);
  numBytes += cDelay_init(this, &cDelay_OnT9TLj9, 10.0f);
  numBytes += cIf_init(&cIf_M0lvoIoE, false);
  numBytes += cIf_init(&cIf_XpJ4LE1D, false);
  numBytes += cDelay_init(this, &cDelay_qd62XIPz, 10.0f);
  numBytes += cIf_init(&cIf_vXDBvyOR, false);
  numBytes += cIf_init(&cIf_iZf468Va, false);
  numBytes += cDelay_init(this, &cDelay_5gL4e7be, 10.0f);
  numBytes += cIf_init(&cIf_86RcTEul, false);
  numBytes += cIf_init(&cIf_4qBrPLuN, false);
  numBytes += cDelay_init(this, &cDelay_8JIEIRMG, 10.0f);
  numBytes += sVarf_init(&sVarf_na4zd2yW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vhMDKSOh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_u7SEbjaX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DPjqO6Sy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2x4cn39u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_g1ggr5wz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9YC6RL7g, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e8ialC3r, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_EHWEowQB, 0.0f);
  numBytes += cSlice_init(&cSlice_VNwhXyr9, 1, -1);
  numBytes += cVar_init_f(&cVar_jP41j4l8, 1.0f);
  numBytes += cSlice_init(&cSlice_ILVSaCXZ, 1, -1);
  numBytes += cVar_init_f(&cVar_eNlDCwbX, 0.0f);
  numBytes += cSlice_init(&cSlice_NGnUileG, 1, -1);
  numBytes += cVar_init_f(&cVar_4xnKJLt4, 512.0f);
  numBytes += cSlice_init(&cSlice_IJD3TRrp, 1, -1);
  numBytes += cVar_init_f(&cVar_N4EHx9x6, 1.0f);
  numBytes += cSlice_init(&cSlice_NMguCvrH, 1, -1);
  numBytes += cVar_init_f(&cVar_VKqpFccA, 1.0f);
  numBytes += cDelay_init(this, &cDelay_MEMWKI7z, 20.0f);
  numBytes += cVar_init_f(&cVar_pn4pXEWR, 0.0f);
  numBytes += cIf_init(&cIf_fjclpkGH, false);
  numBytes += cIf_init(&cIf_V71sXjCx, false);
  numBytes += cBinop_init(&cBinop_m4dZfF1E, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_8LUVYxau, 1, -1);
  numBytes += cVar_init_f(&cVar_umTix8rO, 0.0f);
  numBytes += sVarf_init(&sVarf_aH7ztarG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hilUcDsD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9Ea2JTmW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YqAlHNVi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qJlYZGf6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0oVRCv4X, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VycZz8KO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WBFCvsY8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rHUnVnBC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d4FAhhE8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_2wdCNtjH, 0.0f);
  numBytes += cVar_init_f(&cVar_zKu5bJPS, 0.0f);
  numBytes += cVar_init_f(&cVar_R6cUEzWq, 0.0f);
  numBytes += cVar_init_f(&cVar_4ewJkT60, 0.0f);
  numBytes += cVar_init_f(&cVar_NOIff12y, 0.0f);
  numBytes += cVar_init_f(&cVar_zT7eAdd0, 1.0f);
  numBytes += cSlice_init(&cSlice_bofpWUyt, 1, -1);
  numBytes += cVar_init_f(&cVar_W6EGcOkH, 0.5f);
  numBytes += cVar_init_f(&cVar_qfp8UMBR, 0.0f);
  numBytes += cVar_init_f(&cVar_kt6DulLk, 0.0f);
  numBytes += cIf_init(&cIf_YhFeEQ3g, false);
  numBytes += cIf_init(&cIf_6TIt9y9T, false);
  numBytes += cDelay_init(this, &cDelay_bdXIOw9z, 10.0f);
  numBytes += cIf_init(&cIf_M8h1W7hj, false);
  numBytes += cIf_init(&cIf_gEflgktp, false);
  numBytes += cDelay_init(this, &cDelay_gcqqQASc, 10.0f);
  numBytes += cIf_init(&cIf_mdKoPkuJ, false);
  numBytes += cIf_init(&cIf_W6DGm9yZ, false);
  numBytes += cDelay_init(this, &cDelay_yFCr3pbN, 10.0f);
  numBytes += cIf_init(&cIf_MyXhZFSY, false);
  numBytes += cIf_init(&cIf_e2HuMIBb, false);
  numBytes += cDelay_init(this, &cDelay_KH2azsHu, 10.0f);
  numBytes += cIf_init(&cIf_nBNv8eHV, false);
  numBytes += cIf_init(&cIf_yQjpvQNQ, false);
  numBytes += cDelay_init(this, &cDelay_HdeEnCQg, 10.0f);
  numBytes += cIf_init(&cIf_r87OSDLY, false);
  numBytes += cIf_init(&cIf_O92aYs0o, false);
  numBytes += cDelay_init(this, &cDelay_Ua9bSfCg, 10.0f);
  numBytes += cIf_init(&cIf_Sl0dLRYj, false);
  numBytes += cIf_init(&cIf_YYW03pvZ, false);
  numBytes += cDelay_init(this, &cDelay_TY43hvvf, 10.0f);
  numBytes += cIf_init(&cIf_qA4yEhB2, false);
  numBytes += cIf_init(&cIf_3DxNdedU, false);
  numBytes += cDelay_init(this, &cDelay_0a7NVpUN, 10.0f);
  numBytes += cIf_init(&cIf_lNEhM1RW, false);
  numBytes += cIf_init(&cIf_2tbmD2F9, false);
  numBytes += cDelay_init(this, &cDelay_BvAPUDZv, 10.0f);
  numBytes += cIf_init(&cIf_RsnG6I1h, false);
  numBytes += cIf_init(&cIf_jQVuWXDO, false);
  numBytes += cDelay_init(this, &cDelay_n7VN2c1D, 10.0f);
  numBytes += cIf_init(&cIf_CY9BXvdY, false);
  numBytes += cIf_init(&cIf_QKIkZfdo, false);
  numBytes += cDelay_init(this, &cDelay_fcQ49cHq, 10.0f);
  numBytes += cIf_init(&cIf_txciklWy, false);
  numBytes += cIf_init(&cIf_YpMpzCuL, false);
  numBytes += cDelay_init(this, &cDelay_GJTgTXs8, 10.0f);
  numBytes += sVarf_init(&sVarf_zeAFWw6b, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_amxWlj5Q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_omjPNv5S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_79Vj6AtR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5lytIzup, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uiUHmmNy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vmPVrhYt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LPLBq9AD, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lRhTojfN, 0.0f);
  numBytes += cSlice_init(&cSlice_cgOSNqja, 1, -1);
  numBytes += cVar_init_f(&cVar_oFt1Fhnx, 1.0f);
  numBytes += cSlice_init(&cSlice_NDpUhx2d, 1, -1);
  numBytes += cVar_init_f(&cVar_JESgWUrs, 0.0f);
  numBytes += cSlice_init(&cSlice_uflnoEZr, 1, -1);
  numBytes += cVar_init_f(&cVar_HrjOeZ1V, 512.0f);
  numBytes += cSlice_init(&cSlice_oDwZu1sV, 1, -1);
  numBytes += cVar_init_f(&cVar_4y9jhYxx, 1.0f);
  numBytes += cSlice_init(&cSlice_RBdhYId8, 1, -1);
  numBytes += cVar_init_f(&cVar_Mkcqb0PW, 1.0f);
  numBytes += cDelay_init(this, &cDelay_i1241QDj, 20.0f);
  numBytes += cVar_init_f(&cVar_fxFK37Am, 0.0f);
  numBytes += cIf_init(&cIf_m0M0e0kx, false);
  numBytes += cIf_init(&cIf_ITbPgCF2, false);
  numBytes += cBinop_init(&cBinop_U3TQeCwA, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_83jdy5YH, 1, -1);
  numBytes += cVar_init_f(&cVar_slvz4SLM, 0.0f);
  numBytes += sVarf_init(&sVarf_P7wVsE8Z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_muQmtaV5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xc1iUKYg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PVWWepC7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HDaOl5It, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_z18kN1yV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_tXsybCV5, 0.0f);
  numBytes += cVar_init_f(&cVar_IcgPfhtZ, 0.0f);
  numBytes += cIf_init(&cIf_SFpwcKfK, false);
  numBytes += cIf_init(&cIf_Qd3xRyYp, false);
  numBytes += cDelay_init(this, &cDelay_gfK3Y5da, 10.0f);
  numBytes += cIf_init(&cIf_aU7OmsVP, false);
  numBytes += cIf_init(&cIf_jX5xVRYE, false);
  numBytes += cDelay_init(this, &cDelay_JLLbQ6OO, 10.0f);
  numBytes += cIf_init(&cIf_QekL4h0b, false);
  numBytes += cIf_init(&cIf_kNSSEuqi, false);
  numBytes += cDelay_init(this, &cDelay_jAr6cxFY, 10.0f);
  numBytes += cIf_init(&cIf_2O4lPhbI, false);
  numBytes += cIf_init(&cIf_dySKV4BN, false);
  numBytes += cDelay_init(this, &cDelay_fulqXj8z, 10.0f);
  numBytes += cIf_init(&cIf_aA1hRvSZ, false);
  numBytes += cIf_init(&cIf_zCCI3TRt, false);
  numBytes += cDelay_init(this, &cDelay_SVEIRvs9, 10.0f);
  numBytes += cIf_init(&cIf_HAdqk2So, false);
  numBytes += cIf_init(&cIf_8sihLMgm, false);
  numBytes += cDelay_init(this, &cDelay_wiR08BNS, 10.0f);
  numBytes += cIf_init(&cIf_2Vd5DHr0, false);
  numBytes += cIf_init(&cIf_FuMWvZI8, false);
  numBytes += cDelay_init(this, &cDelay_ghhRMKIz, 10.0f);
  numBytes += cIf_init(&cIf_rsHM8gDR, false);
  numBytes += cIf_init(&cIf_vV5VQNFJ, false);
  numBytes += cDelay_init(this, &cDelay_EyI8I2bo, 10.0f);
  numBytes += cIf_init(&cIf_UqixNn1B, false);
  numBytes += cIf_init(&cIf_FMG8E7VG, false);
  numBytes += cDelay_init(this, &cDelay_WcFoD5qL, 10.0f);
  numBytes += cIf_init(&cIf_JnIesXMw, false);
  numBytes += cIf_init(&cIf_CdNHRwfa, false);
  numBytes += cDelay_init(this, &cDelay_tJSZ2eis, 10.0f);
  numBytes += cIf_init(&cIf_DLbYWztH, false);
  numBytes += cIf_init(&cIf_0zXj7zLX, false);
  numBytes += cDelay_init(this, &cDelay_kxzuFKVZ, 10.0f);
  numBytes += cIf_init(&cIf_mqMkZgKC, false);
  numBytes += cIf_init(&cIf_f79s2zJz, false);
  numBytes += cDelay_init(this, &cDelay_nPOrQUFW, 10.0f);
  numBytes += sVarf_init(&sVarf_T6pMXDJ0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GtXTzvVJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1Cnzr1GK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LNCkQCxs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qiHcQB6d, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nUdy6Oek, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CiAfKGlH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LYkzKyG8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VWmKHPg2, 0.0f);
  numBytes += cSlice_init(&cSlice_0L9LC1um, 1, -1);
  numBytes += cVar_init_f(&cVar_oCEsF3VJ, 1.0f);
  numBytes += cSlice_init(&cSlice_tLnIfMX7, 1, -1);
  numBytes += cVar_init_f(&cVar_tJayuwhs, 0.0f);
  numBytes += cSlice_init(&cSlice_EOTBHyTg, 1, -1);
  numBytes += cVar_init_f(&cVar_DpiuHKO0, 512.0f);
  numBytes += cSlice_init(&cSlice_pw78p04P, 1, -1);
  numBytes += cVar_init_f(&cVar_EDeJWx8Y, 1.0f);
  numBytes += cSlice_init(&cSlice_MoNHbbDh, 1, -1);
  numBytes += cVar_init_f(&cVar_y8ASHgpY, 1.0f);
  numBytes += cDelay_init(this, &cDelay_MJP46uCn, 20.0f);
  numBytes += cVar_init_f(&cVar_Go2uwCmE, 0.0f);
  numBytes += cIf_init(&cIf_QHeaa33u, false);
  numBytes += cIf_init(&cIf_UH6I04nE, false);
  numBytes += cBinop_init(&cBinop_kkTbuh2k, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_h0iVgWJP, 1, -1);
  numBytes += cVar_init_f(&cVar_FXSaRvBK, 0.0f);
  numBytes += sVarf_init(&sVarf_fKdqw9Pd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bEo3VLqS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YW4vWF6x, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qJkKBFzr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rQpCN701, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_h8Bbbo38, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e5sZ6bHs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DBYhKVIM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1Z1tZFVx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Wl0CSus1, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_xtFfayxD, 0.0f);
  numBytes += cVar_init_f(&cVar_cWP0ASJu, 0.0f);
  numBytes += cVar_init_f(&cVar_tMDmTUC1, 0.0f);
  numBytes += cVar_init_f(&cVar_TGpRYBuK, 0.0f);
  numBytes += cVar_init_f(&cVar_bSlh0NpR, 0.0f);
  numBytes += cVar_init_f(&cVar_XSV5LPpD, 1.0f);
  numBytes += cSlice_init(&cSlice_4jOT5Aoq, 1, -1);
  numBytes += cVar_init_f(&cVar_XyhP9xvG, 0.5f);
  numBytes += cVar_init_f(&cVar_DF7LtATY, 0.0f);
  numBytes += cVar_init_f(&cVar_ZCL93WMB, 0.0f);
  numBytes += cIf_init(&cIf_aCsBsLEm, false);
  numBytes += cIf_init(&cIf_AXg0ZunC, false);
  numBytes += cDelay_init(this, &cDelay_8k1Le0Dd, 10.0f);
  numBytes += cIf_init(&cIf_0iTlf6Xd, false);
  numBytes += cIf_init(&cIf_xOQS9BsZ, false);
  numBytes += cDelay_init(this, &cDelay_wSSWi6xU, 10.0f);
  numBytes += cIf_init(&cIf_cw5SS9Ff, false);
  numBytes += cIf_init(&cIf_RfKrrlqo, false);
  numBytes += cDelay_init(this, &cDelay_dtPJiDR0, 10.0f);
  numBytes += cIf_init(&cIf_LPvpMByJ, false);
  numBytes += cIf_init(&cIf_bXzHE5NP, false);
  numBytes += cDelay_init(this, &cDelay_S25SQiJO, 10.0f);
  numBytes += cIf_init(&cIf_Bx1he568, false);
  numBytes += cIf_init(&cIf_LHV9A3dT, false);
  numBytes += cDelay_init(this, &cDelay_okc9aUyS, 10.0f);
  numBytes += cIf_init(&cIf_lWh4NveX, false);
  numBytes += cIf_init(&cIf_a8Gnu465, false);
  numBytes += cDelay_init(this, &cDelay_dQssBt3o, 10.0f);
  numBytes += cIf_init(&cIf_42uWl9tF, false);
  numBytes += cIf_init(&cIf_40ilaPAW, false);
  numBytes += cDelay_init(this, &cDelay_drLkwdsw, 10.0f);
  numBytes += cIf_init(&cIf_fKyUZUAM, false);
  numBytes += cIf_init(&cIf_9DadnTuW, false);
  numBytes += cDelay_init(this, &cDelay_g9vOhTcg, 10.0f);
  numBytes += cIf_init(&cIf_CoCwY55j, false);
  numBytes += cIf_init(&cIf_DF3qDwSe, false);
  numBytes += cDelay_init(this, &cDelay_FAJQpcho, 10.0f);
  numBytes += cIf_init(&cIf_rSnjPXkz, false);
  numBytes += cIf_init(&cIf_g2JIkHm1, false);
  numBytes += cDelay_init(this, &cDelay_ZLESp67O, 10.0f);
  numBytes += cIf_init(&cIf_eIfhc5mn, false);
  numBytes += cIf_init(&cIf_Hj6HjmAR, false);
  numBytes += cDelay_init(this, &cDelay_8I1IWSgC, 10.0f);
  numBytes += cIf_init(&cIf_P0IWq08B, false);
  numBytes += cIf_init(&cIf_WFtGt8Hu, false);
  numBytes += cDelay_init(this, &cDelay_qICwEPCw, 10.0f);
  numBytes += sVarf_init(&sVarf_GAcXPE5Q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ncykVzdu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0HSjEky7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_E1fIeS6f, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3PM6NRdM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6XElEKFi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_twxOL2gv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kFHxfEsg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_d0UIHWkd, 0.0f);
  numBytes += cSlice_init(&cSlice_TMxj7QA6, 1, -1);
  numBytes += cVar_init_f(&cVar_1oGPpB75, 1.0f);
  numBytes += cSlice_init(&cSlice_ifgaJRn1, 1, -1);
  numBytes += cVar_init_f(&cVar_oqHWbQht, 0.0f);
  numBytes += cSlice_init(&cSlice_p6s6QNQs, 1, -1);
  numBytes += cVar_init_f(&cVar_xojiIr5Y, 512.0f);
  numBytes += cSlice_init(&cSlice_C8CKU8O1, 1, -1);
  numBytes += cVar_init_f(&cVar_uHYAOPZu, 1.0f);
  numBytes += cSlice_init(&cSlice_3Egxs0Qh, 1, -1);
  numBytes += cVar_init_f(&cVar_wSIQhArf, 1.0f);
  numBytes += cDelay_init(this, &cDelay_H6pNhDtd, 20.0f);
  numBytes += cVar_init_f(&cVar_uMxkK7pw, 0.0f);
  numBytes += cIf_init(&cIf_aVfvLGjq, false);
  numBytes += cIf_init(&cIf_O7i9Vdq8, false);
  numBytes += cBinop_init(&cBinop_qMxT4q5F, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_j3DiTLfh, 1, -1);
  numBytes += cVar_init_f(&cVar_GZcoSQBY, 0.0f);
  numBytes += sVarf_init(&sVarf_Qy5tS7Wo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tJ70SdOP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0BjaxN28, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_E1ykewi2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NzbO1kxH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VMRc3G3y, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_H6tWrHtF, 0.0f);
  numBytes += cVar_init_f(&cVar_RaDelSIk, 0.0f);
  numBytes += cIf_init(&cIf_xxXZ3ova, false);
  numBytes += cIf_init(&cIf_zPHeFrlC, false);
  numBytes += cDelay_init(this, &cDelay_qWh8vqfn, 10.0f);
  numBytes += cIf_init(&cIf_wadgKbMN, false);
  numBytes += cIf_init(&cIf_xaGdbLJH, false);
  numBytes += cDelay_init(this, &cDelay_w1FSZynK, 10.0f);
  numBytes += cIf_init(&cIf_dJvaFWBE, false);
  numBytes += cIf_init(&cIf_x24q4YMN, false);
  numBytes += cDelay_init(this, &cDelay_wjMhw4yg, 10.0f);
  numBytes += cIf_init(&cIf_bv5kOKAo, false);
  numBytes += cIf_init(&cIf_ZHwwvLsT, false);
  numBytes += cDelay_init(this, &cDelay_iFWnr6uI, 10.0f);
  numBytes += cIf_init(&cIf_RjMA7dsG, false);
  numBytes += cIf_init(&cIf_mahygbl4, false);
  numBytes += cDelay_init(this, &cDelay_ZqUCMNgu, 10.0f);
  numBytes += cIf_init(&cIf_BZNcsPfW, false);
  numBytes += cIf_init(&cIf_uYHBcyBu, false);
  numBytes += cDelay_init(this, &cDelay_ieuZPlxO, 10.0f);
  numBytes += cIf_init(&cIf_C6fBjYHl, false);
  numBytes += cIf_init(&cIf_XzzZRJSg, false);
  numBytes += cDelay_init(this, &cDelay_ogNOkBKr, 10.0f);
  numBytes += cIf_init(&cIf_Ou3JvxHS, false);
  numBytes += cIf_init(&cIf_le3XEfkY, false);
  numBytes += cDelay_init(this, &cDelay_kOVoW3dT, 10.0f);
  numBytes += cIf_init(&cIf_uQGVnhVf, false);
  numBytes += cIf_init(&cIf_XrS5qDui, false);
  numBytes += cDelay_init(this, &cDelay_HMTWMqaf, 10.0f);
  numBytes += cIf_init(&cIf_P2Kenpl7, false);
  numBytes += cIf_init(&cIf_Gk4DGgPY, false);
  numBytes += cDelay_init(this, &cDelay_lL1RMxyR, 10.0f);
  numBytes += cIf_init(&cIf_74qCo3HX, false);
  numBytes += cIf_init(&cIf_6X5rnLnb, false);
  numBytes += cDelay_init(this, &cDelay_tkYB9df6, 10.0f);
  numBytes += cIf_init(&cIf_Voki0qLv, false);
  numBytes += cIf_init(&cIf_H0CP8gp8, false);
  numBytes += cDelay_init(this, &cDelay_Xn0zaNKk, 10.0f);
  numBytes += sVarf_init(&sVarf_c7meKh0X, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ziKLogsF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pGXBMu2q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZRxTI3mt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5ymnO4kV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_95et0w97, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SZu149Ob, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YlGN4I7Q, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Y7wMgskn, 0.0f);
  numBytes += cSlice_init(&cSlice_Er5nW4c6, 1, -1);
  numBytes += cVar_init_f(&cVar_Wh6DFBLr, 1.0f);
  numBytes += cSlice_init(&cSlice_38pT8oAg, 1, -1);
  numBytes += cVar_init_f(&cVar_3c9IS2cT, 0.0f);
  numBytes += cSlice_init(&cSlice_79wymP7u, 1, -1);
  numBytes += cVar_init_f(&cVar_AVUqBteI, 512.0f);
  numBytes += cSlice_init(&cSlice_NYJVyIkc, 1, -1);
  numBytes += cVar_init_f(&cVar_K6HQJSNX, 1.0f);
  numBytes += cSlice_init(&cSlice_USRkBA0C, 1, -1);
  numBytes += cVar_init_f(&cVar_TzYs2DSb, 1.0f);
  numBytes += cDelay_init(this, &cDelay_ec8dCN4v, 20.0f);
  numBytes += cVar_init_f(&cVar_YlXlUBxL, 0.0f);
  numBytes += cIf_init(&cIf_SFPiEieY, false);
  numBytes += cIf_init(&cIf_5S13HbR2, false);
  numBytes += cBinop_init(&cBinop_sSUrOmhG, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_x1NTl6kd, 1, -1);
  numBytes += cVar_init_f(&cVar_nfB2srwp, 0.0f);
  numBytes += sVarf_init(&sVarf_aXCbXoE4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5Z7QKiSP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f2txLTEm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PRj7ZqSm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2cTII000, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6EuvYzcc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vdjnRpgs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IrZSwK3K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QsVQ0cZ6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s7nV9wqn, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_qPd9KWMg, 0.0f);
  numBytes += cVar_init_f(&cVar_7zcss8Lv, 0.0f);
  numBytes += cVar_init_f(&cVar_BAcoilxZ, 0.0f);
  numBytes += sVarf_init(&sVarf_ue4Q0yK2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KkgVwEJZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ujyL913Q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AYEAfZZl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kFCCoLTy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hp9iFfBy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qyKrSBii, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4Krz1zVU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RnT9gRjM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YBnVbyr8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VuEwVgge, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_r2tni5hX, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_8I2AavaZ);
  sEnv_free(&sEnv_k8RewRdg);
  sEnv_free(&sEnv_05lA29xt);
  sEnv_free(&sEnv_QuennDTW);
  sEnv_free(&sEnv_C0qxFZhV);
  sEnv_free(&sEnv_lNcyKyzB);
  sEnv_free(&sEnv_N5SiBRa8);
  sEnv_free(&sEnv_6j78uC21);
  sEnv_free(&sEnv_B0dIa2Pd);
  sEnv_free(&sEnv_JxZZHewb);
  sEnv_free(&sEnv_8KVf23yW);
  sEnv_free(&sEnv_ces4OKNA);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QlCGLk30_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lKe1HXOY_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZxYahyL2_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wxo0QNtz_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WoEffYro_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eWQDEuDV_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yX1EiQtJ_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5Qa6Jvps_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2ezp8psC_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2Hnay4BA_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WBgCxIk2_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tbPFkU2x_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HhyNMNmX_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kuio450i_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_POJVRBHR_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xDYVSD91_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3wZb6Uoc_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JUP4BfBS_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_810GjNgS_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9qNZurPF_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_66ROnvgi_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1jpA0qos_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5Fh76eqY_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fhlSMN64_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o5QGkO21_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nsCJahlm_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GspcLTt2_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SR7ecwDK_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cWJgAdW9_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A5xmOXFd_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eAz6sHYR_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VpNoDRzY_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OztowSrf_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_u0TvZL01_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aNSVOzRm_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iw6Nm7ge_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Sb94ORiU_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ov6V8kqw_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Rq9RR5do_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9QNlmUya_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YremC60Y_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2Jv0htIY_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vhh3HKn6_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3MlWxWa4_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mSGWrmIw_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zNspT3NJ_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JNk5SXcd_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VSfdfk24_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PNsVL5qT_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_neP48Fjp_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iT5xYoJj_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_miNxZ5cN_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cNtbUQ89_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8jNB3X2P_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kve5jjKS_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OYc7cwAy_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_64W6h1ei_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XBiuyqrV_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PmRwMPuH_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZCiAnUmF_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xklyc3UW_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MJrxSTRP_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8E4Latac_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m6jwopj6_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YwpZKxBi_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j80x93J7_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n4sAAdyw_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yjfLv2zw_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t6EoXgr0_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JRYrqwiS_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s9D0ik7m_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RQlt0o9d_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j0HgpWx4_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UXbq2r6n_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y1ob3sfx_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Iel6lz4q_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sgzQc6wH_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5psdvpM6_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iC4hY9lj_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mgzoNqQo_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hcDUm7kb_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_51vfUzSe_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fVdOB1J5_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RAP7wnER_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WkS6PeY3_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RuuYyErg_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_24rle8iv_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eA7r5huO_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hFpLHC2g_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HgfLG95u_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QrDn1mPB_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pFIjw5Wz_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_93v7Zmvf_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_wRL8NeiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jVs3QFuP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CJNpCzO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YEpBYa2b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_KaL8GEYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uISm3oDy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_RYamJPXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GrCXjcUM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_kvFRpE5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TY7GN3RT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_mHb3A5S0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Euz0P0jf_sendMessage);
  cMsg_rSaujatK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Euz0P0jf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mHb3A5S0, 1, m, &cVar_mHb3A5S0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vQUEXHPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xhieze1N_sendMessage(_c, 0, m);
  cMsg_3gz60OtT_sendMessage(_c, 0, m);
  cMsg_GBZZmcsz_sendMessage(_c, 0, m);
  cMsg_P4aCv7Wx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CKlHhUX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wsIE1Yu7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9WuZS8VQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oY90mCnH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Z6hYpUpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E7hn5Nhf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_fBeNiR6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bhU9319B_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GhOLGdPg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YkHIq0aP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KyCBJXUM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Vv6vyaJZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yedcMs4M, 0, m, &cSlice_yedcMs4M_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DT0Sks0a_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_yedcMs4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_f8gmZG5w_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_f8gmZG5w_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3dBjeKVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f8gmZG5w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_f8gmZG5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SR7ecwDK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_NLXQvknZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ND2X8sEw_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_00dv5g5R, 0, m, &cIf_00dv5g5R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_00dv5g5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Ci17fbAH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pkhVKCh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_UMSuTLko_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_VzDCRNwq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_XBWhPb1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cR4d5Uku, HV_BINOP_POW, 0, m, &cBinop_cR4d5Uku_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cR4d5Uku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ELJsCNtT, 0, m, &cIf_ELJsCNtT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ccQmweAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8OK4oBlR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_prlwbinx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pkhVKCh4, 0, m, &cIf_pkhVKCh4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RBs7j02g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lK3b0P0k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lK3b0P0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pkhVKCh4, 1, m, &cIf_pkhVKCh4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VzDCRNwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ccQmweAF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UMSuTLko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ELJsCNtT, 0, m, &cIf_ELJsCNtT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8OK4oBlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cR4d5Uku, HV_BINOP_POW, 1, m, &cBinop_cR4d5Uku_sendMessage);
  cMsg_XBWhPb1L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_ELJsCNtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zOGWBNjt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_ND2X8sEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_00dv5g5R, 1, m, &cIf_00dv5g5R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ci17fbAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uPBG5S7L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrSwzZ85_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bO9lLe18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RBs7j02g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_prlwbinx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vsx4zZ3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ELJsCNtT, 1, m, &cIf_ELJsCNtT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vJonjxMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f2AqsUGL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_f2AqsUGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_zOGWBNjt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lVF9zgWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_bO9lLe18_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uPBG5S7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vJonjxMy, HV_BINOP_EQ, 1, m, &cBinop_vJonjxMy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lrSwzZ85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vsx4zZ3Q, HV_BINOP_GREATER_THAN, 1, m, &cBinop_vsx4zZ3Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k3f3Dwjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vsx4zZ3Q, HV_BINOP_GREATER_THAN, 0, m, &cBinop_vsx4zZ3Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tC3npM8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NLXQvknZ, 0, m, &cVar_NLXQvknZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XT5bRXqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lVF9zgWF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_u12U6Zv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vJonjxMy, HV_BINOP_EQ, 0, m, &cBinop_vJonjxMy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_PsZLMm4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ylb1e3xZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_v1EXOned, 0, m, &cIf_v1EXOned_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_v1EXOned_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nqEQY8Z1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6OGGKHqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_XwrJG0gJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_EmNNqh4S_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_Y51ZYzFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yYy9dqrb, HV_BINOP_POW, 0, m, &cBinop_yYy9dqrb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yYy9dqrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d66M5tMd, 0, m, &cIf_d66M5tMd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O4CKPLIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_JVcTQWaR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jrkba3sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6OGGKHqj, 0, m, &cIf_6OGGKHqj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3azYaUzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nnTTjIJ7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nnTTjIJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6OGGKHqj, 1, m, &cIf_6OGGKHqj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EmNNqh4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_O4CKPLIF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XwrJG0gJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_d66M5tMd, 0, m, &cIf_d66M5tMd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JVcTQWaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yYy9dqrb, HV_BINOP_POW, 1, m, &cBinop_yYy9dqrb_sendMessage);
  cMsg_Y51ZYzFi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_d66M5tMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yA9nxpxh_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xcH5qusN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_ylb1e3xZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v1EXOned, 1, m, &cIf_v1EXOned_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nqEQY8Z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zaJtqhbG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fUitm84X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Buz6lbZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3azYaUzn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jrkba3sO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4y6hNB1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d66M5tMd, 1, m, &cIf_d66M5tMd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_72yZR9mU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xdFtnTQy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xdFtnTQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yA9nxpxh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xcH5qusN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QBI6pLHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Buz6lbZr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zaJtqhbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_72yZR9mU, HV_BINOP_EQ, 1, m, &cBinop_72yZR9mU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fUitm84X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4y6hNB1m, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4y6hNB1m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9a3w71MT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PsZLMm4X, 0, m, &cVar_PsZLMm4X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CLg0UTpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QBI6pLHn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Zz0XYNQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_72yZR9mU, HV_BINOP_EQ, 0, m, &cBinop_72yZR9mU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LFXEPD81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4y6hNB1m, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4y6hNB1m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_FwBC8RLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_I3dzPbDb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_MEJgNYUm, 0, m, &cIf_MEJgNYUm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_MEJgNYUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6adOrsE0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YXspJS9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MhzXX9bT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tYQulzsm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_J7lr0uVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ixGFGhEl, HV_BINOP_POW, 0, m, &cBinop_ixGFGhEl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ixGFGhEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DmyJEJYn, 0, m, &cIf_DmyJEJYn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DXMwRiZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_oZF4B24X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d7oAOYZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aRvRXNpi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fSJq5Sd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YXspJS9M, 0, m, &cIf_YXspJS9M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aRvRXNpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YXspJS9M, 1, m, &cIf_YXspJS9M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tYQulzsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_DXMwRiZb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MhzXX9bT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DmyJEJYn, 0, m, &cIf_DmyJEJYn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oZF4B24X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ixGFGhEl, HV_BINOP_POW, 1, m, &cBinop_ixGFGhEl_sendMessage);
  cMsg_J7lr0uVU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_DmyJEJYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Zq43I8bm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_I3dzPbDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MEJgNYUm, 1, m, &cIf_MEJgNYUm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6adOrsE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UTqb9YpQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vmQPYJmg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OIJiZPsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d7oAOYZQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fSJq5Sd1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K7OX6se3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DmyJEJYn, 1, m, &cIf_DmyJEJYn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_22RYwgsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V0kFyN4A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_V0kFyN4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Zq43I8bm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GXgAWh8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_OIJiZPsR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vmQPYJmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K7OX6se3, HV_BINOP_GREATER_THAN, 1, m, &cBinop_K7OX6se3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UTqb9YpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_22RYwgsB, HV_BINOP_EQ, 1, m, &cBinop_22RYwgsB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fqG633ZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FwBC8RLn, 0, m, &cVar_FwBC8RLn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IHXa4Ia2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_22RYwgsB, HV_BINOP_EQ, 0, m, &cBinop_22RYwgsB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iqrFGaDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K7OX6se3, HV_BINOP_GREATER_THAN, 0, m, &cBinop_K7OX6se3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t8unTe5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GXgAWh8M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_sIZAQJqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VXRymiP4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gvnY34tY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PXaGRUmM, 0, m, &cSlice_PXaGRUmM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xeCCrJiv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_PXaGRUmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_L3g6qVh5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_L3g6qVh5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dr70IFVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_L3g6qVh5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_L3g6qVh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nsCJahlm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xeCCrJiv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gh8jumh0, 0, m, &cSlice_gh8jumh0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Vv6vyaJZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gh8jumh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rTn9jEbt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rTn9jEbt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_K3W9zt7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rTn9jEbt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rTn9jEbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A5xmOXFd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DT0Sks0a_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WSFW5uS7, 0, m, &cSlice_WSFW5uS7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rcbvTLit_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_WSFW5uS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JJBmc49T_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JJBmc49T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TXJraRcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JJBmc49T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_JJBmc49T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GspcLTt2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rcbvTLit_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3uyGP4ga, 0, m, &cSlice_3uyGP4ga_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_3uyGP4ga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FbqfvhoH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FbqfvhoH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_y26mh829_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FbqfvhoH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FbqfvhoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cWJgAdW9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ox4fL8lS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xDMD8vhD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_c5g89nSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FTFeIzTV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gWJ2Akio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q7wo8UDV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zH9z2l24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O9np7GWF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_t6FeJ1uJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SmxhU3Qr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XCiADU4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sGjYBlAA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_sGjYBlAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ZbfarBQ, HV_BINOP_DIVIDE, 1, m, &cBinop_7ZbfarBQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uxKQsPp9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_GlIZADhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_pKSeO5DV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wJvSeIm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_GlIZADhQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pKSeO5DV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ZbfarBQ, HV_BINOP_DIVIDE, 0, m, &cBinop_7ZbfarBQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uxKQsPp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wJvSeIm9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_7ZbfarBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4TD3o4YV, HV_BINOP_MULTIPLY, 1, m, &cBinop_4TD3o4YV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4TD3o4YV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yUg8QVk9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lB0mSfqx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_9Vf8hWdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2UWWfclN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_4E2dMKAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dzzips8l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_30QWAOOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_vzqSSyCa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vzqSSyCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4TD3o4YV, HV_BINOP_MULTIPLY, 0, m, &cBinop_4TD3o4YV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Pxk2um5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_EfrOVm4Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EfrOVm4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EKGiVbHi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_c2Z69g1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n6QEaOJ9, 1, m, &cVar_n6QEaOJ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_n6QEaOJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Eihpg7oM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_utCSaLAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cGwZWRVC, HV_BINOP_MULTIPLY, 1, m, &cBinop_cGwZWRVC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vWryr1jC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_utCSaLAR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zh40WKra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nJvy0lJe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nJvy0lJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F9SEfiHw, HV_BINOP_MULTIPLY, 1, m, &cBinop_F9SEfiHw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dvBl83Z8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vK1IRhnK, HV_BINOP_MULTIPLY, 1, m, &cBinop_vK1IRhnK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xHzmpLSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dvBl83Z8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F1Az9lnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uTpiP1gN, HV_BINOP_MULTIPLY, 1, m, &cBinop_uTpiP1gN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Q2VeGvhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sfnoNJLC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sfnoNJLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GS6LiDOZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_GS6LiDOZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_BSi5Vrwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DNk8lNeZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_30QWAOOv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X2SFXAsX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Kfx5IIdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Pxk2um5I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yUg8QVk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_9Vf8hWdk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lB0mSfqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_4E2dMKAw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_2UWWfclN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OztowSrf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dzzips8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VpNoDRzY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UrFzln0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eAz6sHYR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EKGiVbHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_S3jTXYmU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S3jTXYmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tMpcksBX, HV_BINOP_MULTIPLY, 1, m, &cBinop_tMpcksBX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tMpcksBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7MDDmYAl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7MDDmYAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UrFzln0O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Eihpg7oM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_U3VWR8B7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U3VWR8B7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cJ4yJG9V_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gQBB7cY6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZGGNCRYV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zGTrx3MC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OIhqtmZl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eUMDwctP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cGwZWRVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ox4fL8lS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_F9SEfiHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c5g89nSu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vK1IRhnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gWJ2Akio_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_uTpiP1gN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zH9z2l24_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_GS6LiDOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t6FeJ1uJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cPHdp5VM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Kfx5IIdi, 1, m, &cVar_Kfx5IIdi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NNqLN8dZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BSi5Vrwq, 0, m, &cVar_BSi5Vrwq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OIhqtmZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F9SEfiHw, HV_BINOP_MULTIPLY, 0, m, &cBinop_F9SEfiHw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cJ4yJG9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_ZGGNCRYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uTpiP1gN, HV_BINOP_MULTIPLY, 0, m, &cBinop_uTpiP1gN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eUMDwctP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cGwZWRVC, HV_BINOP_MULTIPLY, 0, m, &cBinop_cGwZWRVC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zGTrx3MC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vK1IRhnK, HV_BINOP_MULTIPLY, 0, m, &cBinop_vK1IRhnK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gQBB7cY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GS6LiDOZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_GS6LiDOZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DNk8lNeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Kfx5IIdi, 0, m, &cVar_Kfx5IIdi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X2SFXAsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n6QEaOJ9, 0, m, &cVar_n6QEaOJ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VnmUEGLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zgdvcgoU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4JJIYUrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7I8IkMkD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZsJOgmWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_luQTH23w, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cwRk9J5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eYofaWbK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bbkSU4BC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TZrf3Psn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_TZrf3Psn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7mDCYIQC, HV_BINOP_DIVIDE, 1, m, &cBinop_7mDCYIQC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u8cpT5tz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_OcHamPpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_cwhsVy2q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K9wTTDK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_OcHamPpT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cwhsVy2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7mDCYIQC, HV_BINOP_DIVIDE, 0, m, &cBinop_7mDCYIQC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u8cpT5tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K9wTTDK3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_7mDCYIQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lTi6qf2S, HV_BINOP_MULTIPLY, 1, m, &cBinop_lTi6qf2S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lTi6qf2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HpNM0fDa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TRwbP3KN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_vX6I47zj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uyLzn0VZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_oDpFUBVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OTxQWgfK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5CWCZVPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_PTkOuKnJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PTkOuKnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lTi6qf2S, HV_BINOP_MULTIPLY, 0, m, &cBinop_lTi6qf2S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KBoPjs1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_tHKfoR9m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tHKfoR9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cPHue3Bj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NLstZpQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_inEP343P, HV_BINOP_MULTIPLY, 1, m, &cBinop_inEP343P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FZsFM2cS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D2Nvrs3a, 1, m, &cVar_D2Nvrs3a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GRMBX5ON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmaF8Dba, HV_BINOP_MULTIPLY, 1, m, &cBinop_wmaF8Dba_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AK2rkAjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VIVnFNDf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VIVnFNDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RYr2QFZ4, HV_BINOP_MULTIPLY, 1, m, &cBinop_RYr2QFZ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_D2Nvrs3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qOKt9XPd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_AAsR2Wlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hwJLT8Jd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_5CWCZVPr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UtPMHLFu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_fHwm3c9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_KBoPjs1I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TRwbP3KN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_oDpFUBVE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HpNM0fDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_vX6I47zj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_uyLzn0VZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iw6Nm7ge_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_OTxQWgfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aNSVOzRm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xjF0nVm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_u0TvZL01_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cPHue3Bj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_n3TQjFvD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n3TQjFvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FnMuoCvZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_FnMuoCvZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FnMuoCvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KdDpj9Pk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KdDpj9Pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xjF0nVm4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qOKt9XPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1WyY2uix_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1WyY2uix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ny7xcqDS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TnRWmJ7I_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dp6Zr7mO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pEPlzzZ3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HmL4B2xD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VnmUEGLY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_inEP343P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4JJIYUrI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wmaF8Dba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZsJOgmWN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_RYr2QFZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cwRk9J5i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_4TPpNHQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AAsR2Wlq, 0, m, &cVar_AAsR2Wlq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dZQgYATO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fHwm3c9n, 1, m, &cVar_fHwm3c9n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UtPMHLFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D2Nvrs3a, 0, m, &cVar_D2Nvrs3a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hwJLT8Jd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fHwm3c9n, 0, m, &cVar_fHwm3c9n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pEPlzzZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmL4B2xD, HV_BINOP_MULTIPLY, 0, m, &cBinop_HmL4B2xD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Dp6Zr7mO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_inEP343P, HV_BINOP_MULTIPLY, 0, m, &cBinop_inEP343P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TnRWmJ7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmaF8Dba, HV_BINOP_MULTIPLY, 0, m, &cBinop_wmaF8Dba_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ny7xcqDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RYr2QFZ4, HV_BINOP_MULTIPLY, 0, m, &cBinop_RYr2QFZ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SCXKOWCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y3CzqMD9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LxzxXwAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3N93t4YC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YehmmXcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PJscdVPl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fDxgaNdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FImyBQ29, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NgVyYnyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_54MqoVpa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aAGUEqaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sbQcPWiy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_sbQcPWiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mv8gVPle, HV_BINOP_DIVIDE, 1, m, &cBinop_mv8gVPle_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HVHQwVcX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_t5kvRirn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_1MLvdqlr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2zY6nd0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_t5kvRirn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1MLvdqlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mv8gVPle, HV_BINOP_DIVIDE, 0, m, &cBinop_mv8gVPle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HVHQwVcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2zY6nd0n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mv8gVPle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4EpPA2zY, HV_BINOP_MULTIPLY, 1, m, &cBinop_4EpPA2zY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4EpPA2zY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OIXZKvhe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iSs7HEkx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_6KDtP8t1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PGILGb1X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_3eNLBTlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KBQJKgos_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HT7Orn2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_0xJuGR4n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0xJuGR4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4EpPA2zY, HV_BINOP_MULTIPLY, 0, m, &cBinop_4EpPA2zY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HIKZtcNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_w5eX23t7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w5eX23t7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VIdLqaAL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_YxyBRNVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_inRegy7y, HV_BINOP_MULTIPLY, 1, m, &cBinop_inRegy7y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NXNQyWV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MjM3PXd9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MjM3PXd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YxyBRNVH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hkoXbOMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FXH1igsM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FXH1igsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qprZGvWp, HV_BINOP_MULTIPLY, 1, m, &cBinop_qprZGvWp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_r4Y2SGc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdYHGKDm, HV_BINOP_MULTIPLY, 1, m, &cBinop_SdYHGKDm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0XqDmUYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SlwZJ2Wn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SlwZJ2Wn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_r4Y2SGc6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IWQhmaHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3Buw6ULn, 1, m, &cVar_3Buw6ULn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_brpxejLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HJBr45nJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_HJBr45nJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FK1iFJGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XkX7mTj1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XkX7mTj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSVifNgm, HV_BINOP_MULTIPLY, 1, m, &cBinop_sSVifNgm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_3Buw6ULn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CeAEEacZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_x1gwRKLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S9h04lW5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_HT7Orn2f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zeuq5lhx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_xKzXKadq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_HIKZtcNO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OIXZKvhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_6KDtP8t1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iSs7HEkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3eNLBTlb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_PGILGb1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Rq9RR5do_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KBQJKgos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ov6V8kqw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WaLEPTHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Sb94ORiU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VIdLqaAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rh7JPVjJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rh7JPVjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_odqridHj, HV_BINOP_MULTIPLY, 1, m, &cBinop_odqridHj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_odqridHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GIjtv3BZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GIjtv3BZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WaLEPTHk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CeAEEacZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fa3gN4q4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fa3gN4q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zpkbYZQN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xGiBepV6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_75xFiObE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KGMkrf4l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7ndnA7n7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SMv2dOyN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_inRegy7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SCXKOWCi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_qprZGvWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LxzxXwAZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_SdYHGKDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YehmmXcd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HJBr45nJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fDxgaNdR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sSVifNgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NgVyYnyv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_yNE7ikCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xKzXKadq, 1, m, &cVar_xKzXKadq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iY2H3Ia0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x1gwRKLx, 0, m, &cVar_x1gwRKLx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SMv2dOyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_inRegy7y, HV_BINOP_MULTIPLY, 0, m, &cBinop_inRegy7y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xGiBepV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSVifNgm, HV_BINOP_MULTIPLY, 0, m, &cBinop_sSVifNgm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_75xFiObE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HJBr45nJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_HJBr45nJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zpkbYZQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_KGMkrf4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdYHGKDm, HV_BINOP_MULTIPLY, 0, m, &cBinop_SdYHGKDm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7ndnA7n7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qprZGvWp, HV_BINOP_MULTIPLY, 0, m, &cBinop_qprZGvWp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S9h04lW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xKzXKadq, 0, m, &cVar_xKzXKadq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zeuq5lhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3Buw6ULn, 0, m, &cVar_3Buw6ULn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WOb3YJ9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sIZAQJqJ, 1, m, &cIf_sIZAQJqJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4qNjCrl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_VXRymiP4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HD5F6p9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4qNjCrl3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kE8Gnhpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sIZAQJqJ, 0, m, &cIf_sIZAQJqJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zOGWBNjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_feTiTrD3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VXRymiP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZzERC1eB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Zq43I8bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VHwSqfq3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xcH5qusN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_kE8Gnhpm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yA9nxpxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WOb3YJ9Q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HD5F6p9g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UWizyAfv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VD1lL5jh, 0, m, &cSlice_VD1lL5jh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZbhCDkWF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_VD1lL5jh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cnV3b7lP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cnV3b7lP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_7OjavuOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cnV3b7lP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_cnV3b7lP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2Jv0htIY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_KtwtQaHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AYwsoyhC_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ERli5Hii, 0, m, &cIf_ERli5Hii_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_ERli5Hii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dzEA4nfC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AHubwXik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_LrIJlHY0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NxEyugA7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_c4St220L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PAY2ztt4, HV_BINOP_POW, 0, m, &cBinop_PAY2ztt4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PAY2ztt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jlCmKqXy, 0, m, &cIf_jlCmKqXy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xieTcXPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_6KVrtSM4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OP64TMsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cJc6hM3d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zrjqBBmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AHubwXik, 0, m, &cIf_AHubwXik_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cJc6hM3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AHubwXik, 1, m, &cIf_AHubwXik_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NxEyugA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_xieTcXPM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LrIJlHY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_jlCmKqXy, 0, m, &cIf_jlCmKqXy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6KVrtSM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PAY2ztt4, HV_BINOP_POW, 1, m, &cBinop_PAY2ztt4_sendMessage);
  cMsg_c4St220L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_jlCmKqXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SBvTmiU7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_AYwsoyhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ERli5Hii, 1, m, &cIf_ERli5Hii_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dzEA4nfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EwecehjW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_swS1y5z1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KV7LzX1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OP64TMsN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zrjqBBmf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D5lXCMn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jlCmKqXy, 1, m, &cIf_jlCmKqXy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_197M2O46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l5esRPsd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_l5esRPsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_SBvTmiU7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lXgbjRMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_KV7LzX1a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_swS1y5z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D5lXCMn7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_D5lXCMn7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EwecehjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_197M2O46, HV_BINOP_EQ, 1, m, &cBinop_197M2O46_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1Wa3CVit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D5lXCMn7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_D5lXCMn7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eiM5f1I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KtwtQaHu, 0, m, &cVar_KtwtQaHu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TiZ9yxj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_197M2O46, HV_BINOP_EQ, 0, m, &cBinop_197M2O46_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bat52ZWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lXgbjRMU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Y5GIoMK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Et5mhFio_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_JPy3Unpb, 0, m, &cIf_JPy3Unpb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_JPy3Unpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_uiOPnhYq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vEGGolJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_IG9Ffed5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_2YJEVq7Q_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_t5ykrHJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uliMo2Ho, HV_BINOP_POW, 0, m, &cBinop_uliMo2Ho_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uliMo2Ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bCVCMST3, 0, m, &cIf_bCVCMST3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9PwZHdsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_cptAdSU2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rAt656Em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vEGGolJz, 0, m, &cIf_vEGGolJz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2BwQhmg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GCWSPzSM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GCWSPzSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vEGGolJz, 1, m, &cIf_vEGGolJz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2YJEVq7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_9PwZHdsd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IG9Ffed5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_bCVCMST3, 0, m, &cIf_bCVCMST3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cptAdSU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uliMo2Ho, HV_BINOP_POW, 1, m, &cBinop_uliMo2Ho_sendMessage);
  cMsg_t5ykrHJM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_bCVCMST3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_695sqNhb_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wuIrcSdX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_Et5mhFio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JPy3Unpb, 1, m, &cIf_JPy3Unpb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uiOPnhYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MO9MEZ7A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VZNuWeve_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Mkjd0m3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2BwQhmg2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rAt656Em_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yr1fsxeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bCVCMST3, 1, m, &cIf_bCVCMST3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aG9E9chf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_34DfIs0w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_34DfIs0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_695sqNhb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wuIrcSdX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g6vcbfiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Mkjd0m3i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VZNuWeve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yr1fsxeD, HV_BINOP_GREATER_THAN, 1, m, &cBinop_yr1fsxeD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MO9MEZ7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aG9E9chf, HV_BINOP_EQ, 1, m, &cBinop_aG9E9chf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Lj94E7AM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aG9E9chf, HV_BINOP_EQ, 0, m, &cBinop_aG9E9chf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_biLyIawD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yr1fsxeD, HV_BINOP_GREATER_THAN, 0, m, &cBinop_yr1fsxeD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GJxXaviY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y5GIoMK3, 0, m, &cVar_Y5GIoMK3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fen38VU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g6vcbfiO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_8Qh0LJoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_d7eenEJF_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Xo12sfi8, 0, m, &cIf_Xo12sfi8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_Xo12sfi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FYcU1TKT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CuI3wd8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_XgDR6607_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_QOjJgrcC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_otFs0NI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8NdMOJpx, HV_BINOP_POW, 0, m, &cBinop_8NdMOJpx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8NdMOJpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qrNoiWo5, 0, m, &cIf_qrNoiWo5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0uAgUJuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_NIxtnRtc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WgbWjUlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_F2NtrTcs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hpYWfrxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CuI3wd8r, 0, m, &cIf_CuI3wd8r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F2NtrTcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CuI3wd8r, 1, m, &cIf_CuI3wd8r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QOjJgrcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_0uAgUJuK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XgDR6607_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_qrNoiWo5, 0, m, &cIf_qrNoiWo5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NIxtnRtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8NdMOJpx, HV_BINOP_POW, 1, m, &cBinop_8NdMOJpx_sendMessage);
  cMsg_otFs0NI5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_qrNoiWo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AxJvtA23_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_d7eenEJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Xo12sfi8, 1, m, &cIf_Xo12sfi8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FYcU1TKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sLJQLf9g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tgV6Jxrf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VAfj33ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WgbWjUlB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hpYWfrxM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N3pBCIVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qrNoiWo5, 1, m, &cIf_qrNoiWo5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9cmnrXqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_du9Dgr7M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_du9Dgr7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_AxJvtA23_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4Sc4ujwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_VAfj33ws_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tgV6Jxrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N3pBCIVK, HV_BINOP_GREATER_THAN, 1, m, &cBinop_N3pBCIVK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sLJQLf9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9cmnrXqf, HV_BINOP_EQ, 1, m, &cBinop_9cmnrXqf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EOH9vYdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9cmnrXqf, HV_BINOP_EQ, 0, m, &cBinop_9cmnrXqf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hJhwstmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Qh0LJoM, 0, m, &cVar_8Qh0LJoM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oewQvNHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N3pBCIVK, HV_BINOP_GREATER_THAN, 0, m, &cBinop_N3pBCIVK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ArpyLJpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Sc4ujwp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_GImybfhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JnMynC1S_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qnmKkh3R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QjHcjMC4, 0, m, &cSlice_QjHcjMC4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_seHLZK4F_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_QjHcjMC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_g00GChK8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_g00GChK8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GVdEzmbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_g00GChK8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_g00GChK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9QNlmUya_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_seHLZK4F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_K35YFhOm, 0, m, &cSlice_K35YFhOm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UWizyAfv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_K35YFhOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_spmX455f_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_spmX455f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_K2v5B417_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_spmX455f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_spmX455f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3MlWxWa4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZbhCDkWF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DgCDxJxl, 0, m, &cSlice_DgCDxJxl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_T6tMIjwx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_DgCDxJxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aNXITP1y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aNXITP1y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_CVVo2uHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aNXITP1y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_aNXITP1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YremC60Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_T6tMIjwx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wgZgvZ6W, 0, m, &cSlice_wgZgvZ6W_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_wgZgvZ6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vY7kmfLU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vY7kmfLU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_tInjQ2wH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vY7kmfLU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_vY7kmfLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Vhh3HKn6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kjl619QN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WfLSYGOo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UXU2uspO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VfgWB3lo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sn0KOEbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0ZmfOL0Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UC4LQlwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8tFqwLvq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_60lysv72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2NSIzL49, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZnpSXRbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fe7NMkTd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_fe7NMkTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P1CHo4TR, HV_BINOP_DIVIDE, 1, m, &cBinop_P1CHo4TR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RdjUWxXY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_vQ580XTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Q119mb8U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SzKJmGvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_vQ580XTD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Q119mb8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P1CHo4TR, HV_BINOP_DIVIDE, 0, m, &cBinop_P1CHo4TR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RdjUWxXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SzKJmGvy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_P1CHo4TR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31pmYoZ2, HV_BINOP_MULTIPLY, 1, m, &cBinop_31pmYoZ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_31pmYoZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XIWZThCl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fGhFtvIX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_oxXlkRIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GnwHoxmC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_NEaWWqJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fa7Vlevp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WQYLklLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_RwuWcEG6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RwuWcEG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31pmYoZ2, HV_BINOP_MULTIPLY, 0, m, &cBinop_31pmYoZ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HIq1VTtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_DYk6oM2c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DYk6oM2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0ofDRKes_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_DaLf53pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2qZ3tsG9, 1, m, &cVar_2qZ3tsG9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_2qZ3tsG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AIoO45uf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ZPWG1woo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dirf9GuL, HV_BINOP_MULTIPLY, 1, m, &cBinop_Dirf9GuL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SYun2YuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZPWG1woo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eZL15lP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Chvo2TkU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Chvo2TkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L2OvDkOY, HV_BINOP_MULTIPLY, 1, m, &cBinop_L2OvDkOY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LTHRAb45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y4XsxyHV, HV_BINOP_MULTIPLY, 1, m, &cBinop_Y4XsxyHV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_quWMb0q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LTHRAb45_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FGd4UtGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cK0NR0UJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_cK0NR0UJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U7vKQWKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FLZ7dylg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FLZ7dylg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3gCgrjdL, HV_BINOP_MULTIPLY, 1, m, &cBinop_3gCgrjdL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_d86Bbco5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sCLQHW5W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_WQYLklLi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yPi4OVu8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_p9n8IB2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_HIq1VTtr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XIWZThCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_oxXlkRIH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fGhFtvIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_NEaWWqJ8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_GnwHoxmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JNk5SXcd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fa7Vlevp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zNspT3NJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_RsHp0EtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mSGWrmIw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0ofDRKes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xBVgn7TO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xBVgn7TO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mn2zqb5D, HV_BINOP_MULTIPLY, 1, m, &cBinop_mn2zqb5D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mn2zqb5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_75QVoVQb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_75QVoVQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RsHp0EtE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AIoO45uf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jjFV2fEh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jjFV2fEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1FPdk1nz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fskCwYSi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ycGp2V18_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OQKHG1XV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dW3zmtVT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n0qIEsqo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Dirf9GuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kjl619QN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_L2OvDkOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UXU2uspO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Y4XsxyHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sn0KOEbU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cK0NR0UJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UC4LQlwE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_3gCgrjdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_60lysv72_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_3OHACB3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d86Bbco5, 0, m, &cVar_d86Bbco5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iPFwcfiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p9n8IB2l, 1, m, &cVar_p9n8IB2l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dW3zmtVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L2OvDkOY, HV_BINOP_MULTIPLY, 0, m, &cBinop_L2OvDkOY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1FPdk1nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_OQKHG1XV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y4XsxyHV, HV_BINOP_MULTIPLY, 0, m, &cBinop_Y4XsxyHV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n0qIEsqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dirf9GuL, HV_BINOP_MULTIPLY, 0, m, &cBinop_Dirf9GuL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ycGp2V18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cK0NR0UJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_cK0NR0UJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fskCwYSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3gCgrjdL, HV_BINOP_MULTIPLY, 0, m, &cBinop_3gCgrjdL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yPi4OVu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2qZ3tsG9, 0, m, &cVar_2qZ3tsG9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sCLQHW5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p9n8IB2l, 0, m, &cVar_p9n8IB2l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o3jqXssi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lWI4tLvw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LKmHJVjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lKGovGtU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Zjr8bbPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0TBwuNQK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IOupavya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jMAC2ho2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hfWDYHs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BWNshYR6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_BWNshYR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ma3IYKsi, HV_BINOP_DIVIDE, 1, m, &cBinop_Ma3IYKsi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iCSDBQnx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_xojlR9Fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_aSIB5ZRv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IWhYBnsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_xojlR9Fy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aSIB5ZRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ma3IYKsi, HV_BINOP_DIVIDE, 0, m, &cBinop_Ma3IYKsi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iCSDBQnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IWhYBnsN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Ma3IYKsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OUL5mGkP, HV_BINOP_MULTIPLY, 1, m, &cBinop_OUL5mGkP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OUL5mGkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YGKg7vfq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nG7KxTOc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_xcHF6iQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CKWY63jy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_6LM0AZ2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sMEdfdyN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MVTev6pi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_O3tk12nI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O3tk12nI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OUL5mGkP, HV_BINOP_MULTIPLY, 0, m, &cBinop_OUL5mGkP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AgPb7Df7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Fci6ATsu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Fci6ATsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hxFJ4oGG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_VReXuA6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JLUogoeX, HV_BINOP_MULTIPLY, 1, m, &cBinop_JLUogoeX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gXD1R2Qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xWAkv9VF, 1, m, &cVar_xWAkv9VF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_puQ6fv8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cGjFklXG, HV_BINOP_MULTIPLY, 1, m, &cBinop_cGjFklXG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IsAQwkQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6PbNddQR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6PbNddQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W2RGATYJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_W2RGATYJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_xWAkv9VF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lYIN2Acp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_PWc7WF6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oD8M4N5n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_MVTev6pi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Bgb5cOw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_oXhyAnSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_AgPb7Df7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nG7KxTOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_6LM0AZ2A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YGKg7vfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_xcHF6iQy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_CKWY63jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_neP48Fjp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sMEdfdyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PNsVL5qT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_f7uLPnIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VSfdfk24_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hxFJ4oGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ee4trs1s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ee4trs1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2cIOP5iF, HV_BINOP_MULTIPLY, 1, m, &cBinop_2cIOP5iF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2cIOP5iF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_biDEV4py_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_biDEV4py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f7uLPnIS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lYIN2Acp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PcJ7TuRy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PcJ7TuRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XkyOoC8q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hbh89fVN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z4vfpVdK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dh3hkqp1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tuNxYYfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o3jqXssi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_JLUogoeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LKmHJVjg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cGjFklXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zjr8bbPm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_W2RGATYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IOupavya_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_qlCq9Gkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oXhyAnSb, 1, m, &cVar_oXhyAnSb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6Htu2avY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PWc7WF6r, 0, m, &cVar_PWc7WF6r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0Bgb5cOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xWAkv9VF, 0, m, &cVar_xWAkv9VF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oD8M4N5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oXhyAnSb, 0, m, &cVar_oXhyAnSb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Dh3hkqp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tuNxYYfO, HV_BINOP_MULTIPLY, 0, m, &cBinop_tuNxYYfO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z4vfpVdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JLUogoeX, HV_BINOP_MULTIPLY, 0, m, &cBinop_JLUogoeX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Hbh89fVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cGjFklXG, HV_BINOP_MULTIPLY, 0, m, &cBinop_cGjFklXG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XkyOoC8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W2RGATYJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_W2RGATYJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Kpex5Mbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iSW7F5Yh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1BOHnQAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qxh0HVK6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mfydq7Lq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rkpXL11R, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_E20DSphZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vV7SAMrq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_g6cyXyIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a6autZ0S, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3XNJvMrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S0czcNVj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_S0czcNVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sik3mTwm, HV_BINOP_DIVIDE, 1, m, &cBinop_sik3mTwm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zHkEbzBg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_nSKcEUGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_xYa8AMNg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IYxkkUJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_nSKcEUGn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xYa8AMNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sik3mTwm, HV_BINOP_DIVIDE, 0, m, &cBinop_sik3mTwm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zHkEbzBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IYxkkUJb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sik3mTwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T8tjtTHY, HV_BINOP_MULTIPLY, 1, m, &cBinop_T8tjtTHY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T8tjtTHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k1uvLhSe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oaOgOVGf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_Ixi1BGUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MzakUEEX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_pksVKkQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p1PKWENS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_TJuEBnGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_UQ8CEQFy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UQ8CEQFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T8tjtTHY, HV_BINOP_MULTIPLY, 0, m, &cBinop_T8tjtTHY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_buFfuGgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_CoqT6vFT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CoqT6vFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1UUK8u5b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EIzTn9Ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UgAK87Sv, HV_BINOP_MULTIPLY, 1, m, &cBinop_UgAK87Sv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZWhrC7tM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Y2R3814W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Y2R3814W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EIzTn9Ki_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tT47ezQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vqIQjESa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vqIQjESa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UzTMQsGt, HV_BINOP_MULTIPLY, 1, m, &cBinop_UzTMQsGt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zo7Zp90r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EBUsir6W, HV_BINOP_MULTIPLY, 1, m, &cBinop_EBUsir6W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mXOxWKgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CNanAZdQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CNanAZdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zo7Zp90r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c0Sq7UeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dlBFsnr1, 1, m, &cVar_dlBFsnr1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JwpjODKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DaHQ0cEF, HV_BINOP_MULTIPLY, 1, m, &cBinop_DaHQ0cEF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P92aXplJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_D5XJrYrK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D5XJrYrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NIGF21M1, HV_BINOP_MULTIPLY, 1, m, &cBinop_NIGF21M1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_dlBFsnr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xyI2bMKo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ovZIAexZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f6YiD9xD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_TJuEBnGb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IjlYLnls_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_gyWI0Gn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_buFfuGgL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k1uvLhSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Ixi1BGUk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oaOgOVGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_pksVKkQO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_MzakUEEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cNtbUQ89_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_p1PKWENS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_miNxZ5cN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_L2oYmPWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iT5xYoJj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1UUK8u5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Z2bWK03x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z2bWK03x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zhngUmQ0, HV_BINOP_MULTIPLY, 1, m, &cBinop_zhngUmQ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zhngUmQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Yza6gnde_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Yza6gnde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_L2oYmPWG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xyI2bMKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_51Q6X85b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_51Q6X85b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jxcesdtx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bmxadcI7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Za7Tk1Iv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dAGMnZ49_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gvzIUypG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LP2cY8X2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UgAK87Sv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kpex5Mbk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_UzTMQsGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1BOHnQAj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EBUsir6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mfydq7Lq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_DaHQ0cEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E20DSphZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NIGF21M1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g6cyXyIr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_4icc0OjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ovZIAexZ, 0, m, &cVar_ovZIAexZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oh84rWmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gyWI0Gn6, 1, m, &cVar_gyWI0Gn6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bmxadcI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NIGF21M1, HV_BINOP_MULTIPLY, 0, m, &cBinop_NIGF21M1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gvzIUypG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UzTMQsGt, HV_BINOP_MULTIPLY, 0, m, &cBinop_UzTMQsGt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LP2cY8X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UgAK87Sv, HV_BINOP_MULTIPLY, 0, m, &cBinop_UgAK87Sv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Za7Tk1Iv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DaHQ0cEF, HV_BINOP_MULTIPLY, 0, m, &cBinop_DaHQ0cEF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dAGMnZ49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EBUsir6W, HV_BINOP_MULTIPLY, 0, m, &cBinop_EBUsir6W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Jxcesdtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_IjlYLnls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dlBFsnr1, 0, m, &cVar_dlBFsnr1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f6YiD9xD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gyWI0Gn6, 0, m, &cVar_gyWI0Gn6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ra8u09ju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GImybfhk, 1, m, &cIf_GImybfhk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Rv41lxAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_JnMynC1S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_TNZhFlHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rv41lxAL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cPcTsT1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GImybfhk, 0, m, &cIf_GImybfhk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SBvTmiU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_buaPGSLL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JnMynC1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9yEHmtNA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AxJvtA23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tOYnzf5b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_695sqNhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ra8u09ju_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TNZhFlHt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wuIrcSdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_cPcTsT1E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_P4QQETPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TXX0EwU2, HV_BINOP_DIVIDE, 0, m, &cBinop_TXX0EwU2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_FDEigvhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2l8gP9Be, HV_BINOP_DIVIDE, 1, m, &cBinop_2l8gP9Be_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TXX0EwU2, HV_BINOP_DIVIDE, 1, m, &cBinop_TXX0EwU2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ufN4WCFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gg6MI6Jr, HV_BINOP_DIVIDE, 0, m, &cBinop_gg6MI6Jr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_c150c27X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gg6MI6Jr, HV_BINOP_DIVIDE, 1, m, &cBinop_gg6MI6Jr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KyCBJXUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2l8gP9Be, HV_BINOP_DIVIDE, 0, m, &cBinop_2l8gP9Be_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GhOLGdPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FDEigvhf, 0, m, &cVar_FDEigvhf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YkHIq0aP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P4QQETPM, 0, m, &cVar_P4QQETPM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2l8gP9Be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ufN4WCFV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TXX0EwU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_c150c27X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gg6MI6Jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ZjUKIvdM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_SjnxJJxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_txhpmNSZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VaNgY1mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_1Nace66u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZjUKIvdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VaNgY1mz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1Nace66u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_SjnxJJxK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_txhpmNSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jS3fWsnG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4jLA8MQ9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DwdHSFeZ, 0, m, &cSlice_DwdHSFeZ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_DwdHSFeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KOltjc5m_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KOltjc5m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_iFvY22vC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KOltjc5m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KOltjc5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8jNB3X2P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0L88qP6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1zxJUGPx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1zxJUGPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_e3yUwvrT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e3yUwvrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BmolqcTu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BmolqcTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qa9pTsb0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LNdiXG4r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LNdiXG4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z9kC9EYW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Qa9pTsb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7GjbyfRr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7GjbyfRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bfsHacoP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z9kC9EYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qVQXM3be_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qVQXM3be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ngOpMbc2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bfsHacoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E00eMIEI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ngOpMbc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rFURwSAU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_E00eMIEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1goSm9Zr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rFURwSAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AO2rZ4n4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_ZNDIRAE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Ltqn8p1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_2OBnviHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XMyiz8pq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vVfbYcSy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bn4OeuBJ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AldaLpPn_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KnS5P4Lk_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rNxJNCVW_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u72iHqA0_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DHDYQ8Gf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_Bn4OeuBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n8lrjqED_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_AldaLpPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DswslUtp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_KnS5P4Lk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i1Ez4pMY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_rNxJNCVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YBJ0n6NH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_u72iHqA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vDQSfWZg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_DHDYQ8Gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F8GMiNJX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_u0rpWKLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rZ7JUolN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RWfcuzpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5g5PkXNA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JObHqww4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fSTv7bbv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fSTv7bbv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xyp5WyfG, 1, m, &cDelay_xyp5WyfG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MlQmzxzO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xyp5WyfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xyp5WyfG, m);
  cIf_onMessage(_c, &Context(_c)->cIf_u0rpWKLS, 0, m, &cIf_u0rpWKLS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fSTv7bbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xyp5WyfG, 0, m, &cDelay_xyp5WyfG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MlQmzxzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xyp5WyfG, 0, m, &cDelay_xyp5WyfG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wUQ9dcxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aEXFpD3K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EYOyNlly_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ec9sljVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BBKqHoFL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FozVbkYO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FozVbkYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JObHqww4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BBKqHoFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_u0rpWKLS, 1, m, &cIf_u0rpWKLS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EYOyNlly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RWfcuzpu, 0, m, &cIf_RWfcuzpu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aEXFpD3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RWfcuzpu, 1, m, &cIf_RWfcuzpu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5g5PkXNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QikgEvqi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rZ7JUolN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QikgEvqi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_eIok8QB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dj3AN9gT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ayukdHlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_D5M8vYm6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_c1BHZopk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qrBkbu1M_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qrBkbu1M_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_02IKhrf1, 1, m, &cDelay_02IKhrf1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aEwqcAmZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_02IKhrf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_02IKhrf1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_eIok8QB8, 0, m, &cIf_eIok8QB8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qrBkbu1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_02IKhrf1, 0, m, &cDelay_02IKhrf1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aEwqcAmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_02IKhrf1, 0, m, &cDelay_02IKhrf1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CGLvWhpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JWekcGls_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jzw8onEv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bZhWUbu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I5Jhf7cM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l05Nv3mb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I5Jhf7cM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eIok8QB8, 1, m, &cIf_eIok8QB8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l05Nv3mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_c1BHZopk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jzw8onEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ayukdHlK, 0, m, &cIf_ayukdHlK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JWekcGls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ayukdHlK, 1, m, &cIf_ayukdHlK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_D5M8vYm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QMTMDGYj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dj3AN9gT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QMTMDGYj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gv69z5QO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b1gdQ6Eh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_PU1xLnVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3slftRw8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2Mem7M5U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JPGN1Xal_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JPGN1Xal_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4vSfFl6b, 1, m, &cDelay_4vSfFl6b_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1M94ijG2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4vSfFl6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4vSfFl6b, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gv69z5QO, 0, m, &cIf_gv69z5QO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JPGN1Xal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4vSfFl6b, 0, m, &cDelay_4vSfFl6b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1M94ijG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4vSfFl6b, 0, m, &cDelay_4vSfFl6b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uaPoDnYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hnKJuIMI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xxpLpUJy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OuxzATHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cEog63r0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ULxz16II_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ULxz16II_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2Mem7M5U_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cEog63r0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gv69z5QO, 1, m, &cIf_gv69z5QO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xxpLpUJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PU1xLnVD, 0, m, &cIf_PU1xLnVD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hnKJuIMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PU1xLnVD, 1, m, &cIf_PU1xLnVD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3slftRw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2T5rapD5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_b1gdQ6Eh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2T5rapD5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ULpl7Y9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0Wa60LPi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pgVUVjty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dN1Le01I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_t5G0gX3W_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OkukGFXf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OkukGFXf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RIHv0xdj, 1, m, &cDelay_RIHv0xdj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fmq5lLfD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RIHv0xdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RIHv0xdj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ULpl7Y9k, 0, m, &cIf_ULpl7Y9k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OkukGFXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RIHv0xdj, 0, m, &cDelay_RIHv0xdj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fmq5lLfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RIHv0xdj, 0, m, &cDelay_RIHv0xdj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NwAthggu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_24kRUFW9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vovXTBpn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KpBHBgY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sgWgrfz4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1DAmesaF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1DAmesaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_t5G0gX3W_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sgWgrfz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ULpl7Y9k, 1, m, &cIf_ULpl7Y9k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vovXTBpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pgVUVjty, 0, m, &cIf_pgVUVjty_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_24kRUFW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pgVUVjty, 1, m, &cIf_pgVUVjty_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dN1Le01I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hKLy1OZR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0Wa60LPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hKLy1OZR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_85Kn7t69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uER0MrN3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0UTsNOrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Vkhwd0bD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lFuopO5V_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TXAbKil3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TXAbKil3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0xVvjJc2, 1, m, &cDelay_0xVvjJc2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mDOLLNPP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0xVvjJc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0xVvjJc2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_85Kn7t69, 0, m, &cIf_85Kn7t69_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TXAbKil3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0xVvjJc2, 0, m, &cDelay_0xVvjJc2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mDOLLNPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0xVvjJc2, 0, m, &cDelay_0xVvjJc2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lUQOzmEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gmsooGES_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_28jF7XlQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ULe3HeG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pQEoPr3D_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hY4Ei6RZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pQEoPr3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_85Kn7t69, 1, m, &cIf_85Kn7t69_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hY4Ei6RZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lFuopO5V_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_28jF7XlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0UTsNOrt, 0, m, &cIf_0UTsNOrt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gmsooGES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0UTsNOrt, 1, m, &cIf_0UTsNOrt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vkhwd0bD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YMDuPPsn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uER0MrN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YMDuPPsn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BQCCpwnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AM7G8qko_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xPuChVNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EWgcGFxB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_H3LG4Wrj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_czVwrBNy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_czVwrBNy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QzhFzzHi, 1, m, &cDelay_QzhFzzHi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D5BpRrN1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_QzhFzzHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QzhFzzHi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BQCCpwnD, 0, m, &cIf_BQCCpwnD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_czVwrBNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QzhFzzHi, 0, m, &cDelay_QzhFzzHi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D5BpRrN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QzhFzzHi, 0, m, &cDelay_QzhFzzHi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4VGJUqQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yso3mGmy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lh2vM7KZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BcdNNYRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HrYUkCNk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_18Y6EcsE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_18Y6EcsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_H3LG4Wrj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HrYUkCNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BQCCpwnD, 1, m, &cIf_BQCCpwnD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Yso3mGmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xPuChVNi, 1, m, &cIf_xPuChVNi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lh2vM7KZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xPuChVNi, 0, m, &cIf_xPuChVNi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EWgcGFxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QcWROYeo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AM7G8qko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QcWROYeo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jvDsCO9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uTVTq4Ba_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8VvRW0Mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TdOeK8Qb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZIQPqR8W_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oolluGF4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oolluGF4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_85aXoZtW, 1, m, &cDelay_85aXoZtW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qTmmKVvf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_85aXoZtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_85aXoZtW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jvDsCO9W, 0, m, &cIf_jvDsCO9W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oolluGF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_85aXoZtW, 0, m, &cDelay_85aXoZtW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qTmmKVvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_85aXoZtW, 0, m, &cDelay_85aXoZtW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rFoyfs6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qjbNFNTL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XPhklYVN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KJz2PwX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tVl84v1Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iVx4UWBa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iVx4UWBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZIQPqR8W_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_tVl84v1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jvDsCO9W, 1, m, &cIf_jvDsCO9W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qjbNFNTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8VvRW0Mn, 1, m, &cIf_8VvRW0Mn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XPhklYVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8VvRW0Mn, 0, m, &cIf_8VvRW0Mn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TdOeK8Qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KMXBEv8k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uTVTq4Ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KMXBEv8k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_TRbYJjvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VM6srVUr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Jp3RT3Tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sgCOjA8u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_m0Tfg6vv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DLfN5YlJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DLfN5YlJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jpxD57ec, 1, m, &cDelay_jpxD57ec_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rIfBSsCd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jpxD57ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jpxD57ec, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TRbYJjvI, 0, m, &cIf_TRbYJjvI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DLfN5YlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jpxD57ec, 0, m, &cDelay_jpxD57ec_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rIfBSsCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jpxD57ec, 0, m, &cDelay_jpxD57ec_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GVOlfKFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fCVeMJGk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WKdzAMdo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EXPukJsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_87v4cQPk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uIkYFj9A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_87v4cQPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TRbYJjvI, 1, m, &cIf_TRbYJjvI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uIkYFj9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_m0Tfg6vv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fCVeMJGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jp3RT3Tz, 1, m, &cIf_Jp3RT3Tz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WKdzAMdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jp3RT3Tz, 0, m, &cIf_Jp3RT3Tz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sgCOjA8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rqr7pDMe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VM6srVUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rqr7pDMe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aLEdvuPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DNWfU0GH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_aolZuLyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MxO2IYE2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7WU2eQY1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AI8MLfNZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AI8MLfNZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bRSyopr6, 1, m, &cDelay_bRSyopr6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zqEpV2hY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_bRSyopr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bRSyopr6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aLEdvuPg, 0, m, &cIf_aLEdvuPg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AI8MLfNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bRSyopr6, 0, m, &cDelay_bRSyopr6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zqEpV2hY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bRSyopr6, 0, m, &cDelay_bRSyopr6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VSUbwAUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TsuJ36Nx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zb5iXtPT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k3wC6hgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ji2e0mYb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p6dGwEt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0p6dGwEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7WU2eQY1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ji2e0mYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aLEdvuPg, 1, m, &cIf_aLEdvuPg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Zb5iXtPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aolZuLyp, 0, m, &cIf_aolZuLyp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TsuJ36Nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aolZuLyp, 1, m, &cIf_aolZuLyp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MxO2IYE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3YTudQSD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DNWfU0GH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3YTudQSD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BR3VwFbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qhvO90Ly_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_G1azr9m2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bM2rUdEC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dsRMH3KT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9LtVmQAs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9LtVmQAs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZX14O3un, 1, m, &cDelay_ZX14O3un_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ckqaO7RP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZX14O3un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZX14O3un, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BR3VwFbi, 0, m, &cIf_BR3VwFbi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9LtVmQAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZX14O3un, 0, m, &cDelay_ZX14O3un_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ckqaO7RP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZX14O3un, 0, m, &cDelay_ZX14O3un_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tV15dfa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nc5nkCHs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZgRGO6qm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9iS9fPOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8OvK2Axq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ow1GlbTP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8OvK2Axq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BR3VwFbi, 1, m, &cIf_BR3VwFbi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ow1GlbTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dsRMH3KT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZgRGO6qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G1azr9m2, 0, m, &cIf_G1azr9m2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nc5nkCHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G1azr9m2, 1, m, &cIf_G1azr9m2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bM2rUdEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4FkqoEdr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qhvO90Ly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4FkqoEdr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RGTRJsVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UIXKeulH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Fs7RzbAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_T7eBCcOq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9brHKhal_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CDivtyiX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CDivtyiX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KOBFAl2F, 1, m, &cDelay_KOBFAl2F_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xtg0qU81_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KOBFAl2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KOBFAl2F, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RGTRJsVp, 0, m, &cIf_RGTRJsVp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CDivtyiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KOBFAl2F, 0, m, &cDelay_KOBFAl2F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Xtg0qU81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KOBFAl2F, 0, m, &cDelay_KOBFAl2F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1gycdc2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ydcMV55n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4eE4OJd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X2dEA6Ir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LagPgl5t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xn1yc2Di_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xn1yc2Di_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9brHKhal_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LagPgl5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RGTRJsVp, 1, m, &cIf_RGTRJsVp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ydcMV55n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fs7RzbAO, 1, m, &cIf_Fs7RzbAO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v4eE4OJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fs7RzbAO, 0, m, &cIf_Fs7RzbAO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T7eBCcOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dUaqa5FB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UIXKeulH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dUaqa5FB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VocLS6tU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZmWjyrH8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dBGMHqnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_H6Oi6zYj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AnDlzy7w_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0q1YM0yS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0q1YM0yS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ahyMCF1x, 1, m, &cDelay_ahyMCF1x_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GYDXq4Cq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ahyMCF1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ahyMCF1x, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VocLS6tU, 0, m, &cIf_VocLS6tU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0q1YM0yS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ahyMCF1x, 0, m, &cDelay_ahyMCF1x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GYDXq4Cq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ahyMCF1x, 0, m, &cDelay_ahyMCF1x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QoOPtBcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AB4r68t7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XAdch0Hj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dPqU1Bra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XJg9yluV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SRoFjcMX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SRoFjcMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AnDlzy7w_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XJg9yluV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VocLS6tU, 1, m, &cIf_VocLS6tU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XAdch0Hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dBGMHqnZ, 0, m, &cIf_dBGMHqnZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AB4r68t7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dBGMHqnZ, 1, m, &cIf_dBGMHqnZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H6Oi6zYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AB1tZY1X, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZmWjyrH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AB1tZY1X, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_n8lrjqED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_RgLRnQfI_sendMessage(_c, 0, m);
  cMsg_0GbKgMLO_sendMessage(_c, 0, m);
  cMsg_z14hYbFW_sendMessage(_c, 0, m);
  cMsg_mTpuAu82_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DswslUtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_RgLRnQfI_sendMessage(_c, 0, m);
  cMsg_LYBFEtQ3_sendMessage(_c, 0, m);
  cMsg_w5hjQ34X_sendMessage(_c, 0, m);
  cMsg_O0A8T28i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_i1Ez4pMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_DzpvylN1_sendMessage(_c, 0, m);
  cMsg_LYBFEtQ3_sendMessage(_c, 0, m);
  cMsg_mTpuAu82_sendMessage(_c, 0, m);
  cMsg_clsvh2yF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YBJ0n6NH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_DzpvylN1_sendMessage(_c, 0, m);
  cMsg_Wxx3Uk1P_sendMessage(_c, 0, m);
  cMsg_z14hYbFW_sendMessage(_c, 0, m);
  cMsg_BivgWYfN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vDQSfWZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_wtuHQOQ7_sendMessage(_c, 0, m);
  cMsg_O0A8T28i_sendMessage(_c, 0, m);
  cMsg_orUhDTc4_sendMessage(_c, 0, m);
  cMsg_z14hYbFW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_F8GMiNJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_wtuHQOQ7_sendMessage(_c, 0, m);
  cMsg_BivgWYfN_sendMessage(_c, 0, m);
  cMsg_LYBFEtQ3_sendMessage(_c, 0, m);
  cMsg_G8w6vT2r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_I0yLGNOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ec9sljVt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wUQ9dcxo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DP9PLMOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ec9sljVt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wUQ9dcxo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WYzwleY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bZhWUbu2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CGLvWhpR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_prAupTm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bZhWUbu2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CGLvWhpR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2S3ZdtEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OuxzATHC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uaPoDnYj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xFkP05ZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OuxzATHC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uaPoDnYj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RgLRnQfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_I0yLGNOo_sendMessage(_c, 0, m);
  cMsg_prAupTm9_sendMessage(_c, 0, m);
  cMsg_xFkP05ZS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DzpvylN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_DP9PLMOm_sendMessage(_c, 0, m);
  cMsg_WYzwleY8_sendMessage(_c, 0, m);
  cMsg_xFkP05ZS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wtuHQOQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_DP9PLMOm_sendMessage(_c, 0, m);
  cMsg_prAupTm9_sendMessage(_c, 0, m);
  cMsg_2S3ZdtEA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aV7AUYR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KpBHBgY9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NwAthggu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RZ7tjkfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KpBHBgY9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NwAthggu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3yCSm7y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ULe3HeG4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lUQOzmEg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7yKmb5va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ULe3HeG4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lUQOzmEg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pVFZbMwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BcdNNYRo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4VGJUqQh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xIdRuIYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BcdNNYRo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4VGJUqQh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LYBFEtQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_RZ7tjkfM_sendMessage(_c, 0, m);
  cMsg_7yKmb5va_sendMessage(_c, 0, m);
  cMsg_xIdRuIYw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0GbKgMLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_RZ7tjkfM_sendMessage(_c, 0, m);
  cMsg_3yCSm7y6_sendMessage(_c, 0, m);
  cMsg_pVFZbMwP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Wxx3Uk1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_aV7AUYR6_sendMessage(_c, 0, m);
  cMsg_7yKmb5va_sendMessage(_c, 0, m);
  cMsg_pVFZbMwP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v4ORu10U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9iS9fPOl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tV15dfa4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MsSE6rF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9iS9fPOl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tV15dfa4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KNtrG409_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_X2dEA6Ir_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1gycdc2t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fLQlyhHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_X2dEA6Ir_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1gycdc2t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HzwdJtca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dPqU1Bra_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QoOPtBcI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6IsqryfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dPqU1Bra_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QoOPtBcI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BivgWYfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_v4ORu10U_sendMessage(_c, 0, m);
  cMsg_fLQlyhHS_sendMessage(_c, 0, m);
  cMsg_6IsqryfT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_O0A8T28i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_MsSE6rF1_sendMessage(_c, 0, m);
  cMsg_KNtrG409_sendMessage(_c, 0, m);
  cMsg_6IsqryfT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mTpuAu82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_MsSE6rF1_sendMessage(_c, 0, m);
  cMsg_fLQlyhHS_sendMessage(_c, 0, m);
  cMsg_HzwdJtca_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Gm9FWqcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KJz2PwX3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rFoyfs6o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SFvu5QPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KJz2PwX3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rFoyfs6o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6sCivLfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EXPukJsu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GVOlfKFA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gZ47LbAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EXPukJsu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GVOlfKFA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fwWRxxa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k3wC6hgI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VSUbwAUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5G4iQrLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k3wC6hgI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VSUbwAUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z14hYbFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_SFvu5QPp_sendMessage(_c, 0, m);
  cMsg_gZ47LbAw_sendMessage(_c, 0, m);
  cMsg_5G4iQrLp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_w5hjQ34X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_SFvu5QPp_sendMessage(_c, 0, m);
  cMsg_6sCivLfa_sendMessage(_c, 0, m);
  cMsg_fwWRxxa4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_G8w6vT2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Gm9FWqcL_sendMessage(_c, 0, m);
  cMsg_6sCivLfa_sendMessage(_c, 0, m);
  cMsg_5G4iQrLp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_orUhDTc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_aV7AUYR6_sendMessage(_c, 0, m);
  cMsg_3yCSm7y6_sendMessage(_c, 0, m);
  cMsg_xIdRuIYw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_clsvh2yF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Gm9FWqcL_sendMessage(_c, 0, m);
  cMsg_gZ47LbAw_sendMessage(_c, 0, m);
  cMsg_fwWRxxa4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_DixvPjcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DKer0Lc6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2tOykZWA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NpXJStps, 0, m, &cSlice_NpXJStps_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2wEKWrAx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_NpXJStps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sMuaaNkU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sMuaaNkU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YBpAip5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sMuaaNkU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sMuaaNkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OYc7cwAy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SSdFB1BG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ak7Tb1jY, 0, m, &cSlice_ak7Tb1jY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lZYUojCL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ak7Tb1jY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lG2rn5nR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lG2rn5nR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lV5Ne8ER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lG2rn5nR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lG2rn5nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZCiAnUmF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lZYUojCL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DqFI8Qs2, 0, m, &cSlice_DqFI8Qs2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2tOykZWA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_DqFI8Qs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HNnpgeuT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HNnpgeuT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_EQXW3SnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HNnpgeuT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_HNnpgeuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kve5jjKS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2wEKWrAx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qGgeFMkP, 0, m, &cSlice_qGgeFMkP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NwsSt8c5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_qGgeFMkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_p5xIe3Vv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_p5xIe3Vv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dHWJMhJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p5xIe3Vv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_p5xIe3Vv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PmRwMPuH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NwsSt8c5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_COoTDqAP, 0, m, &cSlice_COoTDqAP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UD9ub6nB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_COoTDqAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pQjz2mJ2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pQjz2mJ2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qPoYbhpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pQjz2mJ2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pQjz2mJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XBiuyqrV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0LsgYl7p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zlD77cy7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zlD77cy7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_D4mgjkpY, 1, m, &cDelay_D4mgjkpY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7W5FKNfq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_D4mgjkpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D4mgjkpY, m);
  cMsg_Xr7aLI9C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zlD77cy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_D4mgjkpY, 0, m, &cDelay_D4mgjkpY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7W5FKNfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D4mgjkpY, 0, m, &cDelay_D4mgjkpY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_dzFojlpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kwZX8AgV, HV_BINOP_SUBTRACT, 0, m, &cBinop_kwZX8AgV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_HK5q0eaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ChLF2hU7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_57zDrK85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ChLF2hU7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_8I2AavaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dzFojlpg, 0, m, &cVar_dzFojlpg_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_k8RewRdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dNYuiXHq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bJn9S7oV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IntR8O4C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kwZX8AgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q7yHwJkp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_q7yHwJkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NwooAnxf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NwooAnxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_1DYo8YmM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U5FXqT8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_as0T3XwP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OhNvU0Bi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OhNvU0Bi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_frClFMqO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_as0T3XwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HK5q0eaI, 1, m, &cIf_HK5q0eaI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sFLpJnH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_57zDrK85, 1, m, &cIf_57zDrK85_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_frClFMqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HK5q0eaI, 0, m, &cIf_HK5q0eaI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1DYo8YmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_57zDrK85, 0, m, &cIf_57zDrK85_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IntR8O4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dzFojlpg, 0, m, &cVar_dzFojlpg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dNYuiXHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_bJn9S7oV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kwZX8AgV, HV_BINOP_SUBTRACT, 1, m, &cBinop_kwZX8AgV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ChLF2hU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lpXITf1q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UD9ub6nB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9C77ymWA, 0, m, &cSlice_9C77ymWA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9C77ymWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bNuBMhqI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bNuBMhqI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_QTOObYbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bNuBMhqI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_bNuBMhqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_64W6h1ei_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8Ltqn8p1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EKuCotir, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XMyiz8pq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jsOCqsb9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_EGQhq14q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2OBnviHc, 0, m, &cVar_2OBnviHc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DKer0Lc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zYIxGrEX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VX339EIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0LsgYl7p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WpnHuwWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aKZLEtFV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Xr7aLI9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rw2R5x0S, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aKZLEtFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rw2R5x0S, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cZepppfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_jGT4vGbg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jGT4vGbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ApYyIqQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3ApYyIqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zKhmL0eq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_edsmT7Vv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_igmssNc1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_agHobrHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3Fp9hDvi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_otcHmjaY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vWx50IRc_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oTIwg8sH_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hyhBKssH_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eyN8Kj5q_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qK1AZ8KD_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y648ABbC_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_vWx50IRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D1KaHqYL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_oTIwg8sH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mspzcpbL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_hyhBKssH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mFRk6pSW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_eyN8Kj5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ydw8hJRQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_qK1AZ8KD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Js5s06AT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_y648ABbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UyRTjhHN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_JgmLdlVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zqwZGwhg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XA031AKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_l9On8Knx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jVhh3WxO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BbszUHcC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BbszUHcC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hNZEQge1, 1, m, &cDelay_hNZEQge1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qeLc37hK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hNZEQge1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hNZEQge1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JgmLdlVR, 0, m, &cIf_JgmLdlVR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BbszUHcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hNZEQge1, 0, m, &cDelay_hNZEQge1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qeLc37hK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hNZEQge1, 0, m, &cDelay_hNZEQge1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eDx5owjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pVy48mvf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fuKz4cZ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ufSSWu4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uCrBhtHT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HivpLyJ8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HivpLyJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jVhh3WxO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uCrBhtHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JgmLdlVR, 1, m, &cIf_JgmLdlVR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pVy48mvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XA031AKA, 1, m, &cIf_XA031AKA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fuKz4cZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XA031AKA, 0, m, &cIf_XA031AKA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l9On8Knx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lY4aP3aS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zqwZGwhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lY4aP3aS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_w7yppu30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rlvA0JjN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_elQBPX8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_d8KNpXhz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OWWaIWlR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PvOUoWvx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PvOUoWvx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SOxxvD2A, 1, m, &cDelay_SOxxvD2A_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m2tK90mC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SOxxvD2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SOxxvD2A, m);
  cIf_onMessage(_c, &Context(_c)->cIf_w7yppu30, 0, m, &cIf_w7yppu30_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PvOUoWvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SOxxvD2A, 0, m, &cDelay_SOxxvD2A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_m2tK90mC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SOxxvD2A, 0, m, &cDelay_SOxxvD2A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GV6YpeE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8tIOBxm9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QWbM3ceA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tBTogqVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kSWjdCVz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p7Cdk3Vc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p7Cdk3Vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OWWaIWlR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kSWjdCVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w7yppu30, 1, m, &cIf_w7yppu30_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8tIOBxm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_elQBPX8n, 1, m, &cIf_elQBPX8n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QWbM3ceA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_elQBPX8n, 0, m, &cIf_elQBPX8n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d8KNpXhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OITM22Uh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rlvA0JjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OITM22Uh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_kPCZAG3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZPsQWiz0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JC63vDN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZhOHZf08_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rhi6gf5P_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bCwxK8yI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bCwxK8yI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fIONeKCS, 1, m, &cDelay_fIONeKCS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZhT4cGcS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fIONeKCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fIONeKCS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kPCZAG3n, 0, m, &cIf_kPCZAG3n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bCwxK8yI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fIONeKCS, 0, m, &cDelay_fIONeKCS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZhT4cGcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fIONeKCS, 0, m, &cDelay_fIONeKCS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oATIbCB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YBlaSvtL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A3OPJSYI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L4UR9GFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hHWFmInq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_awzDOmIt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hHWFmInq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kPCZAG3n, 1, m, &cIf_kPCZAG3n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_awzDOmIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rhi6gf5P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_A3OPJSYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JC63vDN7, 0, m, &cIf_JC63vDN7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YBlaSvtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JC63vDN7, 1, m, &cIf_JC63vDN7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZhOHZf08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jnCCOh9a, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZPsQWiz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jnCCOh9a, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_P51trzj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_S1ZBNEIp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_tfrp0dZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_15416lP5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_q4lrmUyh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mfuUZU5Z_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mfuUZU5Z_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lmA6FrJ5, 1, m, &cDelay_lmA6FrJ5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S0SJmceL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_lmA6FrJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lmA6FrJ5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_P51trzj4, 0, m, &cIf_P51trzj4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mfuUZU5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lmA6FrJ5, 0, m, &cDelay_lmA6FrJ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S0SJmceL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lmA6FrJ5, 0, m, &cDelay_lmA6FrJ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vqLI4Uvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ovap9Ej3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gCZNiHyo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4x1l05wL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1gHEjAGD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TKbMdaZk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TKbMdaZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_q4lrmUyh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1gHEjAGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P51trzj4, 1, m, &cIf_P51trzj4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ovap9Ej3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tfrp0dZh, 1, m, &cIf_tfrp0dZh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gCZNiHyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tfrp0dZh, 0, m, &cIf_tfrp0dZh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_15416lP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9JeXxVOp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_S1ZBNEIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9JeXxVOp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OmpGSGN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zDfIYXEz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fUbZwLcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LzyQFSNm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XYfUeAQ7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_p0xg7o6u_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_p0xg7o6u_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6S8oOB6R, 1, m, &cDelay_6S8oOB6R_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u6BCFSaE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6S8oOB6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6S8oOB6R, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OmpGSGN8, 0, m, &cIf_OmpGSGN8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p0xg7o6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6S8oOB6R, 0, m, &cDelay_6S8oOB6R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u6BCFSaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6S8oOB6R, 0, m, &cDelay_6S8oOB6R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cV6Y3Nfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rwMjCQDd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vnQGq6y5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BC8rMyWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mDcykQRB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i6Avu0Sx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i6Avu0Sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XYfUeAQ7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mDcykQRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OmpGSGN8, 1, m, &cIf_OmpGSGN8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rwMjCQDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fUbZwLcn, 1, m, &cIf_fUbZwLcn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vnQGq6y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fUbZwLcn, 0, m, &cIf_fUbZwLcn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LzyQFSNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EPx76WLx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zDfIYXEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EPx76WLx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RuNg8wxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eL8odFb2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NukyAYs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jD5aq86m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_T5IlMrpd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3rDQnutn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3rDQnutn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IANRmvzC, 1, m, &cDelay_IANRmvzC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w71JTSz5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IANRmvzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IANRmvzC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RuNg8wxU, 0, m, &cIf_RuNg8wxU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3rDQnutn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IANRmvzC, 0, m, &cDelay_IANRmvzC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w71JTSz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IANRmvzC, 0, m, &cDelay_IANRmvzC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wDHXT56b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QEzIbknD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1ZyPLuvZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dMGhxDPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RkULwxJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KhN9WHpG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RkULwxJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RuNg8wxU, 1, m, &cIf_RuNg8wxU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KhN9WHpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_T5IlMrpd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1ZyPLuvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NukyAYs2, 0, m, &cIf_NukyAYs2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QEzIbknD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NukyAYs2, 1, m, &cIf_NukyAYs2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jD5aq86m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3r9ZuJmw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eL8odFb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3r9ZuJmw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OFW0Xv4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IhhZv4Xy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VEm08rhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HBifUBoO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dikYc8Qm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uKUe4xon_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uKUe4xon_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QWufyErR, 1, m, &cDelay_QWufyErR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MacIMkvh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_QWufyErR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QWufyErR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OFW0Xv4P, 0, m, &cIf_OFW0Xv4P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uKUe4xon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QWufyErR, 0, m, &cDelay_QWufyErR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MacIMkvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QWufyErR, 0, m, &cDelay_QWufyErR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JH8kB2jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_10b5Pyzm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5oD8MzUm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jMZLhm7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tj2kNDem_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pYl0UEyx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pYl0UEyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dikYc8Qm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Tj2kNDem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OFW0Xv4P, 1, m, &cIf_OFW0Xv4P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_10b5Pyzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VEm08rhQ, 1, m, &cIf_VEm08rhQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5oD8MzUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VEm08rhQ, 0, m, &cIf_VEm08rhQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HBifUBoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_im1mFQcA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IhhZv4Xy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_im1mFQcA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tQJPbwH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b1prNLLM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_tpwJWkHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_miWDM4bj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Mbe1OPvx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sMD4GAE4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sMD4GAE4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0NYnOCus, 1, m, &cDelay_0NYnOCus_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nEe3FSrX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0NYnOCus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0NYnOCus, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tQJPbwH7, 0, m, &cIf_tQJPbwH7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sMD4GAE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0NYnOCus, 0, m, &cDelay_0NYnOCus_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nEe3FSrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0NYnOCus, 0, m, &cDelay_0NYnOCus_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tZkq23Zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0LT0VL6G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r50BWFqj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xDOC8snW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H5dWgzu3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yFKDJx3X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yFKDJx3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Mbe1OPvx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_H5dWgzu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tQJPbwH7, 1, m, &cIf_tQJPbwH7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r50BWFqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tpwJWkHL, 0, m, &cIf_tpwJWkHL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0LT0VL6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tpwJWkHL, 1, m, &cIf_tpwJWkHL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_miWDM4bj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_67F3F3cf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_b1prNLLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_67F3F3cf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_v5GYzPj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yiZD4uVI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XnnXnh4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oYwAtdtc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vJ5koR2S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PYkT13ik_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PYkT13ik_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OnT9TLj9, 1, m, &cDelay_OnT9TLj9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WRdG0JCq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OnT9TLj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OnT9TLj9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_v5GYzPj5, 0, m, &cIf_v5GYzPj5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PYkT13ik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OnT9TLj9, 0, m, &cDelay_OnT9TLj9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WRdG0JCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OnT9TLj9, 0, m, &cDelay_OnT9TLj9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dgQ6Yrdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sQIBC3df_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wqqw5StY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Of2cV7ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uXjPA2C3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BOxFlDK0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uXjPA2C3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v5GYzPj5, 1, m, &cIf_v5GYzPj5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BOxFlDK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vJ5koR2S_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Wqqw5StY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XnnXnh4F, 0, m, &cIf_XnnXnh4F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sQIBC3df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XnnXnh4F, 1, m, &cIf_XnnXnh4F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oYwAtdtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_916H9aN2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yiZD4uVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_916H9aN2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_M0lvoIoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DIppHeRs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XpJ4LE1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tznd2sv8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VmRk0CdN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_g5kmHpiL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_g5kmHpiL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qd62XIPz, 1, m, &cDelay_qd62XIPz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ra6w0PCg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qd62XIPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qd62XIPz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_M0lvoIoE, 0, m, &cIf_M0lvoIoE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g5kmHpiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qd62XIPz, 0, m, &cDelay_qd62XIPz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ra6w0PCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qd62XIPz, 0, m, &cDelay_qd62XIPz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4kzEm63M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eQCebBlk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MXLtpQ7P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SURKAdgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oV2dQfjc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c2zZgDxH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c2zZgDxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VmRk0CdN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oV2dQfjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M0lvoIoE, 1, m, &cIf_M0lvoIoE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eQCebBlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XpJ4LE1D, 1, m, &cIf_XpJ4LE1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MXLtpQ7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XpJ4LE1D, 0, m, &cIf_XpJ4LE1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tznd2sv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H9Fyl5Ww, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DIppHeRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H9Fyl5Ww, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vXDBvyOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_H5DaD1WT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_iZf468Va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OE7w865d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pFyOyjli_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Botb7Exj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Botb7Exj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5gL4e7be, 1, m, &cDelay_5gL4e7be_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aDahzKDd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5gL4e7be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5gL4e7be, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vXDBvyOR, 0, m, &cIf_vXDBvyOR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Botb7Exj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5gL4e7be, 0, m, &cDelay_5gL4e7be_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aDahzKDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5gL4e7be, 0, m, &cDelay_5gL4e7be_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VrDzYEhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_un4zU4Ij_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n5tymuLW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8AhJAP53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hpyy64C0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V3pYTbbb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V3pYTbbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pFyOyjli_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hpyy64C0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vXDBvyOR, 1, m, &cIf_vXDBvyOR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n5tymuLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iZf468Va, 0, m, &cIf_iZf468Va_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_un4zU4Ij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iZf468Va, 1, m, &cIf_iZf468Va_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OE7w865d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bFZMWWwB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_H5DaD1WT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bFZMWWwB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_86RcTEul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LkrVD2LQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4qBrPLuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ggo5D9x4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_88nhkB1f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ipsT009e_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ipsT009e_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8JIEIRMG, 1, m, &cDelay_8JIEIRMG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R8KY6H6o_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8JIEIRMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8JIEIRMG, m);
  cIf_onMessage(_c, &Context(_c)->cIf_86RcTEul, 0, m, &cIf_86RcTEul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ipsT009e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8JIEIRMG, 0, m, &cDelay_8JIEIRMG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R8KY6H6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8JIEIRMG, 0, m, &cDelay_8JIEIRMG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gDG1qv8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z4S95yux_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hbhFLezI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GoBwVuvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zJAtOfc2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hWi8qhWP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zJAtOfc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_86RcTEul, 1, m, &cIf_86RcTEul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hWi8qhWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_88nhkB1f_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Z4S95yux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4qBrPLuN, 1, m, &cIf_4qBrPLuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hbhFLezI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4qBrPLuN, 0, m, &cIf_4qBrPLuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ggo5D9x4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OU8jNKbx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LkrVD2LQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OU8jNKbx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_D1KaHqYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_cnzfwWgl_sendMessage(_c, 0, m);
  cMsg_f8u6oWaT_sendMessage(_c, 0, m);
  cMsg_VS940LmY_sendMessage(_c, 0, m);
  cMsg_WFQp7lLy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mspzcpbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_cnzfwWgl_sendMessage(_c, 0, m);
  cMsg_4EsBhAok_sendMessage(_c, 0, m);
  cMsg_OhgUq46R_sendMessage(_c, 0, m);
  cMsg_sWz4fYp6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mFRk6pSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_UUKMc0iT_sendMessage(_c, 0, m);
  cMsg_4EsBhAok_sendMessage(_c, 0, m);
  cMsg_WFQp7lLy_sendMessage(_c, 0, m);
  cMsg_n5gHFYSy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ydw8hJRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_UUKMc0iT_sendMessage(_c, 0, m);
  cMsg_Mk0Uwqdf_sendMessage(_c, 0, m);
  cMsg_VS940LmY_sendMessage(_c, 0, m);
  cMsg_cdQfu0I3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Js5s06AT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_u513FttZ_sendMessage(_c, 0, m);
  cMsg_sWz4fYp6_sendMessage(_c, 0, m);
  cMsg_MPmdTJPa_sendMessage(_c, 0, m);
  cMsg_VS940LmY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UyRTjhHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_u513FttZ_sendMessage(_c, 0, m);
  cMsg_cdQfu0I3_sendMessage(_c, 0, m);
  cMsg_4EsBhAok_sendMessage(_c, 0, m);
  cMsg_JxTDrjSZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5qk0mhpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ufSSWu4a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eDx5owjF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2fr3Hk0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ufSSWu4a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eDx5owjF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GahZH8KZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tBTogqVV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GV6YpeE2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yXPsB8Kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tBTogqVV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GV6YpeE2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WGOBbfNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_L4UR9GFf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oATIbCB2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YPXP8d8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_L4UR9GFf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oATIbCB2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cnzfwWgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_5qk0mhpc_sendMessage(_c, 0, m);
  cMsg_yXPsB8Kp_sendMessage(_c, 0, m);
  cMsg_YPXP8d8o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UUKMc0iT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_2fr3Hk0h_sendMessage(_c, 0, m);
  cMsg_GahZH8KZ_sendMessage(_c, 0, m);
  cMsg_YPXP8d8o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_u513FttZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_2fr3Hk0h_sendMessage(_c, 0, m);
  cMsg_yXPsB8Kp_sendMessage(_c, 0, m);
  cMsg_WGOBbfNM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1fnS1R8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4x1l05wL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vqLI4Uvb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9ekCqWPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4x1l05wL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vqLI4Uvb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vc39LdUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BC8rMyWb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cV6Y3Nfy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XQ54rRnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BC8rMyWb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cV6Y3Nfy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LlBF43Nn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dMGhxDPu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wDHXT56b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e8ZG48sS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dMGhxDPu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wDHXT56b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4EsBhAok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_9ekCqWPa_sendMessage(_c, 0, m);
  cMsg_XQ54rRnP_sendMessage(_c, 0, m);
  cMsg_e8ZG48sS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_f8u6oWaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_9ekCqWPa_sendMessage(_c, 0, m);
  cMsg_Vc39LdUv_sendMessage(_c, 0, m);
  cMsg_LlBF43Nn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Mk0Uwqdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_1fnS1R8c_sendMessage(_c, 0, m);
  cMsg_XQ54rRnP_sendMessage(_c, 0, m);
  cMsg_LlBF43Nn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wTx22G2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SURKAdgb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4kzEm63M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1tzcqgeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SURKAdgb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4kzEm63M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b1kfxnjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8AhJAP53_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VrDzYEhR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5bKgQd2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8AhJAP53_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VrDzYEhR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YiUMrWHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GoBwVuvI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gDG1qv8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_itK746IT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GoBwVuvI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gDG1qv8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cdQfu0I3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_wTx22G2U_sendMessage(_c, 0, m);
  cMsg_5bKgQd2T_sendMessage(_c, 0, m);
  cMsg_itK746IT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sWz4fYp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_1tzcqgeh_sendMessage(_c, 0, m);
  cMsg_b1kfxnjx_sendMessage(_c, 0, m);
  cMsg_itK746IT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WFQp7lLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_1tzcqgeh_sendMessage(_c, 0, m);
  cMsg_5bKgQd2T_sendMessage(_c, 0, m);
  cMsg_YiUMrWHk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EXqoXoPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jMZLhm7a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JH8kB2jy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hHomGrvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jMZLhm7a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JH8kB2jy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GGGqf0CN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xDOC8snW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tZkq23Zp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0xCof8g1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xDOC8snW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tZkq23Zp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3NEq01OG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Of2cV7ru_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dgQ6Yrdp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TjO89C6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Of2cV7ru_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dgQ6Yrdp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VS940LmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_hHomGrvL_sendMessage(_c, 0, m);
  cMsg_0xCof8g1_sendMessage(_c, 0, m);
  cMsg_TjO89C6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OhgUq46R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_hHomGrvL_sendMessage(_c, 0, m);
  cMsg_GGGqf0CN_sendMessage(_c, 0, m);
  cMsg_3NEq01OG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JxTDrjSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_EXqoXoPI_sendMessage(_c, 0, m);
  cMsg_GGGqf0CN_sendMessage(_c, 0, m);
  cMsg_TjO89C6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MPmdTJPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_1fnS1R8c_sendMessage(_c, 0, m);
  cMsg_Vc39LdUv_sendMessage(_c, 0, m);
  cMsg_e8ZG48sS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_n5gHFYSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_EXqoXoPI_sendMessage(_c, 0, m);
  cMsg_0xCof8g1_sendMessage(_c, 0, m);
  cMsg_3NEq01OG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_EHWEowQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3MCmK8D5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KeymVA3x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VNwhXyr9, 0, m, &cSlice_VNwhXyr9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VNQYrdrx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_VNwhXyr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EQbH5kCW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EQbH5kCW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jP41j4l8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EQbH5kCW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EQbH5kCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MJrxSTRP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EgKH64Xo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ILVSaCXZ, 0, m, &cSlice_ILVSaCXZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IN4gz5vg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ILVSaCXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_M6GX7Q6V_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_M6GX7Q6V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_eNlDCwbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M6GX7Q6V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_M6GX7Q6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_j80x93J7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IN4gz5vg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NGnUileG, 0, m, &cSlice_NGnUileG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KeymVA3x_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_NGnUileG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GAH3ISoU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GAH3ISoU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_4xnKJLt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GAH3ISoU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GAH3ISoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xklyc3UW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VNQYrdrx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IJD3TRrp, 0, m, &cSlice_IJD3TRrp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yHXvFqKq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_IJD3TRrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZderaQnd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZderaQnd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_N4EHx9x6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZderaQnd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ZderaQnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YwpZKxBi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yHXvFqKq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NMguCvrH, 0, m, &cSlice_NMguCvrH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_leUgTc1O_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_NMguCvrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gtGg6gu5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gtGg6gu5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_VKqpFccA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gtGg6gu5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gtGg6gu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_m6jwopj6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pqmKXQF8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jcCmgcXC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jcCmgcXC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MEMWKI7z, 1, m, &cDelay_MEMWKI7z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4RgxG1VP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MEMWKI7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MEMWKI7z, m);
  cMsg_1OiM3lzi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jcCmgcXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MEMWKI7z, 0, m, &cDelay_MEMWKI7z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4RgxG1VP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MEMWKI7z, 0, m, &cDelay_MEMWKI7z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_pn4pXEWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m4dZfF1E, HV_BINOP_SUBTRACT, 0, m, &cBinop_m4dZfF1E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_fjclpkGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Wa76pfdW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_V71sXjCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Wa76pfdW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_05lA29xt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pn4pXEWR, 0, m, &cVar_pn4pXEWR_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_QuennDTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6SscbC3M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bdaBlDYX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dj3K9sj3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m4dZfF1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6SEOHRtP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6SEOHRtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_eU0z1jyN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eU0z1jyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_utwBOSv3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gOtxL6cA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SVHtblew_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_awBlQHo6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SVHtblew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fjclpkGH, 1, m, &cIf_fjclpkGH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_awBlQHo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nLSLWBjW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_osOtGI6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V71sXjCx, 1, m, &cIf_V71sXjCx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nLSLWBjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_fjclpkGH, 0, m, &cIf_fjclpkGH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_utwBOSv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V71sXjCx, 0, m, &cIf_V71sXjCx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6SscbC3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_bdaBlDYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m4dZfF1E, HV_BINOP_SUBTRACT, 1, m, &cBinop_m4dZfF1E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Dj3K9sj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pn4pXEWR, 0, m, &cVar_pn4pXEWR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wa76pfdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j3bMlyI5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_leUgTc1O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8LUVYxau, 0, m, &cSlice_8LUVYxau_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_8LUVYxau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4UK45QZG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4UK45QZG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_umTix8rO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4UK45QZG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_4UK45QZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8E4Latac_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_igmssNc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hvw88l84, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3Fp9hDvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bg6xx5OP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_P95rzb19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_agHobrHY, 0, m, &cVar_agHobrHY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3MCmK8D5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lsv3ZpYe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ArVbSQMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kFBEmd8d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JAtbxjNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pqmKXQF8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1OiM3lzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YAQqEmQ4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kFBEmd8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YAQqEmQ4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1GRkTjm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_60mAmWha_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_60mAmWha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nd3Malwg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nd3Malwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8I1ZYsHX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_2wdCNtjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H6vZSYnk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_zKu5bJPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U44WWANL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_R6cUEzWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CmMJ8MrH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_4ewJkT60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A7syGe3I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_NOIff12y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QLRdpekW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_zT7eAdd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_K8knDYAV_sendMessage);
  cMsg_9hqUlon3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_K8knDYAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zT7eAdd0, 1, m, &cVar_zT7eAdd0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8u8XXlG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UNcFmSLe_sendMessage(_c, 0, m);
  cMsg_pgWaj605_sendMessage(_c, 0, m);
  cMsg_Ca2ku1Cv_sendMessage(_c, 0, m);
  cMsg_otYMqMbe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Txkdnz4a_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bofpWUyt, 0, m, &cSlice_bofpWUyt_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bofpWUyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_w9IVrMBI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_w9IVrMBI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_W6EGcOkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_w9IVrMBI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_w9IVrMBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n4sAAdyw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_QgkDHj6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MtuI5jXD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MtuI5jXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Gf4BClaT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Gf4BClaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_z5Od0a1C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_z5Od0a1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CTk2i0oe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A9KdJ8fg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A9KdJ8fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_spiTEFKb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_CTk2i0oe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lj1twuCP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lj1twuCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZtG9sbdT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_spiTEFKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jpyRYuRz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jpyRYuRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_v88uPbZ8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZtG9sbdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4QOFrcyy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_v88uPbZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZbLrwsLr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4QOFrcyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T4cf6d5T, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZbLrwsLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4viKkn7K, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_qfp8UMBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pV86snI9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_kt6DulLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tRnHt1ko_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wZnsHAyv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g1NKxQFd_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_viucr6un_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jPpOPlU8_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j34AF4qq_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rOtFarYt_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SNok9u8s_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_g1NKxQFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_18pAIDY3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_viucr6un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PTx4jyNr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jPpOPlU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bNLmRvSV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_j34AF4qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jq9t9VZb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_rOtFarYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SjVp0cZ8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SNok9u8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qSoBMa3t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_YhFeEQ3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QfW6NCKS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6TIt9y9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o4XimVuU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rTfpztVw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_edjkqZvR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_edjkqZvR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bdXIOw9z, 1, m, &cDelay_bdXIOw9z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WAhVU8Qw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_bdXIOw9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bdXIOw9z, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YhFeEQ3g, 0, m, &cIf_YhFeEQ3g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_edjkqZvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bdXIOw9z, 0, m, &cDelay_bdXIOw9z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WAhVU8Qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bdXIOw9z, 0, m, &cDelay_bdXIOw9z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_btPKMOEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ny1ASwHH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PYQgNDee_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pgYv5L0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sqY6fN7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7eUe9NQt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7eUe9NQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rTfpztVw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sqY6fN7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YhFeEQ3g, 1, m, &cIf_YhFeEQ3g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ny1ASwHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6TIt9y9T, 1, m, &cIf_6TIt9y9T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PYQgNDee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6TIt9y9T, 0, m, &cIf_6TIt9y9T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o4XimVuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UjIe0wB0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QfW6NCKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UjIe0wB0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_M8h1W7hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_riBpZ6oi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gEflgktp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JGaGkxOt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EMWjSgOv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_V8OKJIuJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_V8OKJIuJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gcqqQASc, 1, m, &cDelay_gcqqQASc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uVKHgHNd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gcqqQASc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gcqqQASc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_M8h1W7hj, 0, m, &cIf_M8h1W7hj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_V8OKJIuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gcqqQASc, 0, m, &cDelay_gcqqQASc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uVKHgHNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gcqqQASc, 0, m, &cDelay_gcqqQASc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IDLj8Z0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pXo9w51S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7IZMTaq8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GWSl3j3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4rF83ezM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BX6PYhYF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4rF83ezM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M8h1W7hj, 1, m, &cIf_M8h1W7hj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BX6PYhYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EMWjSgOv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pXo9w51S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gEflgktp, 1, m, &cIf_gEflgktp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7IZMTaq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gEflgktp, 0, m, &cIf_gEflgktp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JGaGkxOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YjL4PIej, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_riBpZ6oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YjL4PIej, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mdKoPkuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ce313UIH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_W6DGm9yZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mp5TeuXi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FMOy0ZLS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pEpQQqtn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pEpQQqtn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yFCr3pbN, 1, m, &cDelay_yFCr3pbN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gOLZQwkI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yFCr3pbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yFCr3pbN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mdKoPkuJ, 0, m, &cIf_mdKoPkuJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pEpQQqtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yFCr3pbN, 0, m, &cDelay_yFCr3pbN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gOLZQwkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yFCr3pbN, 0, m, &cDelay_yFCr3pbN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JhWMF05q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DO3yVpt8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1AgfaV6U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y2DLJluy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nvwDAVga_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xnr1LpvH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xnr1LpvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FMOy0ZLS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nvwDAVga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mdKoPkuJ, 1, m, &cIf_mdKoPkuJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1AgfaV6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W6DGm9yZ, 0, m, &cIf_W6DGm9yZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DO3yVpt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W6DGm9yZ, 1, m, &cIf_W6DGm9yZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mp5TeuXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6TbGbZLC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ce313UIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6TbGbZLC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_MyXhZFSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nDjSj2RQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_e2HuMIBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2wbbslO9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_M8toV5Rl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1zLjdPoq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1zLjdPoq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KH2azsHu, 1, m, &cDelay_KH2azsHu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RPkYVcJo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KH2azsHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KH2azsHu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MyXhZFSY, 0, m, &cIf_MyXhZFSY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1zLjdPoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KH2azsHu, 0, m, &cDelay_KH2azsHu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RPkYVcJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KH2azsHu, 0, m, &cDelay_KH2azsHu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0ngceutc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cpZJUQix_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mae1ndxs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ckiIwChg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yV5hvrKm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JX4xpHIA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JX4xpHIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_M8toV5Rl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yV5hvrKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MyXhZFSY, 1, m, &cIf_MyXhZFSY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cpZJUQix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e2HuMIBb, 1, m, &cIf_e2HuMIBb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mae1ndxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e2HuMIBb, 0, m, &cIf_e2HuMIBb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2wbbslO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FFPTPYu5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nDjSj2RQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FFPTPYu5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_nBNv8eHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hB83740i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yQjpvQNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sYNHf5rP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_G798fJgP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wjC1Y4ty_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wjC1Y4ty_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HdeEnCQg, 1, m, &cDelay_HdeEnCQg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ViSxpegx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HdeEnCQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HdeEnCQg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_nBNv8eHV, 0, m, &cIf_nBNv8eHV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wjC1Y4ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HdeEnCQg, 0, m, &cDelay_HdeEnCQg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ViSxpegx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HdeEnCQg, 0, m, &cDelay_HdeEnCQg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Guyf7GWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dzw1M3ah_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yS995JLo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6WSmwMBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B5vpBMLV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QZsVQG0F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QZsVQG0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_G798fJgP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_B5vpBMLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nBNv8eHV, 1, m, &cIf_nBNv8eHV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dzw1M3ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yQjpvQNQ, 1, m, &cIf_yQjpvQNQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yS995JLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yQjpvQNQ, 0, m, &cIf_yQjpvQNQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sYNHf5rP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fWRK1Yyw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hB83740i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fWRK1Yyw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_r87OSDLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4TfzydYR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_O92aYs0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lpHJl78I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SfIVpzhf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lbNsRxfm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lbNsRxfm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ua9bSfCg, 1, m, &cDelay_Ua9bSfCg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uextXYpH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Ua9bSfCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ua9bSfCg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_r87OSDLY, 0, m, &cIf_r87OSDLY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lbNsRxfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ua9bSfCg, 0, m, &cDelay_Ua9bSfCg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uextXYpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ua9bSfCg, 0, m, &cDelay_Ua9bSfCg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9Nw1hHnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KnY6jYGV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8X8DpYS5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t2MVDlHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4eBIwh3O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MpmIygeF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MpmIygeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SfIVpzhf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4eBIwh3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r87OSDLY, 1, m, &cIf_r87OSDLY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KnY6jYGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O92aYs0o, 1, m, &cIf_O92aYs0o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8X8DpYS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O92aYs0o, 0, m, &cIf_O92aYs0o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lpHJl78I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RdoIW7TP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4TfzydYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RdoIW7TP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Sl0dLRYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_elN2KT7b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YYW03pvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OqmDlTVa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wGWPn1h5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ALjxKwCa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ALjxKwCa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TY43hvvf, 1, m, &cDelay_TY43hvvf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h1A4os0a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TY43hvvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TY43hvvf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Sl0dLRYj, 0, m, &cIf_Sl0dLRYj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ALjxKwCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TY43hvvf, 0, m, &cDelay_TY43hvvf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h1A4os0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TY43hvvf, 0, m, &cDelay_TY43hvvf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vPUdEhIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5xNo7fAE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9bwdrcXa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_puHWDr7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h0oRAQ1s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rAHfUeU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rAHfUeU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wGWPn1h5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_h0oRAQ1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sl0dLRYj, 1, m, &cIf_Sl0dLRYj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5xNo7fAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YYW03pvZ, 1, m, &cIf_YYW03pvZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9bwdrcXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YYW03pvZ, 0, m, &cIf_YYW03pvZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OqmDlTVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qv3eaGnk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_elN2KT7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qv3eaGnk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qA4yEhB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pMIMijzX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3DxNdedU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MuOZ4acu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cLiocfPh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vxMxUmRD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vxMxUmRD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0a7NVpUN, 1, m, &cDelay_0a7NVpUN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eDUwGXzK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0a7NVpUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0a7NVpUN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qA4yEhB2, 0, m, &cIf_qA4yEhB2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vxMxUmRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0a7NVpUN, 0, m, &cDelay_0a7NVpUN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eDUwGXzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0a7NVpUN, 0, m, &cDelay_0a7NVpUN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9bWHVblM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vSMu2gCs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_79py7vAD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eTDOoXX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OmaGd7HC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ynp5RYfX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ynp5RYfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cLiocfPh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_OmaGd7HC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qA4yEhB2, 1, m, &cIf_qA4yEhB2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vSMu2gCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3DxNdedU, 1, m, &cIf_3DxNdedU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_79py7vAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3DxNdedU, 0, m, &cIf_3DxNdedU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MuOZ4acu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FxjQcaT5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pMIMijzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FxjQcaT5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lNEhM1RW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DSEC3n1K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2tbmD2F9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6E7BA8Tj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_A0DyobCV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nImRJSLC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nImRJSLC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BvAPUDZv, 1, m, &cDelay_BvAPUDZv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DGh5jOR9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BvAPUDZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BvAPUDZv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lNEhM1RW, 0, m, &cIf_lNEhM1RW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nImRJSLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BvAPUDZv, 0, m, &cDelay_BvAPUDZv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DGh5jOR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BvAPUDZv, 0, m, &cDelay_BvAPUDZv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pnzvHNjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wnbkjKFB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8mtFqACd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Tt1eQyTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OIKGLvLR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pfmyOT8K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pfmyOT8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_A0DyobCV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_OIKGLvLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lNEhM1RW, 1, m, &cIf_lNEhM1RW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8mtFqACd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2tbmD2F9, 0, m, &cIf_2tbmD2F9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wnbkjKFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2tbmD2F9, 1, m, &cIf_2tbmD2F9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6E7BA8Tj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uUrJ6ASI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DSEC3n1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uUrJ6ASI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RsnG6I1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RETrfJB3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jQVuWXDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6otvfTrM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2F3nPZwB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZPihLhnr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZPihLhnr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_n7VN2c1D, 1, m, &cDelay_n7VN2c1D_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W6daWDP3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_n7VN2c1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_n7VN2c1D, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RsnG6I1h, 0, m, &cIf_RsnG6I1h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZPihLhnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_n7VN2c1D, 0, m, &cDelay_n7VN2c1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W6daWDP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_n7VN2c1D, 0, m, &cDelay_n7VN2c1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0h2sidYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BzjtXuQi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xatjppaP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HF0hQrNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eIOpUA6I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mu48wucB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mu48wucB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2F3nPZwB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_eIOpUA6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RsnG6I1h, 1, m, &cIf_RsnG6I1h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BzjtXuQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jQVuWXDO, 1, m, &cIf_jQVuWXDO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xatjppaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jQVuWXDO, 0, m, &cIf_jQVuWXDO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6otvfTrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_imap6kx1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RETrfJB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_imap6kx1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CY9BXvdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7jj7t0bu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QKIkZfdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VUbGpMhu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9jzivesl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6AQvKLpx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6AQvKLpx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fcQ49cHq, 1, m, &cDelay_fcQ49cHq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u9vOyCD4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fcQ49cHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fcQ49cHq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CY9BXvdY, 0, m, &cIf_CY9BXvdY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6AQvKLpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fcQ49cHq, 0, m, &cDelay_fcQ49cHq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u9vOyCD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fcQ49cHq, 0, m, &cDelay_fcQ49cHq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9iNyfj42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gr2rV6fF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eYkO7fDw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lYta0Scq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_95hSYmOU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoXpJFbD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MoXpJFbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9jzivesl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_95hSYmOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CY9BXvdY, 1, m, &cIf_CY9BXvdY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eYkO7fDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QKIkZfdo, 0, m, &cIf_QKIkZfdo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gr2rV6fF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QKIkZfdo, 1, m, &cIf_QKIkZfdo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VUbGpMhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s5dewbb7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7jj7t0bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s5dewbb7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_txciklWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yW0aoth3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YpMpzCuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nthIrUEe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rWCvXrYy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_h7C92A1e_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_h7C92A1e_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GJTgTXs8, 1, m, &cDelay_GJTgTXs8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3vlBgBeZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GJTgTXs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GJTgTXs8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_txciklWy, 0, m, &cIf_txciklWy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h7C92A1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GJTgTXs8, 0, m, &cDelay_GJTgTXs8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3vlBgBeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GJTgTXs8, 0, m, &cDelay_GJTgTXs8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tBaMsrVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3ndNaFvj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sG5gGTnE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R7M3HFkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MJlpkQpy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O5bjZruD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O5bjZruD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rWCvXrYy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MJlpkQpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_txciklWy, 1, m, &cIf_txciklWy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3ndNaFvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YpMpzCuL, 1, m, &cIf_YpMpzCuL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sG5gGTnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YpMpzCuL, 0, m, &cIf_YpMpzCuL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nthIrUEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rbkkO81R, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yW0aoth3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rbkkO81R, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_18pAIDY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_uEQHCkww_sendMessage(_c, 0, m);
  cMsg_mcWIa1gD_sendMessage(_c, 0, m);
  cMsg_1hgBZWpW_sendMessage(_c, 0, m);
  cMsg_BV17b0EJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PTx4jyNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_uEQHCkww_sendMessage(_c, 0, m);
  cMsg_6GF8C8Pu_sendMessage(_c, 0, m);
  cMsg_D2uxJziA_sendMessage(_c, 0, m);
  cMsg_hzZuBCWL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bNLmRvSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_72fI1QLa_sendMessage(_c, 0, m);
  cMsg_6GF8C8Pu_sendMessage(_c, 0, m);
  cMsg_BV17b0EJ_sendMessage(_c, 0, m);
  cMsg_DcQPVRwW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jq9t9VZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_72fI1QLa_sendMessage(_c, 0, m);
  cMsg_Qq8vAD6U_sendMessage(_c, 0, m);
  cMsg_1hgBZWpW_sendMessage(_c, 0, m);
  cMsg_VyA8lj7l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SjVp0cZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_nVZ1Lz6W_sendMessage(_c, 0, m);
  cMsg_hzZuBCWL_sendMessage(_c, 0, m);
  cMsg_v1UWTjmP_sendMessage(_c, 0, m);
  cMsg_1hgBZWpW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qSoBMa3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_nVZ1Lz6W_sendMessage(_c, 0, m);
  cMsg_VyA8lj7l_sendMessage(_c, 0, m);
  cMsg_6GF8C8Pu_sendMessage(_c, 0, m);
  cMsg_5bIOj4se_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mEdsZW52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pgYv5L0O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_btPKMOEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7lNUFYM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pgYv5L0O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_btPKMOEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_459VbTFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GWSl3j3M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IDLj8Z0r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_biCxmSnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GWSl3j3M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IDLj8Z0r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Zx4wjN1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y2DLJluy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JhWMF05q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aIJXLOLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y2DLJluy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JhWMF05q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uEQHCkww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_mEdsZW52_sendMessage(_c, 0, m);
  cMsg_biCxmSnc_sendMessage(_c, 0, m);
  cMsg_aIJXLOLT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_72fI1QLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_7lNUFYM1_sendMessage(_c, 0, m);
  cMsg_459VbTFh_sendMessage(_c, 0, m);
  cMsg_aIJXLOLT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nVZ1Lz6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_7lNUFYM1_sendMessage(_c, 0, m);
  cMsg_biCxmSnc_sendMessage(_c, 0, m);
  cMsg_Zx4wjN1C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LS5may0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ckiIwChg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0ngceutc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3kc2W1Ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ckiIwChg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0ngceutc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yznCrq7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6WSmwMBs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Guyf7GWq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MCjegaKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6WSmwMBs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Guyf7GWq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Kr7TwjHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t2MVDlHS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9Nw1hHnZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QKGMbEt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t2MVDlHS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9Nw1hHnZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6GF8C8Pu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_3kc2W1Ea_sendMessage(_c, 0, m);
  cMsg_MCjegaKH_sendMessage(_c, 0, m);
  cMsg_QKGMbEt2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mcWIa1gD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_3kc2W1Ea_sendMessage(_c, 0, m);
  cMsg_yznCrq7W_sendMessage(_c, 0, m);
  cMsg_Kr7TwjHw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Qq8vAD6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_LS5may0J_sendMessage(_c, 0, m);
  cMsg_MCjegaKH_sendMessage(_c, 0, m);
  cMsg_Kr7TwjHw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TshwtZ4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HF0hQrNI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0h2sidYM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aTLkWhAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HF0hQrNI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0h2sidYM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H6vYyqm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lYta0Scq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9iNyfj42_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mcUBCN1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lYta0Scq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9iNyfj42_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1gImgHG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R7M3HFkQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tBaMsrVa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_93ovHIwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R7M3HFkQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tBaMsrVa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VyA8lj7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_TshwtZ4y_sendMessage(_c, 0, m);
  cMsg_mcUBCN1B_sendMessage(_c, 0, m);
  cMsg_93ovHIwc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hzZuBCWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_aTLkWhAb_sendMessage(_c, 0, m);
  cMsg_H6vYyqm1_sendMessage(_c, 0, m);
  cMsg_93ovHIwc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BV17b0EJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_aTLkWhAb_sendMessage(_c, 0, m);
  cMsg_mcUBCN1B_sendMessage(_c, 0, m);
  cMsg_1gImgHG9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IFIzMMwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_puHWDr7d_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vPUdEhIb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iUXQCU4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_puHWDr7d_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vPUdEhIb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TI5qW4e3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eTDOoXX5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9bWHVblM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1mQW0sLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eTDOoXX5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9bWHVblM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_baQ7c1px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Tt1eQyTt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pnzvHNjw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iRQlfmIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Tt1eQyTt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pnzvHNjw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1hgBZWpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_iUXQCU4V_sendMessage(_c, 0, m);
  cMsg_1mQW0sLk_sendMessage(_c, 0, m);
  cMsg_iRQlfmIE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_D2uxJziA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_iUXQCU4V_sendMessage(_c, 0, m);
  cMsg_TI5qW4e3_sendMessage(_c, 0, m);
  cMsg_baQ7c1px_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5bIOj4se_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_IFIzMMwU_sendMessage(_c, 0, m);
  cMsg_TI5qW4e3_sendMessage(_c, 0, m);
  cMsg_iRQlfmIE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v1UWTjmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_LS5may0J_sendMessage(_c, 0, m);
  cMsg_yznCrq7W_sendMessage(_c, 0, m);
  cMsg_QKGMbEt2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DcQPVRwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_IFIzMMwU_sendMessage(_c, 0, m);
  cMsg_1mQW0sLk_sendMessage(_c, 0, m);
  cMsg_baQ7c1px_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_lRhTojfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x4wIkSY8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_n2uziQ41_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cgOSNqja, 0, m, &cSlice_cgOSNqja_sendMessage);
      break;
    }
    default: {
      cSwitchcase_L5YYuywg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_cgOSNqja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cWRysjOO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cWRysjOO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_oFt1Fhnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cWRysjOO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_cWRysjOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t6EoXgr0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FSmdS8S3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NDpUhx2d, 0, m, &cSlice_NDpUhx2d_sendMessage);
      break;
    }
    default: {
      cSwitchcase_enaUKjb3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_NDpUhx2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yRAZMQMj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yRAZMQMj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_JESgWUrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yRAZMQMj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yRAZMQMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_j0HgpWx4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_enaUKjb3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uflnoEZr, 0, m, &cSlice_uflnoEZr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_n2uziQ41_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_uflnoEZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MLJYIhb1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MLJYIhb1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_HrjOeZ1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MLJYIhb1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_MLJYIhb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yjfLv2zw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_L5YYuywg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oDwZu1sV, 0, m, &cSlice_oDwZu1sV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CPWmqkqc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_oDwZu1sV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EX8pLxUo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EX8pLxUo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_4y9jhYxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EX8pLxUo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EX8pLxUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RQlt0o9d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CPWmqkqc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RBdhYId8, 0, m, &cSlice_RBdhYId8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_e0EvW3iq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_RBdhYId8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lMg4CJB9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lMg4CJB9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Mkcqb0PW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lMg4CJB9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lMg4CJB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_s9D0ik7m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_62KQghFE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ytjA1MDz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ytjA1MDz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_i1241QDj, 1, m, &cDelay_i1241QDj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QxWDo5ZM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_i1241QDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_i1241QDj, m);
  cMsg_6kONWWcV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ytjA1MDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_i1241QDj, 0, m, &cDelay_i1241QDj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QxWDo5ZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_i1241QDj, 0, m, &cDelay_i1241QDj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_fxFK37Am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U3TQeCwA, HV_BINOP_SUBTRACT, 0, m, &cBinop_U3TQeCwA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_m0M0e0kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KYH8cDN9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ITbPgCF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KYH8cDN9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_C0qxFZhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fxFK37Am, 0, m, &cVar_fxFK37Am_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_lNcyKyzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JaIETXD7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z4sYQUFu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AKXCqNeY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U3TQeCwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5FOuQp1d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5FOuQp1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5DdLsxfv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5DdLsxfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BpojtT4J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PBRFULum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B0th7Uue_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N1H6R9vj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N1H6R9vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l2BJEs0m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_B0th7Uue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m0M0e0kx, 1, m, &cIf_m0M0e0kx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fAofjfmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ITbPgCF2, 1, m, &cIf_ITbPgCF2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l2BJEs0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_m0M0e0kx, 0, m, &cIf_m0M0e0kx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BpojtT4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ITbPgCF2, 0, m, &cIf_ITbPgCF2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AKXCqNeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fxFK37Am, 0, m, &cVar_fxFK37Am_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z4sYQUFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U3TQeCwA, HV_BINOP_SUBTRACT, 1, m, &cBinop_U3TQeCwA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JaIETXD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_KYH8cDN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CjF2d5lm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e0EvW3iq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_83jdy5YH, 0, m, &cSlice_83jdy5YH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_83jdy5YH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_r9yhZODP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_r9yhZODP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_slvz4SLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_r9yhZODP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_r9yhZODP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JRYrqwiS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pV86snI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2dUsWEuF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tRnHt1ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6BrdkH41, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_stKYZrRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kt6DulLk, 0, m, &cVar_kt6DulLk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x4wIkSY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ODdFopKq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_l1BAJHsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_62KQghFE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kawYFAMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rj8wQtgr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6kONWWcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jauuiu3F, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rj8wQtgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jauuiu3F, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ABfRV99I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_LHAvjIwi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LHAvjIwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QwCpo6nG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QwCpo6nG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IqUJbKmP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_tXsybCV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hYRdKrpx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_IcgPfhtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dPrAVSKR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YxqoUois_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oPT5VnOB_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LKdfyMFT_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vwgOLEQ1_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qvzaqcd3_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lVchnxih_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_thawYCZ4_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_oPT5VnOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Oosw6b2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_LKdfyMFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6xf4zppC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_vwgOLEQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0eqe0NV2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_qvzaqcd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ilsJCqLu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_lVchnxih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gYwXmcRu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_thawYCZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_77aYwC5R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_SFpwcKfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zTxYaBJi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Qd3xRyYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WoKbEOPn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ns1ZNllu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5cerKEAQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5cerKEAQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gfK3Y5da, 1, m, &cDelay_gfK3Y5da_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iTIzk3dJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gfK3Y5da_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gfK3Y5da, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SFpwcKfK, 0, m, &cIf_SFpwcKfK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5cerKEAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gfK3Y5da, 0, m, &cDelay_gfK3Y5da_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iTIzk3dJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gfK3Y5da, 0, m, &cDelay_gfK3Y5da_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hLdChJgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qq1i7VKS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aIxJzt2u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n7OvFOyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_km7XLpfc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2TcaEIKX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2TcaEIKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ns1ZNllu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_km7XLpfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SFpwcKfK, 1, m, &cIf_SFpwcKfK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aIxJzt2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qd3xRyYp, 0, m, &cIf_Qd3xRyYp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qq1i7VKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qd3xRyYp, 1, m, &cIf_Qd3xRyYp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WoKbEOPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4FuRiRKa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zTxYaBJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4FuRiRKa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aU7OmsVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3JwFlY5k_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jX5xVRYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MyLPdFUu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JUPzqmqB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HKflQGms_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HKflQGms_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JLLbQ6OO, 1, m, &cDelay_JLLbQ6OO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RamRD7Bu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JLLbQ6OO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JLLbQ6OO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aU7OmsVP, 0, m, &cIf_aU7OmsVP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HKflQGms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JLLbQ6OO, 0, m, &cDelay_JLLbQ6OO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RamRD7Bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JLLbQ6OO, 0, m, &cDelay_JLLbQ6OO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bHnbei6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u0z8lbzV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LaTfgZrZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cw0B6roc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79pPxTh5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aUs9UKr1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aUs9UKr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JUPzqmqB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_79pPxTh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aU7OmsVP, 1, m, &cIf_aU7OmsVP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LaTfgZrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jX5xVRYE, 0, m, &cIf_jX5xVRYE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u0z8lbzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jX5xVRYE, 1, m, &cIf_jX5xVRYE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MyLPdFUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_scf0alsI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3JwFlY5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_scf0alsI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_QekL4h0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CMEO4QxX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kNSSEuqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DVcI1Xtm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Z4nPYMai_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XiViRXjb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XiViRXjb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jAr6cxFY, 1, m, &cDelay_jAr6cxFY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5vBYJfnB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jAr6cxFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jAr6cxFY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QekL4h0b, 0, m, &cIf_QekL4h0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XiViRXjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jAr6cxFY, 0, m, &cDelay_jAr6cxFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5vBYJfnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jAr6cxFY, 0, m, &cDelay_jAr6cxFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zgus2biO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c1nuURwy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qwAXJ1Qq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pHofb1rE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_86QDViLa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0vryNcI0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0vryNcI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Z4nPYMai_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_86QDViLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QekL4h0b, 1, m, &cIf_QekL4h0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c1nuURwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kNSSEuqi, 1, m, &cIf_kNSSEuqi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qwAXJ1Qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kNSSEuqi, 0, m, &cIf_kNSSEuqi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DVcI1Xtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nV1cwAVB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CMEO4QxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nV1cwAVB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2O4lPhbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xWRJCeLQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dySKV4BN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Usf8EQ8O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ODhxn1pL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7aFbAKt5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7aFbAKt5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fulqXj8z, 1, m, &cDelay_fulqXj8z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fVmwBP2w_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fulqXj8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fulqXj8z, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2O4lPhbI, 0, m, &cIf_2O4lPhbI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7aFbAKt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fulqXj8z, 0, m, &cDelay_fulqXj8z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fVmwBP2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fulqXj8z, 0, m, &cDelay_fulqXj8z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tBEwByFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1KBVw3QZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FkRm3FSF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cJ1aOIzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y1n3Y4OW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bnXcAotC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bnXcAotC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ODhxn1pL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_y1n3Y4OW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2O4lPhbI, 1, m, &cIf_2O4lPhbI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FkRm3FSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dySKV4BN, 0, m, &cIf_dySKV4BN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1KBVw3QZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dySKV4BN, 1, m, &cIf_dySKV4BN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Usf8EQ8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R3UlV6im, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xWRJCeLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R3UlV6im, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aA1hRvSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_blczF7Vn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zCCI3TRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9OdJmNbg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QGRFaPcp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9r3k6VQB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9r3k6VQB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SVEIRvs9, 1, m, &cDelay_SVEIRvs9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8gxHXb7p_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SVEIRvs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SVEIRvs9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aA1hRvSZ, 0, m, &cIf_aA1hRvSZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9r3k6VQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SVEIRvs9, 0, m, &cDelay_SVEIRvs9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8gxHXb7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SVEIRvs9, 0, m, &cDelay_SVEIRvs9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HWhvVgHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L9RA9aRT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iB8bzk2N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_momT6dVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OfyLJ0PM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E84rYqlV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E84rYqlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QGRFaPcp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_OfyLJ0PM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aA1hRvSZ, 1, m, &cIf_aA1hRvSZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iB8bzk2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zCCI3TRt, 0, m, &cIf_zCCI3TRt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L9RA9aRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zCCI3TRt, 1, m, &cIf_zCCI3TRt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9OdJmNbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XXaEjQCy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_blczF7Vn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XXaEjQCy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_HAdqk2So_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8pRIlJUG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8sihLMgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_w7IODFIF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oq9YuJ5t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RP10CtiF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RP10CtiF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wiR08BNS, 1, m, &cDelay_wiR08BNS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zjGHiQEI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wiR08BNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wiR08BNS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HAdqk2So, 0, m, &cIf_HAdqk2So_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RP10CtiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wiR08BNS, 0, m, &cDelay_wiR08BNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zjGHiQEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wiR08BNS, 0, m, &cDelay_wiR08BNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E2o8SKOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rDk8RjH8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ofC90Kbn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X8D3i2cU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YtVARg0I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QUbOXkCo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QUbOXkCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oq9YuJ5t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YtVARg0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HAdqk2So, 1, m, &cIf_HAdqk2So_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rDk8RjH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8sihLMgm, 1, m, &cIf_8sihLMgm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ofC90Kbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8sihLMgm, 0, m, &cIf_8sihLMgm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w7IODFIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8rb5DdsF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8pRIlJUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8rb5DdsF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2Vd5DHr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_78w6Hg07_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FuMWvZI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OI6btC0c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6A7b4UFw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BZOC2eL5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BZOC2eL5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ghhRMKIz, 1, m, &cDelay_ghhRMKIz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UcgSGY8l_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ghhRMKIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ghhRMKIz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2Vd5DHr0, 0, m, &cIf_2Vd5DHr0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BZOC2eL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ghhRMKIz, 0, m, &cDelay_ghhRMKIz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UcgSGY8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ghhRMKIz, 0, m, &cDelay_ghhRMKIz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8EBbktmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c7WsuzVl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wIJz2xe2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CN5JgjpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RvIM5qjB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SQBgCS8b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SQBgCS8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6A7b4UFw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RvIM5qjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2Vd5DHr0, 1, m, &cIf_2Vd5DHr0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wIJz2xe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FuMWvZI8, 0, m, &cIf_FuMWvZI8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c7WsuzVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FuMWvZI8, 1, m, &cIf_FuMWvZI8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OI6btC0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_23g6OJ46, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_78w6Hg07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_23g6OJ46, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_rsHM8gDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sNNdLqhe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vV5VQNFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fUP1PsTN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_z1MwfPJr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4RD9Vsve_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4RD9Vsve_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EyI8I2bo, 1, m, &cDelay_EyI8I2bo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yFS6zXbd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EyI8I2bo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EyI8I2bo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rsHM8gDR, 0, m, &cIf_rsHM8gDR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4RD9Vsve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EyI8I2bo, 0, m, &cDelay_EyI8I2bo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yFS6zXbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EyI8I2bo, 0, m, &cDelay_EyI8I2bo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sH3F4jxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HA00AQhw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bbJzF2Bn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6zfTjcka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1eAdMjc2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yDcrWLl8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yDcrWLl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_z1MwfPJr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1eAdMjc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rsHM8gDR, 1, m, &cIf_rsHM8gDR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bbJzF2Bn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vV5VQNFJ, 0, m, &cIf_vV5VQNFJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HA00AQhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vV5VQNFJ, 1, m, &cIf_vV5VQNFJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fUP1PsTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hvgcP6hu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sNNdLqhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hvgcP6hu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UqixNn1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lD9ZftK8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FMG8E7VG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_78Azdx8c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_w0D6WRUr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eJFjGL6T_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eJFjGL6T_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WcFoD5qL, 1, m, &cDelay_WcFoD5qL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tyozpjKo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WcFoD5qL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WcFoD5qL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UqixNn1B, 0, m, &cIf_UqixNn1B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eJFjGL6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WcFoD5qL, 0, m, &cDelay_WcFoD5qL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tyozpjKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WcFoD5qL, 0, m, &cDelay_WcFoD5qL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a7dw5o6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e2OU5tL0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E4SbZqZl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YOLdUWbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g0F7qGvM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5PxFVQXF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5PxFVQXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_w0D6WRUr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_g0F7qGvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UqixNn1B, 1, m, &cIf_UqixNn1B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E4SbZqZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FMG8E7VG, 0, m, &cIf_FMG8E7VG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e2OU5tL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FMG8E7VG, 1, m, &cIf_FMG8E7VG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_78Azdx8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K9zOQ3mr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lD9ZftK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K9zOQ3mr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_JnIesXMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FTYMGXw3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CdNHRwfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dCkdracJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RR1DZpob_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ufydmM1g_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ufydmM1g_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tJSZ2eis, 1, m, &cDelay_tJSZ2eis_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0I2MCdAl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tJSZ2eis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tJSZ2eis, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JnIesXMw, 0, m, &cIf_JnIesXMw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ufydmM1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tJSZ2eis, 0, m, &cDelay_tJSZ2eis_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0I2MCdAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tJSZ2eis, 0, m, &cDelay_tJSZ2eis_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VVWh99cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PXYBwbal_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8J3uwXx3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pzzvtshA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NboQYh12_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ThpWzLZ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ThpWzLZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RR1DZpob_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NboQYh12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JnIesXMw, 1, m, &cIf_JnIesXMw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PXYBwbal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CdNHRwfa, 1, m, &cIf_CdNHRwfa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8J3uwXx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CdNHRwfa, 0, m, &cIf_CdNHRwfa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dCkdracJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GcuJvUXP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FTYMGXw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GcuJvUXP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_DLbYWztH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qKbioMXu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0zXj7zLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_74bAjoD4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_E2DSoowS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PkjpTAdX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PkjpTAdX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kxzuFKVZ, 1, m, &cDelay_kxzuFKVZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qhgsCAVI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kxzuFKVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kxzuFKVZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_DLbYWztH, 0, m, &cIf_DLbYWztH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PkjpTAdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kxzuFKVZ, 0, m, &cDelay_kxzuFKVZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qhgsCAVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kxzuFKVZ, 0, m, &cDelay_kxzuFKVZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pR3dvDwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VHgjCwPG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x3uudUKj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_brh2MZqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4o3P8d9z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QvjNX1NB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QvjNX1NB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_E2DSoowS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4o3P8d9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DLbYWztH, 1, m, &cIf_DLbYWztH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x3uudUKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0zXj7zLX, 0, m, &cIf_0zXj7zLX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VHgjCwPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0zXj7zLX, 1, m, &cIf_0zXj7zLX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_74bAjoD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c81Khmzt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qKbioMXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c81Khmzt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mqMkZgKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3wmzTyQA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_f79s2zJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ehpLD62b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_h2MtjZHt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_e7adKuN5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_e7adKuN5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nPOrQUFW, 1, m, &cDelay_nPOrQUFW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PKcZjSfj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nPOrQUFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nPOrQUFW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mqMkZgKC, 0, m, &cIf_mqMkZgKC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e7adKuN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nPOrQUFW, 0, m, &cDelay_nPOrQUFW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PKcZjSfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nPOrQUFW, 0, m, &cDelay_nPOrQUFW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XKWsQ6HP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KUxJQLfV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3DAMCi1G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zWFOHLAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gX7xHUn1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NNWVhZLq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NNWVhZLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_h2MtjZHt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gX7xHUn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mqMkZgKC, 1, m, &cIf_mqMkZgKC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3DAMCi1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f79s2zJz, 0, m, &cIf_f79s2zJz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KUxJQLfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f79s2zJz, 1, m, &cIf_f79s2zJz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ehpLD62b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fcK3TKG7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3wmzTyQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fcK3TKG7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1Oosw6b2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_2n4C8hg1_sendMessage(_c, 0, m);
  cMsg_BdRdz4nL_sendMessage(_c, 0, m);
  cMsg_aI2ufZvN_sendMessage(_c, 0, m);
  cMsg_XKVHKlLj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6xf4zppC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_2n4C8hg1_sendMessage(_c, 0, m);
  cMsg_a9QDRBNg_sendMessage(_c, 0, m);
  cMsg_fvZ9sxHM_sendMessage(_c, 0, m);
  cMsg_hWsTInFN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0eqe0NV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_zcy8cNyJ_sendMessage(_c, 0, m);
  cMsg_a9QDRBNg_sendMessage(_c, 0, m);
  cMsg_XKVHKlLj_sendMessage(_c, 0, m);
  cMsg_GaCkMx8G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ilsJCqLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_zcy8cNyJ_sendMessage(_c, 0, m);
  cMsg_y3KWR0cL_sendMessage(_c, 0, m);
  cMsg_aI2ufZvN_sendMessage(_c, 0, m);
  cMsg_WYkwGTmc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gYwXmcRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_OuvueVsR_sendMessage(_c, 0, m);
  cMsg_hWsTInFN_sendMessage(_c, 0, m);
  cMsg_oEjHVHma_sendMessage(_c, 0, m);
  cMsg_aI2ufZvN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_77aYwC5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_OuvueVsR_sendMessage(_c, 0, m);
  cMsg_WYkwGTmc_sendMessage(_c, 0, m);
  cMsg_a9QDRBNg_sendMessage(_c, 0, m);
  cMsg_2pIhd0M7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GyLpSfkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n7OvFOyC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hLdChJgA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4O6JP3xE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n7OvFOyC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hLdChJgA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1Di3Oiwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cw0B6roc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bHnbei6b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7a8MqNvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cw0B6roc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bHnbei6b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EYNMXkRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pHofb1rE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Zgus2biO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_V76iOza5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pHofb1rE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Zgus2biO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2n4C8hg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_GyLpSfkK_sendMessage(_c, 0, m);
  cMsg_7a8MqNvE_sendMessage(_c, 0, m);
  cMsg_V76iOza5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zcy8cNyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_4O6JP3xE_sendMessage(_c, 0, m);
  cMsg_1Di3Oiwg_sendMessage(_c, 0, m);
  cMsg_V76iOza5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OuvueVsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_4O6JP3xE_sendMessage(_c, 0, m);
  cMsg_7a8MqNvE_sendMessage(_c, 0, m);
  cMsg_EYNMXkRq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DEdKqh08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cJ1aOIzi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tBEwByFq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DMMv2NIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cJ1aOIzi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tBEwByFq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fjOX94Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_momT6dVH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HWhvVgHD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ql1A8gLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_momT6dVH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HWhvVgHD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I3ORI7yL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_X8D3i2cU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E2o8SKOZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QREjRhRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_X8D3i2cU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E2o8SKOZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a9QDRBNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_DMMv2NIQ_sendMessage(_c, 0, m);
  cMsg_ql1A8gLV_sendMessage(_c, 0, m);
  cMsg_QREjRhRG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BdRdz4nL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_DMMv2NIQ_sendMessage(_c, 0, m);
  cMsg_fjOX94Rs_sendMessage(_c, 0, m);
  cMsg_I3ORI7yL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y3KWR0cL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_DEdKqh08_sendMessage(_c, 0, m);
  cMsg_ql1A8gLV_sendMessage(_c, 0, m);
  cMsg_I3ORI7yL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DkY3msBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pzzvtshA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VVWh99cs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GKDWmLKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pzzvtshA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VVWh99cs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0EntKlNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_brh2MZqU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pR3dvDwt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4sL9wx3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_brh2MZqU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pR3dvDwt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2OiSGf7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zWFOHLAV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XKWsQ6HP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9FIrbR4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zWFOHLAV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XKWsQ6HP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WYkwGTmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_DkY3msBW_sendMessage(_c, 0, m);
  cMsg_4sL9wx3Y_sendMessage(_c, 0, m);
  cMsg_9FIrbR4Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hWsTInFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_GKDWmLKi_sendMessage(_c, 0, m);
  cMsg_0EntKlNm_sendMessage(_c, 0, m);
  cMsg_9FIrbR4Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XKVHKlLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_GKDWmLKi_sendMessage(_c, 0, m);
  cMsg_4sL9wx3Y_sendMessage(_c, 0, m);
  cMsg_2OiSGf7Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7t8f1rZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CN5JgjpJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8EBbktmd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Rs1OmgiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CN5JgjpJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8EBbktmd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AwosRjH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6zfTjcka_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sH3F4jxa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XNLIFjXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6zfTjcka_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sH3F4jxa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4HyiCp9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YOLdUWbQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a7dw5o6i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E9zGA8Cn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YOLdUWbQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a7dw5o6i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aI2ufZvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_Rs1OmgiC_sendMessage(_c, 0, m);
  cMsg_XNLIFjXy_sendMessage(_c, 0, m);
  cMsg_E9zGA8Cn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fvZ9sxHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_Rs1OmgiC_sendMessage(_c, 0, m);
  cMsg_AwosRjH6_sendMessage(_c, 0, m);
  cMsg_4HyiCp9l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2pIhd0M7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_7t8f1rZn_sendMessage(_c, 0, m);
  cMsg_AwosRjH6_sendMessage(_c, 0, m);
  cMsg_E9zGA8Cn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oEjHVHma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_DEdKqh08_sendMessage(_c, 0, m);
  cMsg_fjOX94Rs_sendMessage(_c, 0, m);
  cMsg_QREjRhRG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GaCkMx8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_7t8f1rZn_sendMessage(_c, 0, m);
  cMsg_XNLIFjXy_sendMessage(_c, 0, m);
  cMsg_4HyiCp9l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_VWmKHPg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IWuXorDW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iWXZ2uGI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0L9LC1um, 0, m, &cSlice_0L9LC1um_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uRyPd9ud_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0L9LC1um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KgtKRNnJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KgtKRNnJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_oCEsF3VJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KgtKRNnJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KgtKRNnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Y1ob3sfx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TV2VbYSQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tLnIfMX7, 0, m, &cSlice_tLnIfMX7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zrV2HlFf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_tLnIfMX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aEeLnbU7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aEeLnbU7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_tJayuwhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aEeLnbU7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_aEeLnbU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iC4hY9lj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zrV2HlFf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EOTBHyTg, 0, m, &cSlice_EOTBHyTg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_iWXZ2uGI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_EOTBHyTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RnLrT6yE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RnLrT6yE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_DpiuHKO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RnLrT6yE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_RnLrT6yE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UXbq2r6n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uRyPd9ud_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pw78p04P, 0, m, &cSlice_pw78p04P_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wuL9L9pM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pw78p04P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7acA1WPT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7acA1WPT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_EDeJWx8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7acA1WPT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7acA1WPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5psdvpM6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wuL9L9pM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MoNHbbDh, 0, m, &cSlice_MoNHbbDh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NduG5O0Z_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_MoNHbbDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_s6YQf3Hb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_s6YQf3Hb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_y8ASHgpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s6YQf3Hb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_s6YQf3Hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sgzQc6wH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Gc5u02CN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BCGQNvau_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BCGQNvau_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MJP46uCn, 1, m, &cDelay_MJP46uCn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nnyP2YyI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MJP46uCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MJP46uCn, m);
  cMsg_2NpC1y7J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BCGQNvau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MJP46uCn, 0, m, &cDelay_MJP46uCn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nnyP2YyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MJP46uCn, 0, m, &cDelay_MJP46uCn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Go2uwCmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kkTbuh2k, HV_BINOP_SUBTRACT, 0, m, &cBinop_kkTbuh2k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_QHeaa33u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UvF7xiS5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UH6I04nE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UvF7xiS5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_N5SiBRa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Go2uwCmE, 0, m, &cVar_Go2uwCmE_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_6j78uC21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vAz0Q4n5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pEo2e7mQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ptjPWOfH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kkTbuh2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d53IA3Bu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_d53IA3Bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wK6Vp4JI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wK6Vp4JI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_IHgtZ4EF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vxUrPLM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uDTUtzUL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S4bQzDZ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S4bQzDZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j3rmmRi2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_uDTUtzUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QHeaa33u, 1, m, &cIf_QHeaa33u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rpKmzsKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UH6I04nE, 1, m, &cIf_UH6I04nE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j3rmmRi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_QHeaa33u, 0, m, &cIf_QHeaa33u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IHgtZ4EF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UH6I04nE, 0, m, &cIf_UH6I04nE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vAz0Q4n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_ptjPWOfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Go2uwCmE, 0, m, &cVar_Go2uwCmE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pEo2e7mQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kkTbuh2k, HV_BINOP_SUBTRACT, 1, m, &cBinop_kkTbuh2k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UvF7xiS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_66u6Ukwv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NduG5O0Z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_h0iVgWJP, 0, m, &cSlice_h0iVgWJP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_h0iVgWJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VRWi1Opp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VRWi1Opp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_FXSaRvBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VRWi1Opp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_VRWi1Opp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Iel6lz4q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hYRdKrpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Zja1w4Ff, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dPrAVSKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nn8fFKr1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_SzBR3Tn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IcgPfhtZ, 0, m, &cVar_IcgPfhtZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IWuXorDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YIazHxvq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_qfiI7xDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Gc5u02CN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vojmksV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JtZWwexe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2NpC1y7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I7K81zKl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JtZWwexe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I7K81zKl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hhWNy6r9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_h2ooEqWN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_h2ooEqWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7wHOMAb9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7wHOMAb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_emrotTTQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_xtFfayxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OHeRe5hh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_cWP0ASJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hZ8X4hmN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_tMDmTUC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mfD12kTt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_TGpRYBuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fYXNaqn0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_bSlh0NpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3pnrnlFU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_XSV5LPpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kplJo3No_sendMessage);
  cMsg_iEbUOzNC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kplJo3No_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XSV5LPpD, 1, m, &cVar_XSV5LPpD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kwbZJNa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ANhsNnTI_sendMessage(_c, 0, m);
  cMsg_mMV4pIz7_sendMessage(_c, 0, m);
  cMsg_RSbyjpa1_sendMessage(_c, 0, m);
  cMsg_U2ueglSn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GtQ3nRfH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4jOT5Aoq, 0, m, &cSlice_4jOT5Aoq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_4jOT5Aoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ILmNwhye_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ILmNwhye_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_XyhP9xvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ILmNwhye_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ILmNwhye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mgzoNqQo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_uSWq3gDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_km8YV6hD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_km8YV6hD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_rlhLyeba_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rlhLyeba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9sLWjAGb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9sLWjAGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_37GtA37w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GpFLZvGb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GpFLZvGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vcc4fpzb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_37GtA37w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vdNmMKGv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vdNmMKGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9cmCrZY9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vcc4fpzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AaMrd5e5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AaMrd5e5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oqLblaYE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9cmCrZY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d5uNsgtd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_oqLblaYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pCYHv2rb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_d5uNsgtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2kVhlrGH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pCYHv2rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7kKII2te, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_DF7LtATY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mLQyr1xb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ZCL93WMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_chtWHMs3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_w2vFes6j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mXUzw7SZ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dAoGnxd6_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n6riQhTp_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XRpMzoQx_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C3G16Rjx_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t9nN94hj_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_mXUzw7SZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bqvGXrko_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_dAoGnxd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y7Snbjp0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_n6riQhTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pz1MLd9W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XRpMzoQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UENx5G6k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_C3G16Rjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uBVxhTah_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_t9nN94hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yMJBdh0q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_aCsBsLEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_70fEdiUF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AXg0ZunC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g66KJoov_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JfusAeqE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1AxZAsYi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1AxZAsYi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8k1Le0Dd, 1, m, &cDelay_8k1Le0Dd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4jrCRH8P_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8k1Le0Dd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8k1Le0Dd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aCsBsLEm, 0, m, &cIf_aCsBsLEm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1AxZAsYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8k1Le0Dd, 0, m, &cDelay_8k1Le0Dd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4jrCRH8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8k1Le0Dd, 0, m, &cDelay_8k1Le0Dd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ieC1gHuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7WjCif99_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8JvF4aES_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wGWlpO15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b1katPD4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oDB8YNYq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b1katPD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aCsBsLEm, 1, m, &cIf_aCsBsLEm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oDB8YNYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JfusAeqE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7WjCif99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AXg0ZunC, 1, m, &cIf_AXg0ZunC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8JvF4aES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AXg0ZunC, 0, m, &cIf_AXg0ZunC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g66KJoov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2jBiqcyt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_70fEdiUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2jBiqcyt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_0iTlf6Xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kp8qLxhg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xOQS9BsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ARHaXdUK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nFU77uu1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wncLYTop_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wncLYTop_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wSSWi6xU, 1, m, &cDelay_wSSWi6xU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zGzYI9EW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wSSWi6xU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wSSWi6xU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0iTlf6Xd, 0, m, &cIf_0iTlf6Xd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wncLYTop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wSSWi6xU, 0, m, &cDelay_wSSWi6xU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zGzYI9EW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wSSWi6xU, 0, m, &cDelay_wSSWi6xU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FCJk8G7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eNaYdGVy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NQPNxOon_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aA9mquuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_whinEuXy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cqnPj4S2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cqnPj4S2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nFU77uu1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_whinEuXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0iTlf6Xd, 1, m, &cIf_0iTlf6Xd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NQPNxOon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xOQS9BsZ, 0, m, &cIf_xOQS9BsZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eNaYdGVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xOQS9BsZ, 1, m, &cIf_xOQS9BsZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ARHaXdUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FWY9PQO3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kp8qLxhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FWY9PQO3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_cw5SS9Ff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wErK60Ap_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RfKrrlqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RfBpyqZT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mllVnkWV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rWNjpUfo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rWNjpUfo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dtPJiDR0, 1, m, &cDelay_dtPJiDR0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U9I2aGjS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dtPJiDR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dtPJiDR0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cw5SS9Ff, 0, m, &cIf_cw5SS9Ff_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rWNjpUfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dtPJiDR0, 0, m, &cDelay_dtPJiDR0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U9I2aGjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dtPJiDR0, 0, m, &cDelay_dtPJiDR0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NaCWpDAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xIEC9x52_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_coHgNpLe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m0vVQm8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3g33BKZg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BFBaGtzs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3g33BKZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cw5SS9Ff, 1, m, &cIf_cw5SS9Ff_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BFBaGtzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mllVnkWV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xIEC9x52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RfKrrlqo, 1, m, &cIf_RfKrrlqo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_coHgNpLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RfKrrlqo, 0, m, &cIf_RfKrrlqo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RfBpyqZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5D4Wla7L, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wErK60Ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5D4Wla7L, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LPvpMByJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tgfrYwMy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bXzHE5NP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Pmizsnsu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eLQNyHmN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gtVRohrd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gtVRohrd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_S25SQiJO, 1, m, &cDelay_S25SQiJO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V1zJQ4x7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_S25SQiJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_S25SQiJO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LPvpMByJ, 0, m, &cIf_LPvpMByJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gtVRohrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_S25SQiJO, 0, m, &cDelay_S25SQiJO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V1zJQ4x7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_S25SQiJO, 0, m, &cDelay_S25SQiJO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WNcEVVYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FlTFuICn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vym1313I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_z75TD3oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h6a7sYY9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8BhWKGtV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8BhWKGtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eLQNyHmN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_h6a7sYY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LPvpMByJ, 1, m, &cIf_LPvpMByJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FlTFuICn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bXzHE5NP, 1, m, &cIf_bXzHE5NP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Vym1313I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bXzHE5NP, 0, m, &cIf_bXzHE5NP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Pmizsnsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FpvHjCof, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tgfrYwMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FpvHjCof, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Bx1he568_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lnkDjGBx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LHV9A3dT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CBaFet1X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Xzr8fmzD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hXPAuIHM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hXPAuIHM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_okc9aUyS, 1, m, &cDelay_okc9aUyS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tqYlbsv1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_okc9aUyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_okc9aUyS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Bx1he568, 0, m, &cIf_Bx1he568_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hXPAuIHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_okc9aUyS, 0, m, &cDelay_okc9aUyS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tqYlbsv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_okc9aUyS, 0, m, &cDelay_okc9aUyS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DmpbLcIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mRhcZaGi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TGOtucaK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_83Ee9UqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vn5en7VY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nEHmNKn1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nEHmNKn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Xzr8fmzD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Vn5en7VY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bx1he568, 1, m, &cIf_Bx1he568_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mRhcZaGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LHV9A3dT, 1, m, &cIf_LHV9A3dT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TGOtucaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LHV9A3dT, 0, m, &cIf_LHV9A3dT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CBaFet1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kPTb6DvY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lnkDjGBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kPTb6DvY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lWh4NveX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YNn8TOAI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_a8Gnu465_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5wr39Jdp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PeZr1O6O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9RnMzovu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9RnMzovu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dQssBt3o, 1, m, &cDelay_dQssBt3o_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pYz15Il9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dQssBt3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dQssBt3o, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lWh4NveX, 0, m, &cIf_lWh4NveX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9RnMzovu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dQssBt3o, 0, m, &cDelay_dQssBt3o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pYz15Il9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dQssBt3o, 0, m, &cDelay_dQssBt3o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9cvnmMGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kCDHleR9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TJDxVaWL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ACRa74Hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uI3fmwD5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aish53PC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uI3fmwD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lWh4NveX, 1, m, &cIf_lWh4NveX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aish53PC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PeZr1O6O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kCDHleR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a8Gnu465, 1, m, &cIf_a8Gnu465_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TJDxVaWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a8Gnu465, 0, m, &cIf_a8Gnu465_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5wr39Jdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cHtUmy29, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YNn8TOAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cHtUmy29, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_42uWl9tF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Eyu0MxmD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_40ilaPAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UaXCNl0y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Fpqk5YVg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mKmX10zQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mKmX10zQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_drLkwdsw, 1, m, &cDelay_drLkwdsw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hVNZPbey_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_drLkwdsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_drLkwdsw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_42uWl9tF, 0, m, &cIf_42uWl9tF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mKmX10zQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_drLkwdsw, 0, m, &cDelay_drLkwdsw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hVNZPbey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_drLkwdsw, 0, m, &cDelay_drLkwdsw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E1RGf09m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v5tAp2VR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_43pX5vXp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bjyYAFBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TBohOuEC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8OPp3rKW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TBohOuEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_42uWl9tF, 1, m, &cIf_42uWl9tF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8OPp3rKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Fpqk5YVg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_43pX5vXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_40ilaPAW, 0, m, &cIf_40ilaPAW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v5tAp2VR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_40ilaPAW, 1, m, &cIf_40ilaPAW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UaXCNl0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Cfo3mEtD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Eyu0MxmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Cfo3mEtD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fKyUZUAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9gV5bips_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9DadnTuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zvswXFPv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BILYYJqC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9sIom1oV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9sIom1oV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_g9vOhTcg, 1, m, &cDelay_g9vOhTcg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wKS4FWGa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_g9vOhTcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_g9vOhTcg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fKyUZUAM, 0, m, &cIf_fKyUZUAM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9sIom1oV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_g9vOhTcg, 0, m, &cDelay_g9vOhTcg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wKS4FWGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_g9vOhTcg, 0, m, &cDelay_g9vOhTcg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ojsOJVnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SYCO2iGJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aBHcAu2R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i2MKzCXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5mXotlTZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fttN6Q1n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fttN6Q1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BILYYJqC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5mXotlTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fKyUZUAM, 1, m, &cIf_fKyUZUAM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aBHcAu2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9DadnTuW, 0, m, &cIf_9DadnTuW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SYCO2iGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9DadnTuW, 1, m, &cIf_9DadnTuW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zvswXFPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nUCE0QFc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9gV5bips_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nUCE0QFc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CoCwY55j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_d8gKb5kC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DF3qDwSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_X7ms3sGT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cuLQAAls_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nSrMEG4y_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nSrMEG4y_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FAJQpcho, 1, m, &cDelay_FAJQpcho_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HoE6ueh2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FAJQpcho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FAJQpcho, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CoCwY55j, 0, m, &cIf_CoCwY55j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nSrMEG4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FAJQpcho, 0, m, &cDelay_FAJQpcho_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HoE6ueh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FAJQpcho, 0, m, &cDelay_FAJQpcho_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GU7TXdmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kt7qAUtY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I301RwRx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QZfA8bu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cu1qfRRY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_meiHy2zb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Cu1qfRRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CoCwY55j, 1, m, &cIf_CoCwY55j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_meiHy2zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cuLQAAls_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Kt7qAUtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DF3qDwSe, 1, m, &cIf_DF3qDwSe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I301RwRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DF3qDwSe, 0, m, &cIf_DF3qDwSe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_X7ms3sGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ww3slCCJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_d8gKb5kC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ww3slCCJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_rSnjPXkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_991wBet3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_g2JIkHm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rFR36bmT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YAluE0hy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JusTfHqW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JusTfHqW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZLESp67O, 1, m, &cDelay_ZLESp67O_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jUds5HS2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZLESp67O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZLESp67O, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rSnjPXkz, 0, m, &cIf_rSnjPXkz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JusTfHqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZLESp67O, 0, m, &cDelay_ZLESp67O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jUds5HS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZLESp67O, 0, m, &cDelay_ZLESp67O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NAov7HrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p1pBaxO6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5oY417Vm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gsCYndk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ky6P5qsB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1CbnnJST_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1CbnnJST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YAluE0hy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Ky6P5qsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rSnjPXkz, 1, m, &cIf_rSnjPXkz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5oY417Vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g2JIkHm1, 0, m, &cIf_g2JIkHm1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p1pBaxO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g2JIkHm1, 1, m, &cIf_g2JIkHm1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rFR36bmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ADU3pU8E, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_991wBet3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ADU3pU8E, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_eIfhc5mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_99m3hzTd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Hj6HjmAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rDWfi0xS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Fim1pYOk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aAvCMDFU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aAvCMDFU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8I1IWSgC, 1, m, &cDelay_8I1IWSgC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IsWnyKJF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8I1IWSgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8I1IWSgC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_eIfhc5mn, 0, m, &cIf_eIfhc5mn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aAvCMDFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8I1IWSgC, 0, m, &cDelay_8I1IWSgC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IsWnyKJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8I1IWSgC, 0, m, &cDelay_8I1IWSgC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nffg03xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JWNqPMJ6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MksjrFkh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iZTxL7EC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IIgpUdcM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UmwBJPaR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UmwBJPaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Fim1pYOk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_IIgpUdcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eIfhc5mn, 1, m, &cIf_eIfhc5mn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JWNqPMJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hj6HjmAR, 1, m, &cIf_Hj6HjmAR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MksjrFkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hj6HjmAR, 0, m, &cIf_Hj6HjmAR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rDWfi0xS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OVIIniNx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_99m3hzTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OVIIniNx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_P0IWq08B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ejKduMqE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WFtGt8Hu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SliyFgEK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nn8aPqnu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MMucMdCw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MMucMdCw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qICwEPCw, 1, m, &cDelay_qICwEPCw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SvtYUsKw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qICwEPCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qICwEPCw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_P0IWq08B, 0, m, &cIf_P0IWq08B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MMucMdCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qICwEPCw, 0, m, &cDelay_qICwEPCw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SvtYUsKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qICwEPCw, 0, m, &cDelay_qICwEPCw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7bRd35HP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_esQIeCck_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_faUlKZTl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VymvE6S6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WX12dm2q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XREg0YMY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WX12dm2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P0IWq08B, 1, m, &cIf_P0IWq08B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XREg0YMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nn8aPqnu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_faUlKZTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WFtGt8Hu, 0, m, &cIf_WFtGt8Hu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_esQIeCck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WFtGt8Hu, 1, m, &cIf_WFtGt8Hu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SliyFgEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_olLnLmzE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ejKduMqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_olLnLmzE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bqvGXrko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_T2v828UL_sendMessage(_c, 0, m);
  cMsg_vYrHmuda_sendMessage(_c, 0, m);
  cMsg_fYOOOovf_sendMessage(_c, 0, m);
  cMsg_G8dt8W1W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Y7Snbjp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_T2v828UL_sendMessage(_c, 0, m);
  cMsg_OshpkGc6_sendMessage(_c, 0, m);
  cMsg_4TKYQFF0_sendMessage(_c, 0, m);
  cMsg_GsyMnX4p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Pz1MLd9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_YZ1I6aP6_sendMessage(_c, 0, m);
  cMsg_OshpkGc6_sendMessage(_c, 0, m);
  cMsg_G8dt8W1W_sendMessage(_c, 0, m);
  cMsg_klTtRIi9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UENx5G6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_YZ1I6aP6_sendMessage(_c, 0, m);
  cMsg_8XiWv57F_sendMessage(_c, 0, m);
  cMsg_fYOOOovf_sendMessage(_c, 0, m);
  cMsg_MSpBAMr2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uBVxhTah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_0hqaVlKH_sendMessage(_c, 0, m);
  cMsg_GsyMnX4p_sendMessage(_c, 0, m);
  cMsg_RPYG6KGE_sendMessage(_c, 0, m);
  cMsg_fYOOOovf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yMJBdh0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_0hqaVlKH_sendMessage(_c, 0, m);
  cMsg_MSpBAMr2_sendMessage(_c, 0, m);
  cMsg_OshpkGc6_sendMessage(_c, 0, m);
  cMsg_0viomyCp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_40wzw0u2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wGWlpO15_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ieC1gHuj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GX9gkeQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wGWlpO15_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ieC1gHuj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3091j1i6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aA9mquuK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FCJk8G7r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hg24o65s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aA9mquuK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FCJk8G7r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FF5cWYob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_m0vVQm8l_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NaCWpDAX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VTQ7wDMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_m0vVQm8l_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NaCWpDAX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T2v828UL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_40wzw0u2_sendMessage(_c, 0, m);
  cMsg_hg24o65s_sendMessage(_c, 0, m);
  cMsg_VTQ7wDMC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YZ1I6aP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_GX9gkeQK_sendMessage(_c, 0, m);
  cMsg_3091j1i6_sendMessage(_c, 0, m);
  cMsg_VTQ7wDMC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0hqaVlKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_GX9gkeQK_sendMessage(_c, 0, m);
  cMsg_hg24o65s_sendMessage(_c, 0, m);
  cMsg_FF5cWYob_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jPvvb5JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_z75TD3oi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WNcEVVYH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EiqPvKXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_z75TD3oi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WNcEVVYH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h1vtUdzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_83Ee9UqT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DmpbLcIQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_v1XLbuee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_83Ee9UqT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DmpbLcIQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xxuRmRE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ACRa74Hb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9cvnmMGD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PlIhXRlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ACRa74Hb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9cvnmMGD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OshpkGc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_EiqPvKXq_sendMessage(_c, 0, m);
  cMsg_v1XLbuee_sendMessage(_c, 0, m);
  cMsg_PlIhXRlO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vYrHmuda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_EiqPvKXq_sendMessage(_c, 0, m);
  cMsg_h1vtUdzr_sendMessage(_c, 0, m);
  cMsg_xxuRmRE2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8XiWv57F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_jPvvb5JM_sendMessage(_c, 0, m);
  cMsg_v1XLbuee_sendMessage(_c, 0, m);
  cMsg_xxuRmRE2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_b8uANh5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gsCYndk4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NAov7HrL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_X1EQmUeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gsCYndk4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NAov7HrL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_koGBwIkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iZTxL7EC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nffg03xr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TUB6X0aZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iZTxL7EC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nffg03xr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_clV1JI4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VymvE6S6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7bRd35HP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9hJSiqI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VymvE6S6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7bRd35HP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MSpBAMr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_b8uANh5f_sendMessage(_c, 0, m);
  cMsg_TUB6X0aZ_sendMessage(_c, 0, m);
  cMsg_9hJSiqI6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GsyMnX4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_X1EQmUeS_sendMessage(_c, 0, m);
  cMsg_koGBwIkG_sendMessage(_c, 0, m);
  cMsg_9hJSiqI6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_G8dt8W1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_X1EQmUeS_sendMessage(_c, 0, m);
  cMsg_TUB6X0aZ_sendMessage(_c, 0, m);
  cMsg_clV1JI4m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ru3aMwyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bjyYAFBn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E1RGf09m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aXh7NQWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bjyYAFBn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_E1RGf09m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d6LSOd5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i2MKzCXf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ojsOJVnt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3VXVASj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i2MKzCXf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ojsOJVnt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xmZClu80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QZfA8bu8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GU7TXdmF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TQYtWZJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QZfA8bu8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GU7TXdmF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fYOOOovf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_aXh7NQWI_sendMessage(_c, 0, m);
  cMsg_3VXVASj4_sendMessage(_c, 0, m);
  cMsg_TQYtWZJ9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4TKYQFF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_aXh7NQWI_sendMessage(_c, 0, m);
  cMsg_d6LSOd5E_sendMessage(_c, 0, m);
  cMsg_xmZClu80_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0viomyCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Ru3aMwyG_sendMessage(_c, 0, m);
  cMsg_d6LSOd5E_sendMessage(_c, 0, m);
  cMsg_TQYtWZJ9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RPYG6KGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_jPvvb5JM_sendMessage(_c, 0, m);
  cMsg_h1vtUdzr_sendMessage(_c, 0, m);
  cMsg_PlIhXRlO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_klTtRIi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Ru3aMwyG_sendMessage(_c, 0, m);
  cMsg_3VXVASj4_sendMessage(_c, 0, m);
  cMsg_xmZClu80_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_d0UIHWkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oQsNdkI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RHieMXa8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TMxj7QA6, 0, m, &cSlice_TMxj7QA6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Xa361ji9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_TMxj7QA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Rq7LtkPn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Rq7LtkPn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_1oGPpB75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Rq7LtkPn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Rq7LtkPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_51vfUzSe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_b8j7NUZh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ifgaJRn1, 0, m, &cSlice_ifgaJRn1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PTWrVyNR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ifgaJRn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eSScv00i_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eSScv00i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_oqHWbQht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eSScv00i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_eSScv00i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RuuYyErg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PTWrVyNR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p6s6QNQs, 0, m, &cSlice_p6s6QNQs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RHieMXa8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_p6s6QNQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dhNvvfTP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dhNvvfTP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_xojiIr5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dhNvvfTP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dhNvvfTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hcDUm7kb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Xa361ji9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_C8CKU8O1, 0, m, &cSlice_C8CKU8O1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fciWUyzB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_C8CKU8O1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CPgySoO6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CPgySoO6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_uHYAOPZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CPgySoO6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_CPgySoO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WkS6PeY3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fciWUyzB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3Egxs0Qh, 0, m, &cSlice_3Egxs0Qh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yQdUXCV7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_3Egxs0Qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Y3KyuoQs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Y3KyuoQs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_wSIQhArf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Y3KyuoQs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Y3KyuoQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RAP7wnER_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_c4WkCm6E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HA1feX1E_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HA1feX1E_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_H6pNhDtd, 1, m, &cDelay_H6pNhDtd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z89GLV1H_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_H6pNhDtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_H6pNhDtd, m);
  cMsg_1bv61oMX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HA1feX1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_H6pNhDtd, 0, m, &cDelay_H6pNhDtd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z89GLV1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_H6pNhDtd, 0, m, &cDelay_H6pNhDtd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_uMxkK7pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qMxT4q5F, HV_BINOP_SUBTRACT, 0, m, &cBinop_qMxT4q5F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_aVfvLGjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2fyAqyG2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_O7i9Vdq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2fyAqyG2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_B0dIa2Pd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uMxkK7pw, 0, m, &cVar_uMxkK7pw_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_JxZZHewb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e5HolJda_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8vboDBr4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Fj8peNQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qMxT4q5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cb855CLB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cb855CLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hMa8DQTp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hMa8DQTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_UTr5OFGL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tpKmon4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t3pk2peW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_USr5Zu9z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t3pk2peW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aVfvLGjq, 1, m, &cIf_aVfvLGjq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_USr5Zu9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gNV0rmVg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_YPsn0aZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O7i9Vdq8, 1, m, &cIf_O7i9Vdq8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gNV0rmVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aVfvLGjq, 0, m, &cIf_aVfvLGjq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UTr5OFGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O7i9Vdq8, 0, m, &cIf_O7i9Vdq8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e5HolJda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_8vboDBr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qMxT4q5F, HV_BINOP_SUBTRACT, 1, m, &cBinop_qMxT4q5F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0Fj8peNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uMxkK7pw, 0, m, &cVar_uMxkK7pw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2fyAqyG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h40aHv3q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yQdUXCV7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_j3DiTLfh, 0, m, &cSlice_j3DiTLfh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_j3DiTLfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YXB88NiJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YXB88NiJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GZcoSQBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YXB88NiJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_YXB88NiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fVdOB1J5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mLQyr1xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v6lZF7Jr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_chtWHMs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7VL79Njo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_c7g6eaMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZCL93WMB, 0, m, &cVar_ZCL93WMB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oQsNdkI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_A4iUqYeO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5OtXcAuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uW2RWb6L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_IVhzlfdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_c4WkCm6E_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1bv61oMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Apfcv8qH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uW2RWb6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Apfcv8qH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LnjoSa1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_5nuBDdCo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5nuBDdCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EYE4F4N4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EYE4F4N4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t3sCLgyX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_H6tWrHtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5OOr7APc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_RaDelSIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H3bE1kpx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zIlX0k5b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tVcqSuNx_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xNwG4IOM_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kYzIsSEE_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LIpOIkVH_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gcc1nagS_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u27C7IoU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_tVcqSuNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_inz70kEC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_xNwG4IOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LqkUL26v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_kYzIsSEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hQF71UP7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_LIpOIkVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ix8A7sF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_gcc1nagS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8pFiuEpO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_u27C7IoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_csFcRnVv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_xxXZ3ova_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_G89Icuqm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zPHeFrlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_13oTfUUJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DDcPvBpU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SVHeaNWS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SVHeaNWS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qWh8vqfn, 1, m, &cDelay_qWh8vqfn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ykEVYaTT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qWh8vqfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qWh8vqfn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xxXZ3ova, 0, m, &cIf_xxXZ3ova_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SVHeaNWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qWh8vqfn, 0, m, &cDelay_qWh8vqfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ykEVYaTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qWh8vqfn, 0, m, &cDelay_qWh8vqfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WXOaJIVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TfbrfA55_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ImqN058t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_maSLtTUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vkbTx5qd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ncy2DURW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ncy2DURW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DDcPvBpU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vkbTx5qd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xxXZ3ova, 1, m, &cIf_xxXZ3ova_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TfbrfA55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zPHeFrlC, 1, m, &cIf_zPHeFrlC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ImqN058t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zPHeFrlC, 0, m, &cIf_zPHeFrlC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_13oTfUUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BtddmSqq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_G89Icuqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BtddmSqq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_wadgKbMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3Of1u8tx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xaGdbLJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O2RCDpQf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7XMw3EWx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pdqwEaLd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pdqwEaLd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_w1FSZynK, 1, m, &cDelay_w1FSZynK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ULwxdwAr_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_w1FSZynK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_w1FSZynK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wadgKbMN, 0, m, &cIf_wadgKbMN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pdqwEaLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_w1FSZynK, 0, m, &cDelay_w1FSZynK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ULwxdwAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_w1FSZynK, 0, m, &cDelay_w1FSZynK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YltaRMke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EXVFJsCE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vvmOiKcl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D0WqWuE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4S4qZQMM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0j6vUbeG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0j6vUbeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7XMw3EWx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4S4qZQMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wadgKbMN, 1, m, &cIf_wadgKbMN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vvmOiKcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xaGdbLJH, 0, m, &cIf_xaGdbLJH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EXVFJsCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xaGdbLJH, 1, m, &cIf_xaGdbLJH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O2RCDpQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e6Thk3AC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3Of1u8tx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e6Thk3AC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_dJvaFWBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6nxQjNeB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_x24q4YMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BUdI4JR1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9pIHUJLV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FbDqBDJw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FbDqBDJw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wjMhw4yg, 1, m, &cDelay_wjMhw4yg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7hgRMj9H_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wjMhw4yg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wjMhw4yg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dJvaFWBE, 0, m, &cIf_dJvaFWBE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FbDqBDJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wjMhw4yg, 0, m, &cDelay_wjMhw4yg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7hgRMj9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wjMhw4yg, 0, m, &cDelay_wjMhw4yg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_alEsK1Vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HPPIt0FW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hDrB5TaW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P4LWNhFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BH7E5etO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b3e0yuJo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b3e0yuJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9pIHUJLV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BH7E5etO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dJvaFWBE, 1, m, &cIf_dJvaFWBE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hDrB5TaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x24q4YMN, 0, m, &cIf_x24q4YMN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HPPIt0FW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x24q4YMN, 1, m, &cIf_x24q4YMN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BUdI4JR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6o9dr5e7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6nxQjNeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6o9dr5e7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bv5kOKAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aUQId1v1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZHwwvLsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fyVTkQQE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xvRh5OHt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_R0q7aLii_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_R0q7aLii_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_iFWnr6uI, 1, m, &cDelay_iFWnr6uI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PDTXVEgq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_iFWnr6uI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iFWnr6uI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bv5kOKAo, 0, m, &cIf_bv5kOKAo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R0q7aLii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_iFWnr6uI, 0, m, &cDelay_iFWnr6uI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PDTXVEgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iFWnr6uI, 0, m, &cDelay_iFWnr6uI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K4Pzzt50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T0PIgvvM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KNBUDKkz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aMJyVFNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8rRmJOD6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xu9PEajw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Xu9PEajw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xvRh5OHt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8rRmJOD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bv5kOKAo, 1, m, &cIf_bv5kOKAo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KNBUDKkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZHwwvLsT, 0, m, &cIf_ZHwwvLsT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T0PIgvvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZHwwvLsT, 1, m, &cIf_ZHwwvLsT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fyVTkQQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fg4rdsLb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aUQId1v1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fg4rdsLb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RjMA7dsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_k2PZFdZq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_mahygbl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_V7g1D0LE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5vlZeFX1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ybmy9huW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ybmy9huW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZqUCMNgu, 1, m, &cDelay_ZqUCMNgu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WL1bm9Er_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZqUCMNgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZqUCMNgu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RjMA7dsG, 0, m, &cIf_RjMA7dsG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ybmy9huW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZqUCMNgu, 0, m, &cDelay_ZqUCMNgu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WL1bm9Er_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZqUCMNgu, 0, m, &cDelay_ZqUCMNgu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sFx2Z9dT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6I214ULc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RwlkHFyq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gdHkUuj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vsY3jScy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n8r7KY58_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n8r7KY58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5vlZeFX1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vsY3jScy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RjMA7dsG, 1, m, &cIf_RjMA7dsG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RwlkHFyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mahygbl4, 0, m, &cIf_mahygbl4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6I214ULc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mahygbl4, 1, m, &cIf_mahygbl4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_V7g1D0LE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s5YJ384D, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_k2PZFdZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s5YJ384D, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BZNcsPfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PwlM3kZF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_uYHBcyBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bvmxDnja_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JCIdrIpb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uY3DHqRU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uY3DHqRU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ieuZPlxO, 1, m, &cDelay_ieuZPlxO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xSsvZPUQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ieuZPlxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ieuZPlxO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BZNcsPfW, 0, m, &cIf_BZNcsPfW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uY3DHqRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ieuZPlxO, 0, m, &cDelay_ieuZPlxO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xSsvZPUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ieuZPlxO, 0, m, &cDelay_ieuZPlxO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ptdo2r3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JZuPdjdg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z3BizOM5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fwLS7HNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CofrjgsZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bq1WFyAn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bq1WFyAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JCIdrIpb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CofrjgsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BZNcsPfW, 1, m, &cIf_BZNcsPfW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z3BizOM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uYHBcyBu, 0, m, &cIf_uYHBcyBu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JZuPdjdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uYHBcyBu, 1, m, &cIf_uYHBcyBu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bvmxDnja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pFzcvv2s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PwlM3kZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pFzcvv2s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_C6fBjYHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ckUy02uo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XzzZRJSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3jeAdHkM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_urBb2jgJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6SbAPrC7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6SbAPrC7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ogNOkBKr, 1, m, &cDelay_ogNOkBKr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jNRO3Qcb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ogNOkBKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ogNOkBKr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_C6fBjYHl, 0, m, &cIf_C6fBjYHl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6SbAPrC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ogNOkBKr, 0, m, &cDelay_ogNOkBKr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jNRO3Qcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ogNOkBKr, 0, m, &cDelay_ogNOkBKr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T7m2wmhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MQFutgPs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Ame8VAM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n2GH0wrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FRCeiY7R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_93iQFbxI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_93iQFbxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_urBb2jgJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FRCeiY7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_C6fBjYHl, 1, m, &cIf_C6fBjYHl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5Ame8VAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XzzZRJSg, 0, m, &cIf_XzzZRJSg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MQFutgPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XzzZRJSg, 1, m, &cIf_XzzZRJSg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3jeAdHkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5Xd2g0VE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ckUy02uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5Xd2g0VE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ou3JvxHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aC69naGy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_le3XEfkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IEdZwEns_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oduNcXEf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AawD9fW6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AawD9fW6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kOVoW3dT, 1, m, &cDelay_kOVoW3dT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2l3Z8RFs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kOVoW3dT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kOVoW3dT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ou3JvxHS, 0, m, &cIf_Ou3JvxHS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AawD9fW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kOVoW3dT, 0, m, &cDelay_kOVoW3dT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2l3Z8RFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kOVoW3dT, 0, m, &cDelay_kOVoW3dT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JXPNZ2QK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZijPuKx2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ugqvIku9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s7JReYW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wJJBr60v_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pB6ad9iM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wJJBr60v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ou3JvxHS, 1, m, &cIf_Ou3JvxHS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pB6ad9iM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oduNcXEf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZijPuKx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_le3XEfkY, 1, m, &cIf_le3XEfkY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ugqvIku9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_le3XEfkY, 0, m, &cIf_le3XEfkY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IEdZwEns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fSsM6t4s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aC69naGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fSsM6t4s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_uQGVnhVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_G1x4v3Ee_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XrS5qDui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bwGXisyU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_W4V9BHHj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gvfToCdc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gvfToCdc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HMTWMqaf, 1, m, &cDelay_HMTWMqaf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BOWUwNIe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HMTWMqaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HMTWMqaf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uQGVnhVf, 0, m, &cIf_uQGVnhVf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gvfToCdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HMTWMqaf, 0, m, &cDelay_HMTWMqaf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BOWUwNIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HMTWMqaf, 0, m, &cDelay_HMTWMqaf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Iyg9WeuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pnTQXoGL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jefY1FyA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rVqLhC4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_11y9dmNV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MgAHylVZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MgAHylVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_W4V9BHHj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_11y9dmNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uQGVnhVf, 1, m, &cIf_uQGVnhVf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pnTQXoGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XrS5qDui, 1, m, &cIf_XrS5qDui_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jefY1FyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XrS5qDui, 0, m, &cIf_XrS5qDui_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bwGXisyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J5to9nmY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_G1x4v3Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J5to9nmY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_P2Kenpl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6tk1bGHs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Gk4DGgPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o93o6mau_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_86NgaF6S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KMODRftP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KMODRftP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lL1RMxyR, 1, m, &cDelay_lL1RMxyR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Tgw1212_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_lL1RMxyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lL1RMxyR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_P2Kenpl7, 0, m, &cIf_P2Kenpl7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KMODRftP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lL1RMxyR, 0, m, &cDelay_lL1RMxyR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7Tgw1212_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lL1RMxyR, 0, m, &cDelay_lL1RMxyR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TQElRaeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oKpiwDXc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WM1HaNWw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d1ICQ6qT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T6gIPMxl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A7Avkq2r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A7Avkq2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_86NgaF6S_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_T6gIPMxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P2Kenpl7, 1, m, &cIf_P2Kenpl7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WM1HaNWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gk4DGgPY, 0, m, &cIf_Gk4DGgPY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oKpiwDXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gk4DGgPY, 1, m, &cIf_Gk4DGgPY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o93o6mau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nvtTWWvs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6tk1bGHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nvtTWWvs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_74qCo3HX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SvGH40dy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6X5rnLnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tuAYE7TY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jGoO3GQq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CfdtReqP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CfdtReqP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tkYB9df6, 1, m, &cDelay_tkYB9df6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wCCj8CYb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tkYB9df6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tkYB9df6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_74qCo3HX, 0, m, &cIf_74qCo3HX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CfdtReqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tkYB9df6, 0, m, &cDelay_tkYB9df6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wCCj8CYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tkYB9df6, 0, m, &cDelay_tkYB9df6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7MB93t3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2W42WZBv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vJ57nDt6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TP1MA4ph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PGypzKeH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_klh5WSst_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_klh5WSst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jGoO3GQq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_PGypzKeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_74qCo3HX, 1, m, &cIf_74qCo3HX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2W42WZBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6X5rnLnb, 1, m, &cIf_6X5rnLnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vJ57nDt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6X5rnLnb, 0, m, &cIf_6X5rnLnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tuAYE7TY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DlyL8j4R, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SvGH40dy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DlyL8j4R, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Voki0qLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O9FZIIm2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_H0CP8gp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dRwmHENJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_s2B79gx4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3J63ElNV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3J63ElNV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Xn0zaNKk, 1, m, &cDelay_Xn0zaNKk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3BvGgyQl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Xn0zaNKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Xn0zaNKk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Voki0qLv, 0, m, &cIf_Voki0qLv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3J63ElNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xn0zaNKk, 0, m, &cDelay_Xn0zaNKk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3BvGgyQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xn0zaNKk, 0, m, &cDelay_Xn0zaNKk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_waDxyEFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Re4ERsuW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lrK8Qzcj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NymnyaFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OwILiXrL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uH6ZkeFx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OwILiXrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Voki0qLv, 1, m, &cIf_Voki0qLv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uH6ZkeFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_s2B79gx4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Re4ERsuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H0CP8gp8, 1, m, &cIf_H0CP8gp8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lrK8Qzcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H0CP8gp8, 0, m, &cIf_H0CP8gp8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dRwmHENJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zKnnP0vm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_O9FZIIm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zKnnP0vm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_inz70kEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_Lbc8uX7l_sendMessage(_c, 0, m);
  cMsg_UH1OL7n2_sendMessage(_c, 0, m);
  cMsg_NwyWCnLG_sendMessage(_c, 0, m);
  cMsg_8izmPyVM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LqkUL26v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_Lbc8uX7l_sendMessage(_c, 0, m);
  cMsg_KEiL2itd_sendMessage(_c, 0, m);
  cMsg_IEK5dTCb_sendMessage(_c, 0, m);
  cMsg_5kSv1HMk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hQF71UP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_6Y8nwU2s_sendMessage(_c, 0, m);
  cMsg_KEiL2itd_sendMessage(_c, 0, m);
  cMsg_8izmPyVM_sendMessage(_c, 0, m);
  cMsg_9zbgjiad_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6ix8A7sF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_6Y8nwU2s_sendMessage(_c, 0, m);
  cMsg_TORzfss7_sendMessage(_c, 0, m);
  cMsg_NwyWCnLG_sendMessage(_c, 0, m);
  cMsg_aiZWPXHP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8pFiuEpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_wbFwM2KM_sendMessage(_c, 0, m);
  cMsg_5kSv1HMk_sendMessage(_c, 0, m);
  cMsg_dUxO9ooH_sendMessage(_c, 0, m);
  cMsg_NwyWCnLG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_csFcRnVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_wbFwM2KM_sendMessage(_c, 0, m);
  cMsg_aiZWPXHP_sendMessage(_c, 0, m);
  cMsg_KEiL2itd_sendMessage(_c, 0, m);
  cMsg_Yl5jRlz2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_T4xjDKxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_maSLtTUd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WXOaJIVs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H05ns03B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_maSLtTUd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WXOaJIVs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ApqB4Cou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_D0WqWuE6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YltaRMke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4aw3Uc8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_D0WqWuE6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YltaRMke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MlUxZb2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_P4LWNhFg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_alEsK1Vu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ak361eIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_P4LWNhFg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_alEsK1Vu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Lbc8uX7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_T4xjDKxT_sendMessage(_c, 0, m);
  cMsg_4aw3Uc8B_sendMessage(_c, 0, m);
  cMsg_Ak361eIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6Y8nwU2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_H05ns03B_sendMessage(_c, 0, m);
  cMsg_ApqB4Cou_sendMessage(_c, 0, m);
  cMsg_Ak361eIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wbFwM2KM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_H05ns03B_sendMessage(_c, 0, m);
  cMsg_4aw3Uc8B_sendMessage(_c, 0, m);
  cMsg_MlUxZb2Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BphhwKvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aMJyVFNO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_K4Pzzt50_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AAJmHp1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aMJyVFNO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_K4Pzzt50_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4RzU352q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gdHkUuj9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sFx2Z9dT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_q8V4UuLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gdHkUuj9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sFx2Z9dT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cIjFjKkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fwLS7HNS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ptdo2r3o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0E0lvfpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fwLS7HNS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ptdo2r3o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KEiL2itd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_AAJmHp1v_sendMessage(_c, 0, m);
  cMsg_q8V4UuLD_sendMessage(_c, 0, m);
  cMsg_0E0lvfpE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UH1OL7n2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_AAJmHp1v_sendMessage(_c, 0, m);
  cMsg_4RzU352q_sendMessage(_c, 0, m);
  cMsg_cIjFjKkN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TORzfss7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_BphhwKvs_sendMessage(_c, 0, m);
  cMsg_q8V4UuLD_sendMessage(_c, 0, m);
  cMsg_cIjFjKkN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QIBUwpy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_d1ICQ6qT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TQElRaeX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3Cdr1bnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_d1ICQ6qT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TQElRaeX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_D3WgNJyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TP1MA4ph_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7MB93t3V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XV4tGm4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TP1MA4ph_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7MB93t3V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JhT2vQXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NymnyaFz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_waDxyEFl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GkRnMWvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NymnyaFz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_waDxyEFl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aiZWPXHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_QIBUwpy7_sendMessage(_c, 0, m);
  cMsg_XV4tGm4G_sendMessage(_c, 0, m);
  cMsg_GkRnMWvP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5kSv1HMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_3Cdr1bnk_sendMessage(_c, 0, m);
  cMsg_D3WgNJyQ_sendMessage(_c, 0, m);
  cMsg_GkRnMWvP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8izmPyVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_3Cdr1bnk_sendMessage(_c, 0, m);
  cMsg_XV4tGm4G_sendMessage(_c, 0, m);
  cMsg_JhT2vQXj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xFTFRYsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n2GH0wrv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T7m2wmhX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8fLzUoiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n2GH0wrv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T7m2wmhX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Mibrq90j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_s7JReYW0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JXPNZ2QK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AA6JQKjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_s7JReYW0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JXPNZ2QK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NQdFdPKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rVqLhC4E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Iyg9WeuL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fu5HyXlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rVqLhC4E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Iyg9WeuL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NwyWCnLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_8fLzUoiV_sendMessage(_c, 0, m);
  cMsg_AA6JQKjB_sendMessage(_c, 0, m);
  cMsg_fu5HyXlc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IEK5dTCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_8fLzUoiV_sendMessage(_c, 0, m);
  cMsg_Mibrq90j_sendMessage(_c, 0, m);
  cMsg_NQdFdPKQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Yl5jRlz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_xFTFRYsD_sendMessage(_c, 0, m);
  cMsg_Mibrq90j_sendMessage(_c, 0, m);
  cMsg_fu5HyXlc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dUxO9ooH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_BphhwKvs_sendMessage(_c, 0, m);
  cMsg_4RzU352q_sendMessage(_c, 0, m);
  cMsg_0E0lvfpE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9zbgjiad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_xFTFRYsD_sendMessage(_c, 0, m);
  cMsg_AA6JQKjB_sendMessage(_c, 0, m);
  cMsg_NQdFdPKQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Y7wMgskn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fQNzoxz1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2xK6ZuaQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Er5nW4c6, 0, m, &cSlice_Er5nW4c6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QPjVrzlD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Er5nW4c6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1ijIymWo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1ijIymWo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Wh6DFBLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1ijIymWo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_1ijIymWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eA7r5huO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MXJ3wyBt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_38pT8oAg, 0, m, &cSlice_38pT8oAg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_g1OBJTfb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_38pT8oAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9BKYjA1s_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9BKYjA1s_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3c9IS2cT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9BKYjA1s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9BKYjA1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pFIjw5Wz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_g1OBJTfb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_79wymP7u, 0, m, &cSlice_79wymP7u_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2xK6ZuaQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_79wymP7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bCnMwbsA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bCnMwbsA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_AVUqBteI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bCnMwbsA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_bCnMwbsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_24rle8iv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QPjVrzlD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NYJVyIkc, 0, m, &cSlice_NYJVyIkc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pQzKvLUf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_NYJVyIkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RmPjrXK8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RmPjrXK8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_K6HQJSNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RmPjrXK8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_RmPjrXK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QrDn1mPB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pQzKvLUf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_USRkBA0C, 0, m, &cSlice_USRkBA0C_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gSZAhNqH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_USRkBA0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_08J54KEq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_08J54KEq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TzYs2DSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_08J54KEq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_08J54KEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HgfLG95u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_upBZ5ChN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qFOg37wo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qFOg37wo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ec8dCN4v, 1, m, &cDelay_ec8dCN4v_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dMDCAMiU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ec8dCN4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ec8dCN4v, m);
  cMsg_dUeFIo0v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qFOg37wo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ec8dCN4v, 0, m, &cDelay_ec8dCN4v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dMDCAMiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ec8dCN4v, 0, m, &cDelay_ec8dCN4v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_YlXlUBxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSUrOmhG, HV_BINOP_SUBTRACT, 0, m, &cBinop_sSUrOmhG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_SFPiEieY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QCZUfWbg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5S13HbR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QCZUfWbg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_8KVf23yW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YlXlUBxL, 0, m, &cVar_YlXlUBxL_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_ces4OKNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1kNIUGn0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rtAq4Gc4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yV37AOeP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sSUrOmhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6bHxpV9A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6bHxpV9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HsyHgLRT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HsyHgLRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9nXO03vN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OiSCg6Pi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_myRbWXZr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pLaCSSX6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_myRbWXZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SFPiEieY, 1, m, &cIf_SFPiEieY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pLaCSSX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_80lkTkI6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CjPr0kXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5S13HbR2, 1, m, &cIf_5S13HbR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_80lkTkI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_SFPiEieY, 0, m, &cIf_SFPiEieY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9nXO03vN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5S13HbR2, 0, m, &cIf_5S13HbR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1kNIUGn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_rtAq4Gc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSUrOmhG, HV_BINOP_SUBTRACT, 1, m, &cBinop_sSUrOmhG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yV37AOeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YlXlUBxL, 0, m, &cVar_YlXlUBxL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QCZUfWbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lKRGoCU4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gSZAhNqH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_x1NTl6kd, 0, m, &cSlice_x1NTl6kd_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_x1NTl6kd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WZQOBSWU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WZQOBSWU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_nfB2srwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WZQOBSWU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WZQOBSWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hFpLHC2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5OOr7APc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lzzAREx4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_H3bE1kpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7OC7X3OX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_Ep2y4lbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RaDelSIk, 0, m, &cVar_RaDelSIk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fQNzoxz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yaHtpyqH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_36Qe5fkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_upBZ5ChN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XhEGfdM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qsRKurZ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dUeFIo0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tb6keyZu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qsRKurZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tb6keyZu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9udVkbYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_bpBi4490_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bpBi4490_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PqYTlrQF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PqYTlrQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xXjR9Ejs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_qPd9KWMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G0S4XgvZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_7zcss8Lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_poEf5ZBs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_BAcoilxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tTb0UrbG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jVs3QFuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4jLA8MQ9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SSdFB1BG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_EgKH64Xo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GrCXjcUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4jLA8MQ9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SSdFB1BG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_EgKH64Xo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_YlwjMf4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CJNpCzO7, 0, m, &cVar_CJNpCzO7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uISm3oDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4jLA8MQ9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SSdFB1BG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_EgKH64Xo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TY7GN3RT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4jLA8MQ9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SSdFB1BG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_EgKH64Xo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rSaujatK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4jLA8MQ9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SSdFB1BG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_EgKH64Xo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Xhieze1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_RYamJPXe, 0, m, &cVar_RYamJPXe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3gz60OtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_KaL8GEYA, 0, m, &cVar_KaL8GEYA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kvFRpE5E, 0, m, &cVar_kvFRpE5E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mHb3A5S0, 0, m, &cVar_mHb3A5S0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GBZZmcsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_YlwjMf4Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wsIE1Yu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_gvnY34tY_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qnmKkh3R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oY90mCnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_gvnY34tY_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qnmKkh3R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_E7hn5Nhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_gvnY34tY_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qnmKkh3R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bhU9319B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_gvnY34tY_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qnmKkh3R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jS3fWsnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_gvnY34tY_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qnmKkh3R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hOzKomQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_fBeNiR6V, 0, m, &cVar_fBeNiR6V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jn4Q9EqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_CKlHhUX6, 0, m, &cVar_CKlHhUX6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9WuZS8VQ, 0, m, &cVar_9WuZS8VQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z6hYpUpg, 0, m, &cVar_Z6hYpUpg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YEpBYa2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4jLA8MQ9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SSdFB1BG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_EgKH64Xo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_H6vZSYnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Txkdnz4a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FSmdS8S3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TV2VbYSQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_A7syGe3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Txkdnz4a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FSmdS8S3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TV2VbYSQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_0mM9T7K4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zKu5bJPS, 0, m, &cVar_zKu5bJPS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CmMJ8MrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Txkdnz4a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FSmdS8S3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TV2VbYSQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QLRdpekW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Txkdnz4a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FSmdS8S3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TV2VbYSQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9hqUlon3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Txkdnz4a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FSmdS8S3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TV2VbYSQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UNcFmSLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_4ewJkT60, 0, m, &cVar_4ewJkT60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pgWaj605_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_R6cUEzWq, 0, m, &cVar_R6cUEzWq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NOIff12y, 0, m, &cVar_NOIff12y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zT7eAdd0, 0, m, &cVar_zT7eAdd0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ca2ku1Cv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_0mM9T7K4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U44WWANL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Txkdnz4a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FSmdS8S3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TV2VbYSQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OHeRe5hh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtQ3nRfH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_b8j7NUZh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MXJ3wyBt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fYXNaqn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtQ3nRfH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_b8j7NUZh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MXJ3wyBt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_yq7ZL24e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cWP0ASJu, 0, m, &cVar_cWP0ASJu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mfD12kTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtQ3nRfH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_b8j7NUZh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MXJ3wyBt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3pnrnlFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtQ3nRfH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_b8j7NUZh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MXJ3wyBt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iEbUOzNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtQ3nRfH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_b8j7NUZh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MXJ3wyBt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ANhsNnTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_TGpRYBuK, 0, m, &cVar_TGpRYBuK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mMV4pIz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_tMDmTUC1, 0, m, &cVar_tMDmTUC1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bSlh0NpR, 0, m, &cVar_bSlh0NpR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XSV5LPpD, 0, m, &cVar_XSV5LPpD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RSbyjpa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_yq7ZL24e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hZ8X4hmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtQ3nRfH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_b8j7NUZh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MXJ3wyBt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_P4aCv7Wx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_qPd9KWMg, 0, m, &cVar_qPd9KWMg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_G0S4XgvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4jLA8MQ9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SSdFB1BG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_EgKH64Xo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_otYMqMbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_7zcss8Lv, 0, m, &cVar_7zcss8Lv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_poEf5ZBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Txkdnz4a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FSmdS8S3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TV2VbYSQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_U2ueglSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_BAcoilxZ, 0, m, &cVar_BAcoilxZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tTb0UrbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GtQ3nRfH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_b8j7NUZh_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MXJ3wyBt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_93v7Zmvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XCiADU4P_sendMessage(_c, 0, m);
  cMsg_bbkSU4BC_sendMessage(_c, 0, m);
  cMsg_aAGUEqaD_sendMessage(_c, 0, m);
  cMsg_ZnpSXRbC_sendMessage(_c, 0, m);
  cMsg_hfWDYHs1_sendMessage(_c, 0, m);
  cMsg_3XNJvMrs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BSi5Vrwq, 0, m, &cVar_BSi5Vrwq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AAsR2Wlq, 0, m, &cVar_AAsR2Wlq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x1gwRKLx, 0, m, &cVar_x1gwRKLx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_d86Bbco5, 0, m, &cVar_d86Bbco5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PWc7WF6r, 0, m, &cVar_PWc7WF6r_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ovZIAexZ, 0, m, &cVar_ovZIAexZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3dBjeKVZ, 0, m, &cVar_3dBjeKVZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NLXQvknZ, 0, m, &cVar_NLXQvknZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PsZLMm4X, 0, m, &cVar_PsZLMm4X_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FwBC8RLn, 0, m, &cVar_FwBC8RLn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dr70IFVw, 0, m, &cVar_dr70IFVw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K3W9zt7K, 0, m, &cVar_K3W9zt7K_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TXJraRcY, 0, m, &cVar_TXJraRcY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_y26mh829, 0, m, &cVar_y26mh829_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7OjavuOg, 0, m, &cVar_7OjavuOg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KtwtQaHu, 0, m, &cVar_KtwtQaHu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y5GIoMK3, 0, m, &cVar_Y5GIoMK3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8Qh0LJoM, 0, m, &cVar_8Qh0LJoM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GVdEzmbq, 0, m, &cVar_GVdEzmbq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K2v5B417, 0, m, &cVar_K2v5B417_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CVVo2uHX, 0, m, &cVar_CVVo2uHX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tInjQ2wH, 0, m, &cVar_tInjQ2wH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YBpAip5F, 0, m, &cVar_YBpAip5F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lV5Ne8ER, 0, m, &cVar_lV5Ne8ER_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EQXW3SnD, 0, m, &cVar_EQXW3SnD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dHWJMhJO, 0, m, &cVar_dHWJMhJO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qPoYbhpx, 0, m, &cVar_qPoYbhpx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QTOObYbV, 0, m, &cVar_QTOObYbV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jP41j4l8, 0, m, &cVar_jP41j4l8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eNlDCwbX, 0, m, &cVar_eNlDCwbX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4xnKJLt4, 0, m, &cVar_4xnKJLt4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N4EHx9x6, 0, m, &cVar_N4EHx9x6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VKqpFccA, 0, m, &cVar_VKqpFccA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_umTix8rO, 0, m, &cVar_umTix8rO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oFt1Fhnx, 0, m, &cVar_oFt1Fhnx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JESgWUrs, 0, m, &cVar_JESgWUrs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HrjOeZ1V, 0, m, &cVar_HrjOeZ1V_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4y9jhYxx, 0, m, &cVar_4y9jhYxx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Mkcqb0PW, 0, m, &cVar_Mkcqb0PW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_slvz4SLM, 0, m, &cVar_slvz4SLM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oCEsF3VJ, 0, m, &cVar_oCEsF3VJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tJayuwhs, 0, m, &cVar_tJayuwhs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DpiuHKO0, 0, m, &cVar_DpiuHKO0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EDeJWx8Y, 0, m, &cVar_EDeJWx8Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_y8ASHgpY, 0, m, &cVar_y8ASHgpY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FXSaRvBK, 0, m, &cVar_FXSaRvBK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1oGPpB75, 0, m, &cVar_1oGPpB75_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oqHWbQht, 0, m, &cVar_oqHWbQht_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xojiIr5Y, 0, m, &cVar_xojiIr5Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uHYAOPZu, 0, m, &cVar_uHYAOPZu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wSIQhArf, 0, m, &cVar_wSIQhArf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GZcoSQBY, 0, m, &cVar_GZcoSQBY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Wh6DFBLr, 0, m, &cVar_Wh6DFBLr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3c9IS2cT, 0, m, &cVar_3c9IS2cT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AVUqBteI, 0, m, &cVar_AVUqBteI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K6HQJSNX, 0, m, &cVar_K6HQJSNX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TzYs2DSb, 0, m, &cVar_TzYs2DSb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nfB2srwp, 0, m, &cVar_nfB2srwp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iFvY22vC, 0, m, &cVar_iFvY22vC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_W6EGcOkH, 0, m, &cVar_W6EGcOkH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XyhP9xvG, 0, m, &cVar_XyhP9xvG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vQUEXHPe_sendMessage);
  cMsg_jn4Q9EqL_sendMessage(_c, 0, m);
  cMsg_hOzKomQz_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8u8XXlG6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kwbZJNa2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QlCGLk30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CKlHhUX6, 0, m, &cVar_CKlHhUX6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3wZb6Uoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9WuZS8VQ, 0, m, &cVar_9WuZS8VQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2ezp8psC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z6hYpUpg, 0, m, &cVar_Z6hYpUpg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SR7ecwDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AAsR2Wlq, 0, m, &cVar_AAsR2Wlq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cWJgAdW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dZQgYATO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4TPpNHQx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nsCJahlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tC3npM8W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u12U6Zv6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k3f3Dwjp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XT5bRXqX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GspcLTt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fqG633ZX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IHXa4Ia2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iqrFGaDr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t8unTe5a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_A5xmOXFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9a3w71MT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zz0XYNQx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LFXEPD81_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CLg0UTpK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OztowSrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tMpcksBX, HV_BINOP_MULTIPLY, 0, m, &cBinop_tMpcksBX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VpNoDRzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vWryr1jC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zh40WKra_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xHzmpLSc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_F1Az9lnK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eAz6sHYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_c2Z69g1y_sendMessage);
  cMsg_Q2VeGvhJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_iw6Nm7ge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FnMuoCvZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_FnMuoCvZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aNSVOzRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_GRMBX5ON_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_u0TvZL01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmL4B2xD, HV_BINOP_MULTIPLY, 1, m, &cBinop_HmL4B2xD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NLstZpQS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_FZsFM2cS_sendMessage);
  cMsg_AK2rkAjk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_Rq9RR5do_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_odqridHj, HV_BINOP_MULTIPLY, 0, m, &cBinop_odqridHj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ov6V8kqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NXNQyWV1_sendMessage(_c, 0, m);
  cMsg_hkoXbOMW_sendMessage(_c, 0, m);
  cMsg_0XqDmUYV_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_brpxejLs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Sb94ORiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IWQhmaHH_sendMessage);
  cMsg_FK1iFJGC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_2Jv0htIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PWc7WF6r, 0, m, &cVar_PWc7WF6r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Vhh3HKn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qlCq9Gkx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6Htu2avY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_9QNlmUya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eiM5f1I1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TiZ9yxj3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1Wa3CVit_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bat52ZWO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YremC60Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hJhwstmZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EOH9vYdZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oewQvNHx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ArpyLJpY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3MlWxWa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GJxXaviY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lj94E7AM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_biLyIawD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fen38VU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JNk5SXcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mn2zqb5D, HV_BINOP_MULTIPLY, 0, m, &cBinop_mn2zqb5D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zNspT3NJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SYun2YuC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_eZL15lP5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_quWMb0q8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_FGd4UtGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_mSGWrmIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_DaLf53pe_sendMessage);
  cMsg_U7vKQWKH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_neP48Fjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2cIOP5iF, HV_BINOP_MULTIPLY, 0, m, &cBinop_2cIOP5iF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PNsVL5qT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_puQ6fv8q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_VSfdfk24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tuNxYYfO, HV_BINOP_MULTIPLY, 1, m, &cBinop_tuNxYYfO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VReXuA6r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gXD1R2Qw_sendMessage);
  cMsg_IsAQwkQP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_cNtbUQ89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zhngUmQ0, HV_BINOP_MULTIPLY, 0, m, &cBinop_zhngUmQ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_miNxZ5cN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZWhrC7tM_sendMessage(_c, 0, m);
  cMsg_tT47ezQs_sendMessage(_c, 0, m);
  cMsg_mXOxWKgh_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_JwpjODKx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_iT5xYoJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_c0Sq7UeI_sendMessage);
  cMsg_P92aXplJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_9qNZurPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fBeNiR6V, 0, m, &cVar_fBeNiR6V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5Qa6Jvps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wRL8NeiJ, 0, m, &cVar_wRL8NeiJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lKe1HXOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RYamJPXe, 0, m, &cVar_RYamJPXe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZxYahyL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KaL8GEYA, 0, m, &cVar_KaL8GEYA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yX1EiQtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kvFRpE5E, 0, m, &cVar_kvFRpE5E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WoEffYro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mHb3A5S0, 0, m, &cVar_mHb3A5S0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eWQDEuDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_YlwjMf4Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8jNB3X2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0L88qP6e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OYc7cwAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZNDIRAE8, 0, m, &cVar_ZNDIRAE8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PmRwMPuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DixvPjcv, 0, m, &cVar_DixvPjcv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_kve5jjKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_EGQhq14q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZCiAnUmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vVfbYcSy_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WpnHuwWP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VX339EIP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_XBiuyqrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_U5FXqT8V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sFLpJnH9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_64W6h1ei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cZepppfd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_MJrxSTRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_edsmT7Vv, 0, m, &cVar_edsmT7Vv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YwpZKxBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EHWEowQB, 0, m, &cVar_EHWEowQB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_xklyc3UW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_P95rzb19_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_j80x93J7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_otcHmjaY_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ArVbSQMZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JAtbxjNw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_m6jwopj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gOtxL6cA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_osOtGI6D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8E4Latac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1GRkTjm0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_n4sAAdyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QgkDHj6J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_t6EoXgr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qfp8UMBR, 0, m, &cVar_qfp8UMBR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RQlt0o9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lRhTojfN, 0, m, &cVar_lRhTojfN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yjfLv2zw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_stKYZrRl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_j0HgpWx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wZnsHAyv_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kawYFAMS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l1BAJHsb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_s9D0ik7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PBRFULum_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fAofjfmK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JRYrqwiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ABfRV99I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_Y1ob3sfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tXsybCV5, 0, m, &cVar_tXsybCV5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5psdvpM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VWmKHPg2, 0, m, &cVar_VWmKHPg2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UXbq2r6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_SzBR3Tn3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_iC4hY9lj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YxqoUois_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vojmksV3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qfiI7xDK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sgzQc6wH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vxUrPLM8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rpKmzsKi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Iel6lz4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hhWNy6r9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_o5QGkO21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2wdCNtjH, 0, m, &cVar_2wdCNtjH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JUP4BfBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4ewJkT60, 0, m, &cVar_4ewJkT60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_810GjNgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R6cUEzWq, 0, m, &cVar_R6cUEzWq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fhlSMN64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NOIff12y, 0, m, &cVar_NOIff12y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1jpA0qos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zT7eAdd0, 0, m, &cVar_zT7eAdd0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5Fh76eqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_0mM9T7K4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_mgzoNqQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uSWq3gDA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_51vfUzSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DF7LtATY, 0, m, &cVar_DF7LtATY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WkS6PeY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d0UIHWkd, 0, m, &cVar_d0UIHWkd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hcDUm7kb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_c7g6eaMj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RuuYyErg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_w2vFes6j_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5OtXcAuA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IVhzlfdK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RAP7wnER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tpKmon4H_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YPsn0aZf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fVdOB1J5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LnjoSa1o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_eA7r5huO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H6tWrHtF, 0, m, &cVar_H6tWrHtF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QrDn1mPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y7wMgskn, 0, m, &cVar_Y7wMgskn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_24rle8iv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Ep2y4lbw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pFIjw5Wz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zIlX0k5b_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XhEGfdM4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_36Qe5fkF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HgfLG95u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OiSCg6Pi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CjPr0kXS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hFpLHC2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9udVkbYW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_xDYVSD91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xtFfayxD, 0, m, &cVar_xtFfayxD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2Hnay4BA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TGpRYBuK, 0, m, &cVar_TGpRYBuK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WBgCxIk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tMDmTUC1, 0, m, &cVar_tMDmTUC1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_POJVRBHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bSlh0NpR, 0, m, &cVar_bSlh0NpR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HhyNMNmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XSV5LPpD, 0, m, &cVar_XSV5LPpD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_kuio450i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_yq7ZL24e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_wxo0QNtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qPd9KWMg, 0, m, &cVar_qPd9KWMg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_66ROnvgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7zcss8Lv, 0, m, &cVar_7zcss8Lv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_tbPFkU2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BAcoilxZ, 0, m, &cVar_BAcoilxZ_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_xDMD8vhD, VOf(Bf0));
    __hv_line_f(&sLine_FTFeIzTV, VOf(Bf1));
    __hv_line_f(&sLine_Q7wo8UDV, VOf(Bf2));
    __hv_line_f(&sLine_O9np7GWF, VOf(Bf3));
    __hv_line_f(&sLine_SmxhU3Qr, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_C4Xl65kc, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_feTiTrD3, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_zgdvcgoU, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_7I8IkMkD, VOf(Bf1));
    __hv_line_f(&sLine_luQTH23w, VOf(Bf0));
    __hv_line_f(&sLine_eYofaWbK, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_sGiiG4XQ, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_ZzERC1eB, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_Y3CzqMD9, VOf(Bf5));
    __hv_line_f(&sLine_3N93t4YC, VOf(Bf1));
    __hv_line_f(&sLine_PJscdVPl, VOf(Bf2));
    __hv_line_f(&sLine_FImyBQ29, VOf(Bf4));
    __hv_line_f(&sLine_54MqoVpa, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_DdsUbuaW, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_VHwSqfq3, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_WfLSYGOo, VOf(Bf6));
    __hv_line_f(&sLine_VfgWB3lo, VOf(Bf2));
    __hv_line_f(&sLine_0ZmfOL0Q, VOf(Bf1));
    __hv_line_f(&sLine_8tFqwLvq, VOf(Bf5));
    __hv_line_f(&sLine_2NSIzL49, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_63IS8BpI, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_buaPGSLL, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_lWI4tLvw, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_lKGovGtU, VOf(Bf2));
    __hv_line_f(&sLine_0TBwuNQK, VOf(Bf6));
    __hv_line_f(&sLine_jMAC2ho2, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_KcUNYXJ8, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_9yEHmtNA, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_iSW7F5Yh, VOf(Bf8));
    __hv_line_f(&sLine_Qxh0HVK6, VOf(Bf2));
    __hv_line_f(&sLine_rkpXL11R, VOf(Bf1));
    __hv_line_f(&sLine_vV7SAMrq, VOf(Bf7));
    __hv_line_f(&sLine_a6autZ0S, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_4hLbhCmr, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_tOYnzf5b, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_ue4Q0yK2, VIf(Bf0));
    __hv_varwrite_f(&sVarf_KkgVwEJZ, VIf(Bf6));
    __hv_varwrite_f(&sVarf_ujyL913Q, VIf(Bf4));
    __hv_varwrite_f(&sVarf_AYEAfZZl, VIf(Bf7));
    __hv_varread_f(&sVarf_VuEwVgge, VOf(Bf7));
    __hv_varread_f(&sVarf_r2tni5hX, VOf(Bf4));
    __hv_varread_f(&sVarf_VycZz8KO, VOf(Bf6));
    __hv_varread_f(&sVarf_rHUnVnBC, VOf(Bf0));
    __hv_varread_f(&sVarf_WBFCvsY8, VOf(Bf9));
    __hv_varread_f(&sVarf_d4FAhhE8, VOf(Bf1));
    __hv_line_f(&sLine_AO2rZ4n4, VOf(Bf2));
    __hv_line_f(&sLine_1goSm9Zr, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_VycZz8KO, VIf(Bf7));
    __hv_varwrite_f(&sVarf_WBFCvsY8, VIf(Bf4));
    __hv_varread_f(&sVarf_7QHrG7XT, VOf(Bf2));
    __hv_varread_f(&sVarf_LckS7ywX, VOf(Bf9));
    __hv_varread_f(&sVarf_Y9AMAtzs, VOf(Bf1));
    __hv_varread_f(&sVarf_XgNQVIPc, VOf(Bf6));
    __hv_varread_f(&sVarf_0H6UUASK, VOf(Bf10));
    __hv_varread_f(&sVarf_Rk24idhD, VOf(Bf11));
    __hv_varread_f(&sVarf_iD9qEnjg, VOf(Bf12));
    __hv_varwrite_f(&sVarf_JMj3XXFj, VIf(Bf7));
    __hv_varread_f(&sVarf_CswBK4RD, VOf(Bf13));
    __hv_line_f(&sLine_4FkqoEdr, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_9ycg3PKl, VOf(Bf15));
    __hv_line_f(&sLine_dUaqa5FB, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_qcWIsCaV, VOf(Bf14));
    __hv_line_f(&sLine_AB1tZY1X, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_XgNQVIPc, VIf(Bf17));
    __hv_varread_f(&sVarf_JMj3XXFj, VOf(Bf17));
    __hv_line_f(&sLine_QikgEvqi, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_hKLy1OZR, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_KMXBEv8k, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_0H6UUASK, VIf(Bf16));
    __hv_line_f(&sLine_QMTMDGYj, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_YMDuPPsn, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_rqr7pDMe, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_Rk24idhD, VIf(Bf16));
    __hv_line_f(&sLine_2T5rapD5, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_QcWROYeo, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_3YTudQSD, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_iD9qEnjg, VIf(Bf16));
    __hv_varwrite_f(&sVarf_CswBK4RD, VIf(Bf2));
    __hv_varwrite_f(&sVarf_9ycg3PKl, VIf(Bf9));
    __hv_varwrite_f(&sVarf_qcWIsCaV, VIf(Bf1));
    sEnv_process(this, &sEnv_8I2AavaZ, VIf(Bf6), &sEnv_8I2AavaZ_sendMessage);
    sEnv_process(this, &sEnv_k8RewRdg, VIf(Bf7), &sEnv_k8RewRdg_sendMessage);
    __hv_line_f(&sLine_lpXITf1q, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_rw2R5x0S, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_zKhmL0eq, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_sCdTfaPH, VOf(Bf6));
    __hv_line_f(&sLine_jsOCqsb9, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_7QHrG7XT, VIf(Bf9));
    __hv_varwrite_f(&sVarf_sCdTfaPH, VIf(Bf10));
    __hv_varwrite_f(&sVarf_QBuFdkfc, VIf(Bf11));
    __hv_varwrite_f(&sVarf_szSg8TqW, VIf(Bf12));
    __hv_varread_f(&sVarf_szSg8TqW, VOf(Bf12));
    __hv_line_f(&sLine_zYIxGrEX, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_Y9AMAtzs, VIf(Bf10));
    __hv_varread_f(&sVarf_QBuFdkfc, VOf(Bf10));
    __hv_line_f(&sLine_EKuCotir, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_LckS7ywX, VIf(Bf10));
    __hv_varwrite_f(&sVarf_rHUnVnBC, VIf(Bf7));
    __hv_varread_f(&sVarf_aH7ztarG, VOf(Bf7));
    __hv_varread_f(&sVarf_0oVRCv4X, VOf(Bf10));
    __hv_varread_f(&sVarf_qJlYZGf6, VOf(Bf9));
    __hv_varread_f(&sVarf_vhMDKSOh, VOf(Bf11));
    __hv_varread_f(&sVarf_u7SEbjaX, VOf(Bf6));
    __hv_varread_f(&sVarf_DPjqO6Sy, VOf(Bf12));
    __hv_varread_f(&sVarf_2x4cn39u, VOf(Bf1));
    __hv_varwrite_f(&sVarf_na4zd2yW, VIf(Bf4));
    __hv_varread_f(&sVarf_g1ggr5wz, VOf(Bf2));
    __hv_line_f(&sLine_H9Fyl5Ww, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_9YC6RL7g, VOf(Bf17));
    __hv_line_f(&sLine_bFZMWWwB, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_e8ialC3r, VOf(Bf16));
    __hv_line_f(&sLine_OU8jNKbx, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_vhMDKSOh, VIf(Bf15));
    __hv_varread_f(&sVarf_na4zd2yW, VOf(Bf15));
    __hv_line_f(&sLine_lY4aP3aS, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_9JeXxVOp, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_im1mFQcA, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_u7SEbjaX, VIf(Bf13));
    __hv_line_f(&sLine_OITM22Uh, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_EPx76WLx, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_67F3F3cf, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_DPjqO6Sy, VIf(Bf13));
    __hv_line_f(&sLine_jnCCOh9a, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_3r9ZuJmw, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_916H9aN2, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_2x4cn39u, VIf(Bf13));
    __hv_varwrite_f(&sVarf_g1ggr5wz, VIf(Bf7));
    __hv_varwrite_f(&sVarf_9YC6RL7g, VIf(Bf10));
    __hv_varwrite_f(&sVarf_e8ialC3r, VIf(Bf9));
    sEnv_process(this, &sEnv_05lA29xt, VIf(Bf11), &sEnv_05lA29xt_sendMessage);
    sEnv_process(this, &sEnv_QuennDTW, VIf(Bf4), &sEnv_QuennDTW_sendMessage);
    __hv_line_f(&sLine_j3bMlyI5, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_YAQqEmQ4, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_8I1ZYsHX, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_hilUcDsD, VOf(Bf11));
    __hv_line_f(&sLine_bg6xx5OP, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_aH7ztarG, VIf(Bf10));
    __hv_varwrite_f(&sVarf_hilUcDsD, VIf(Bf6));
    __hv_varwrite_f(&sVarf_9Ea2JTmW, VIf(Bf12));
    __hv_varwrite_f(&sVarf_YqAlHNVi, VIf(Bf1));
    __hv_varread_f(&sVarf_YqAlHNVi, VOf(Bf1));
    __hv_line_f(&sLine_lsv3ZpYe, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_qJlYZGf6, VIf(Bf6));
    __hv_varread_f(&sVarf_9Ea2JTmW, VOf(Bf6));
    __hv_line_f(&sLine_hvw88l84, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_0oVRCv4X, VIf(Bf6));
    __hv_varwrite_f(&sVarf_d4FAhhE8, VIf(Bf4));
    __hv_varwrite_f(&sVarf_kFCCoLTy, VIf(Bf0));
    __hv_varread_f(&sVarf_ue4Q0yK2, VOf(Bf0));
    __hv_varread_f(&sVarf_KkgVwEJZ, VOf(Bf4));
    __hv_varread_f(&sVarf_e5sZ6bHs, VOf(Bf6));
    __hv_varread_f(&sVarf_1Z1tZFVx, VOf(Bf10));
    __hv_varread_f(&sVarf_DBYhKVIM, VOf(Bf12));
    __hv_varread_f(&sVarf_Wl0CSus1, VOf(Bf11));
    __hv_line_f(&sLine_4viKkn7K, VOf(Bf1));
    __hv_line_f(&sLine_T4cf6d5T, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_e5sZ6bHs, VIf(Bf0));
    __hv_varwrite_f(&sVarf_DBYhKVIM, VIf(Bf4));
    __hv_varread_f(&sVarf_P7wVsE8Z, VOf(Bf1));
    __hv_varread_f(&sVarf_z18kN1yV, VOf(Bf12));
    __hv_varread_f(&sVarf_HDaOl5It, VOf(Bf11));
    __hv_varread_f(&sVarf_amxWlj5Q, VOf(Bf6));
    __hv_varread_f(&sVarf_omjPNv5S, VOf(Bf7));
    __hv_varread_f(&sVarf_79Vj6AtR, VOf(Bf13));
    __hv_varread_f(&sVarf_5lytIzup, VOf(Bf15));
    __hv_varwrite_f(&sVarf_zeAFWw6b, VIf(Bf0));
    __hv_varread_f(&sVarf_uiUHmmNy, VOf(Bf2));
    __hv_line_f(&sLine_imap6kx1, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_vmPVrhYt, VOf(Bf18));
    __hv_line_f(&sLine_s5dewbb7, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_LPLBq9AD, VOf(Bf17));
    __hv_line_f(&sLine_rbkkO81R, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_amxWlj5Q, VIf(Bf14));
    __hv_varread_f(&sVarf_zeAFWw6b, VOf(Bf14));
    __hv_line_f(&sLine_UjIe0wB0, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_FFPTPYu5, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_Qv3eaGnk, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_omjPNv5S, VIf(Bf16));
    __hv_line_f(&sLine_YjL4PIej, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_fWRK1Yyw, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_FxjQcaT5, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_79Vj6AtR, VIf(Bf16));
    __hv_line_f(&sLine_6TbGbZLC, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_RdoIW7TP, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_uUrJ6ASI, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_5lytIzup, VIf(Bf16));
    __hv_varwrite_f(&sVarf_uiUHmmNy, VIf(Bf1));
    __hv_varwrite_f(&sVarf_vmPVrhYt, VIf(Bf12));
    __hv_varwrite_f(&sVarf_LPLBq9AD, VIf(Bf11));
    sEnv_process(this, &sEnv_C0qxFZhV, VIf(Bf6), &sEnv_C0qxFZhV_sendMessage);
    sEnv_process(this, &sEnv_lNcyKyzB, VIf(Bf0), &sEnv_lNcyKyzB_sendMessage);
    __hv_line_f(&sLine_CjF2d5lm, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_Jauuiu3F, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_IqUJbKmP, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_muQmtaV5, VOf(Bf6));
    __hv_line_f(&sLine_6BrdkH41, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_P7wVsE8Z, VIf(Bf12));
    __hv_varwrite_f(&sVarf_muQmtaV5, VIf(Bf7));
    __hv_varwrite_f(&sVarf_xc1iUKYg, VIf(Bf13));
    __hv_varwrite_f(&sVarf_PVWWepC7, VIf(Bf15));
    __hv_varread_f(&sVarf_PVWWepC7, VOf(Bf15));
    __hv_line_f(&sLine_ODdFopKq, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_HDaOl5It, VIf(Bf7));
    __hv_varread_f(&sVarf_xc1iUKYg, VOf(Bf7));
    __hv_line_f(&sLine_2dUsWEuF, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_z18kN1yV, VIf(Bf7));
    __hv_varwrite_f(&sVarf_1Z1tZFVx, VIf(Bf0));
    __hv_varread_f(&sVarf_fKdqw9Pd, VOf(Bf0));
    __hv_varread_f(&sVarf_h8Bbbo38, VOf(Bf7));
    __hv_varread_f(&sVarf_rQpCN701, VOf(Bf12));
    __hv_varread_f(&sVarf_GtXTzvVJ, VOf(Bf13));
    __hv_varread_f(&sVarf_1Cnzr1GK, VOf(Bf6));
    __hv_varread_f(&sVarf_LNCkQCxs, VOf(Bf15));
    __hv_varread_f(&sVarf_qiHcQB6d, VOf(Bf11));
    __hv_varwrite_f(&sVarf_T6pMXDJ0, VIf(Bf4));
    __hv_varread_f(&sVarf_nUdy6Oek, VOf(Bf1));
    __hv_line_f(&sLine_GcuJvUXP, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_CiAfKGlH, VOf(Bf14));
    __hv_line_f(&sLine_c81Khmzt, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_LYkzKyG8, VOf(Bf16));
    __hv_line_f(&sLine_fcK3TKG7, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_GtXTzvVJ, VIf(Bf18));
    __hv_varread_f(&sVarf_T6pMXDJ0, VOf(Bf18));
    __hv_line_f(&sLine_4FuRiRKa, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_R3UlV6im, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_23g6OJ46, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_1Cnzr1GK, VIf(Bf2));
    __hv_line_f(&sLine_scf0alsI, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_XXaEjQCy, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_hvgcP6hu, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_LNCkQCxs, VIf(Bf2));
    __hv_line_f(&sLine_nV1cwAVB, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_8rb5DdsF, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_K9zOQ3mr, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_qiHcQB6d, VIf(Bf2));
    __hv_varwrite_f(&sVarf_nUdy6Oek, VIf(Bf0));
    __hv_varwrite_f(&sVarf_CiAfKGlH, VIf(Bf7));
    __hv_varwrite_f(&sVarf_LYkzKyG8, VIf(Bf12));
    sEnv_process(this, &sEnv_N5SiBRa8, VIf(Bf13), &sEnv_N5SiBRa8_sendMessage);
    sEnv_process(this, &sEnv_6j78uC21, VIf(Bf4), &sEnv_6j78uC21_sendMessage);
    __hv_line_f(&sLine_66u6Ukwv, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_I7K81zKl, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_emrotTTQ, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_bEo3VLqS, VOf(Bf13));
    __hv_line_f(&sLine_nn8fFKr1, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_fKdqw9Pd, VIf(Bf7));
    __hv_varwrite_f(&sVarf_bEo3VLqS, VIf(Bf6));
    __hv_varwrite_f(&sVarf_YW4vWF6x, VIf(Bf15));
    __hv_varwrite_f(&sVarf_qJkKBFzr, VIf(Bf11));
    __hv_varread_f(&sVarf_qJkKBFzr, VOf(Bf11));
    __hv_line_f(&sLine_YIazHxvq, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_rQpCN701, VIf(Bf6));
    __hv_varread_f(&sVarf_YW4vWF6x, VOf(Bf6));
    __hv_line_f(&sLine_Zja1w4Ff, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_h8Bbbo38, VIf(Bf6));
    __hv_varwrite_f(&sVarf_Wl0CSus1, VIf(Bf4));
    __hv_varwrite_f(&sVarf_hp9iFfBy, VIf(Bf10));
    __hv_varread_f(&sVarf_ujyL913Q, VOf(Bf10));
    __hv_varread_f(&sVarf_AYEAfZZl, VOf(Bf4));
    __hv_varread_f(&sVarf_vdjnRpgs, VOf(Bf6));
    __hv_varread_f(&sVarf_QsVQ0cZ6, VOf(Bf7));
    __hv_varread_f(&sVarf_IrZSwK3K, VOf(Bf15));
    __hv_varread_f(&sVarf_s7nV9wqn, VOf(Bf13));
    __hv_line_f(&sLine_7kKII2te, VOf(Bf11));
    __hv_line_f(&sLine_2kVhlrGH, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_vdjnRpgs, VIf(Bf10));
    __hv_varwrite_f(&sVarf_IrZSwK3K, VIf(Bf4));
    __hv_varread_f(&sVarf_Qy5tS7Wo, VOf(Bf11));
    __hv_varread_f(&sVarf_VMRc3G3y, VOf(Bf15));
    __hv_varread_f(&sVarf_NzbO1kxH, VOf(Bf13));
    __hv_varread_f(&sVarf_ncykVzdu, VOf(Bf6));
    __hv_varread_f(&sVarf_0HSjEky7, VOf(Bf0));
    __hv_varread_f(&sVarf_E1fIeS6f, VOf(Bf2));
    __hv_varread_f(&sVarf_3PM6NRdM, VOf(Bf18));
    __hv_varwrite_f(&sVarf_GAcXPE5Q, VIf(Bf10));
    __hv_varread_f(&sVarf_6XElEKFi, VOf(Bf1));
    __hv_line_f(&sLine_ADU3pU8E, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_twxOL2gv, VOf(Bf19));
    __hv_line_f(&sLine_OVIIniNx, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_kFHxfEsg, VOf(Bf14));
    __hv_line_f(&sLine_olLnLmzE, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_ncykVzdu, VIf(Bf17));
    __hv_varread_f(&sVarf_GAcXPE5Q, VOf(Bf17));
    __hv_line_f(&sLine_2jBiqcyt, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_FpvHjCof, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_Cfo3mEtD, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_0HSjEky7, VIf(Bf16));
    __hv_line_f(&sLine_FWY9PQO3, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_kPTb6DvY, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_nUCE0QFc, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_E1fIeS6f, VIf(Bf16));
    __hv_line_f(&sLine_5D4Wla7L, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_cHtUmy29, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_ww3slCCJ, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_3PM6NRdM, VIf(Bf16));
    __hv_varwrite_f(&sVarf_6XElEKFi, VIf(Bf11));
    __hv_varwrite_f(&sVarf_twxOL2gv, VIf(Bf15));
    __hv_varwrite_f(&sVarf_kFHxfEsg, VIf(Bf13));
    sEnv_process(this, &sEnv_B0dIa2Pd, VIf(Bf6), &sEnv_B0dIa2Pd_sendMessage);
    sEnv_process(this, &sEnv_JxZZHewb, VIf(Bf10), &sEnv_JxZZHewb_sendMessage);
    __hv_line_f(&sLine_h40aHv3q, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_Apfcv8qH, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_t3sCLgyX, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_tJ70SdOP, VOf(Bf6));
    __hv_line_f(&sLine_7VL79Njo, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_Qy5tS7Wo, VIf(Bf15));
    __hv_varwrite_f(&sVarf_tJ70SdOP, VIf(Bf0));
    __hv_varwrite_f(&sVarf_0BjaxN28, VIf(Bf2));
    __hv_varwrite_f(&sVarf_E1ykewi2, VIf(Bf18));
    __hv_varread_f(&sVarf_E1ykewi2, VOf(Bf18));
    __hv_line_f(&sLine_A4iUqYeO, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_NzbO1kxH, VIf(Bf0));
    __hv_varread_f(&sVarf_0BjaxN28, VOf(Bf0));
    __hv_line_f(&sLine_v6lZF7Jr, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_VMRc3G3y, VIf(Bf0));
    __hv_varwrite_f(&sVarf_QsVQ0cZ6, VIf(Bf10));
    __hv_varread_f(&sVarf_aXCbXoE4, VOf(Bf10));
    __hv_varread_f(&sVarf_6EuvYzcc, VOf(Bf0));
    __hv_varread_f(&sVarf_2cTII000, VOf(Bf15));
    __hv_varread_f(&sVarf_ziKLogsF, VOf(Bf2));
    __hv_varread_f(&sVarf_pGXBMu2q, VOf(Bf6));
    __hv_varread_f(&sVarf_ZRxTI3mt, VOf(Bf18));
    __hv_varread_f(&sVarf_5ymnO4kV, VOf(Bf13));
    __hv_varwrite_f(&sVarf_c7meKh0X, VIf(Bf4));
    __hv_varread_f(&sVarf_95et0w97, VOf(Bf11));
    __hv_line_f(&sLine_nvtTWWvs, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_SZu149Ob, VOf(Bf17));
    __hv_line_f(&sLine_DlyL8j4R, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_YlGN4I7Q, VOf(Bf16));
    __hv_line_f(&sLine_zKnnP0vm, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_ziKLogsF, VIf(Bf19));
    __hv_varread_f(&sVarf_c7meKh0X, VOf(Bf19));
    __hv_line_f(&sLine_BtddmSqq, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_fg4rdsLb, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_5Xd2g0VE, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_pGXBMu2q, VIf(Bf1));
    __hv_line_f(&sLine_e6Thk3AC, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_s5YJ384D, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_fSsM6t4s, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_ZRxTI3mt, VIf(Bf1));
    __hv_line_f(&sLine_6o9dr5e7, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_pFzcvv2s, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_J5to9nmY, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_5ymnO4kV, VIf(Bf1));
    __hv_varwrite_f(&sVarf_95et0w97, VIf(Bf10));
    __hv_varwrite_f(&sVarf_SZu149Ob, VIf(Bf0));
    __hv_varwrite_f(&sVarf_YlGN4I7Q, VIf(Bf15));
    sEnv_process(this, &sEnv_8KVf23yW, VIf(Bf2), &sEnv_8KVf23yW_sendMessage);
    sEnv_process(this, &sEnv_ces4OKNA, VIf(Bf4), &sEnv_ces4OKNA_sendMessage);
    __hv_line_f(&sLine_lKRGoCU4, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_Tb6keyZu, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_xXjR9Ejs, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_5Z7QKiSP, VOf(Bf2));
    __hv_line_f(&sLine_7OC7X3OX, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_aXCbXoE4, VIf(Bf0));
    __hv_varwrite_f(&sVarf_5Z7QKiSP, VIf(Bf6));
    __hv_varwrite_f(&sVarf_f2txLTEm, VIf(Bf18));
    __hv_varwrite_f(&sVarf_PRj7ZqSm, VIf(Bf13));
    __hv_varread_f(&sVarf_PRj7ZqSm, VOf(Bf13));
    __hv_line_f(&sLine_yaHtpyqH, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_2cTII000, VIf(Bf6));
    __hv_varread_f(&sVarf_f2txLTEm, VOf(Bf6));
    __hv_line_f(&sLine_lzzAREx4, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_6EuvYzcc, VIf(Bf6));
    __hv_varwrite_f(&sVarf_s7nV9wqn, VIf(Bf4));
    __hv_varwrite_f(&sVarf_qyKrSBii, VIf(Bf7));
    __hv_varwrite_f(&sVarf_4Krz1zVU, VIf(Bf8));
    __hv_varwrite_f(&sVarf_RnT9gRjM, VIf(Bf9));
    __hv_varwrite_f(&sVarf_YBnVbyr8, VIf(Bf12));
    __hv_varwrite_f(&sVarf_VuEwVgge, VIf(Bf3));
    __hv_varwrite_f(&sVarf_r2tni5hX, VIf(Bf5));
    __hv_varread_f(&sVarf_kFCCoLTy, VOf(Bf5));
    __hv_varread_f(&sVarf_hp9iFfBy, VOf(Bf3));
    __hv_varread_f(&sVarf_qyKrSBii, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_4Krz1zVU, VOf(Bf12));
    __hv_varread_f(&sVarf_RnT9gRjM, VOf(Bf5));
    __hv_varread_f(&sVarf_YBnVbyr8, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
